
// File: index.xml

// File: classAdmixtures.xml
%feature("docstring") Admixtures "

The list of material admixtures to a slice.

Needed for calculating the average of a material, which is needed in the Fresnel calculation.

C++ includes: Admixtures.h
";

%feature("docstring")  Admixtures::Admixtures "Admixtures::Admixtures()=default
";

%feature("docstring")  Admixtures::Admixtures "Admixtures::Admixtures(const std::vector< OneAdmixture > &_super)
";


// File: classBaseMaterialImpl.xml
%feature("docstring") BaseMaterialImpl "

Interface for material implementation classes. Inherited by  MagneticMaterialImpl, which has further children.

C++ includes: BaseMaterialImpl.h
";

%feature("docstring")  BaseMaterialImpl::BaseMaterialImpl "BaseMaterialImpl::BaseMaterialImpl(std::string name)

Constructs basic material with name. 
";

%feature("docstring")  BaseMaterialImpl::~BaseMaterialImpl "virtual BaseMaterialImpl::~BaseMaterialImpl()=default
";

%feature("docstring")  BaseMaterialImpl::clone "virtual BaseMaterialImpl* BaseMaterialImpl::clone() const =0

Returns pointer to a copy of material. 
";

%feature("docstring")  BaseMaterialImpl::inverted "virtual BaseMaterialImpl* BaseMaterialImpl::inverted() const =0

Constructs a material with inverted magnetization. 
";

%feature("docstring")  BaseMaterialImpl::refractiveIndex "virtual complex_t BaseMaterialImpl::refractiveIndex(double wavelength) const =0

Returns refractive index. 
";

%feature("docstring")  BaseMaterialImpl::refractiveIndex2 "virtual complex_t BaseMaterialImpl::refractiveIndex2(double wavelength) const =0

Returns squared refractive index. 
";

%feature("docstring")  BaseMaterialImpl::isScalarMaterial "virtual bool BaseMaterialImpl::isScalarMaterial() const =0

Indicates whether the interaction with the material is scalar. This means that different polarization states will be diffracted equally 
";

%feature("docstring")  BaseMaterialImpl::isMagneticMaterial "virtual bool BaseMaterialImpl::isMagneticMaterial() const =0
";

%feature("docstring")  BaseMaterialImpl::magnetization "virtual R3 BaseMaterialImpl::magnetization() const =0

Returns the magnetization (in A/m) 
";

%feature("docstring")  BaseMaterialImpl::materialData "virtual complex_t BaseMaterialImpl::materialData() const =0

Returns underlying material data. 
";

%feature("docstring")  BaseMaterialImpl::typeID "virtual MATERIAL_TYPES BaseMaterialImpl::typeID() const =0

Returns type of material implementation. 
";

%feature("docstring")  BaseMaterialImpl::scalarSubtrSLD "virtual complex_t BaseMaterialImpl::scalarSubtrSLD(double lambda0) const =0

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld being the scattering length density. 
";

%feature("docstring")  BaseMaterialImpl::polarizedSubtrSLD "virtual Eigen::Matrix2cd BaseMaterialImpl::polarizedSubtrSLD(const WavevectorInfo &wavevectors) const =0

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld) matrix with magnetization corrections. 
";

%feature("docstring")  BaseMaterialImpl::rotatedMaterial "virtual BaseMaterialImpl* BaseMaterialImpl::rotatedMaterial(const Transform3D &transform) const =0
";

%feature("docstring")  BaseMaterialImpl::print "virtual void BaseMaterialImpl::print(std::ostream &ostr) const =0

Prints object data. 
";

%feature("docstring")  BaseMaterialImpl::matName "const std::string& BaseMaterialImpl::matName() const

Returns name of the material. 
";


// File: classBasicLattice2D.xml
%feature("docstring") BasicLattice2D "

A two-dimensional Bravais lattice with no special symmetry.

C++ includes: Lattice2D.h
";

%feature("docstring")  BasicLattice2D::className "std::string BasicLattice2D::className() const final
";

%feature("docstring")  BasicLattice2D::BasicLattice2D "BasicLattice2D::BasicLattice2D(double length1, double length2, double angle, double xi)
";

%feature("docstring")  BasicLattice2D::clone "BasicLattice2D * BasicLattice2D::clone() const override
";

%feature("docstring")  BasicLattice2D::accept "void BasicLattice2D::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  BasicLattice2D::length1 "double BasicLattice2D::length1() const override
";

%feature("docstring")  BasicLattice2D::length2 "double BasicLattice2D::length2() const override
";

%feature("docstring")  BasicLattice2D::latticeAngle "double BasicLattice2D::latticeAngle() const override
";

%feature("docstring")  BasicLattice2D::unitCellArea "double BasicLattice2D::unitCellArea() const override
";


// File: classBox.xml
%feature("docstring") Box "";

%feature("docstring")  Box::Box "Box::Box(double length, double width, double height)
";

%feature("docstring")  Box::~Box "Box::~Box() override
";


// File: classCrystal.xml
%feature("docstring") Crystal "

A crystal structure, defined by a Bravais lattice, a basis, and a position variance.

The basis is either a  Particle or a  ParticleComposition.

Computations are delegated to class  FormFactorCrystal.

Used in  MesoCrystal, where it is given an outer shape.

C++ includes: Crystal.h
";

%feature("docstring")  Crystal::className "std::string Crystal::className() const final
";

%feature("docstring")  Crystal::Crystal "Crystal::Crystal(const IParticle &basis, const Lattice3D &lattice, double position_variance=0)
";

%feature("docstring")  Crystal::~Crystal "Crystal::~Crystal() override
";

%feature("docstring")  Crystal::clone "Crystal * Crystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Crystal::accept "void Crystal::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Crystal::createTotalFormFactor "IFormFactor * Crystal::createTotalFormFactor(const IFormFactor &meso_crystal_form_factor, const IRotation *rotation, const R3 &translation) const
";

%feature("docstring")  Crystal::admixtures "Admixtures Crystal::admixtures() const
";

%feature("docstring")  Crystal::transformedLattice "Lattice3D Crystal::transformedLattice(const IRotation *rotation=nullptr) const
";

%feature("docstring")  Crystal::getChildren "std::vector< const INode * > Crystal::getChildren() const override
";


// File: classDistribution1DCauchySampler.xml
%feature("docstring") Distribution1DCauchySampler "";

%feature("docstring")  Distribution1DCauchySampler::Distribution1DCauchySampler "Distribution1DCauchySampler::Distribution1DCauchySampler(double lambda)
";

%feature("docstring")  Distribution1DCauchySampler::randomSample "double Distribution1DCauchySampler::randomSample() const override
";


// File: classDistribution1DCosineSampler.xml
%feature("docstring") Distribution1DCosineSampler "";

%feature("docstring")  Distribution1DCosineSampler::Distribution1DCosineSampler "Distribution1DCosineSampler::Distribution1DCosineSampler(double omega)
";

%feature("docstring")  Distribution1DCosineSampler::randomSample "double Distribution1DCosineSampler::randomSample() const override
";


// File: classDistribution1DGateSampler.xml
%feature("docstring") Distribution1DGateSampler "";

%feature("docstring")  Distribution1DGateSampler::Distribution1DGateSampler "Distribution1DGateSampler::Distribution1DGateSampler(double a, double b)
";

%feature("docstring")  Distribution1DGateSampler::randomSample "double Distribution1DGateSampler::randomSample() const override
";


// File: classDistribution1DGaussSampler.xml
%feature("docstring") Distribution1DGaussSampler "";

%feature("docstring")  Distribution1DGaussSampler::Distribution1DGaussSampler "Distribution1DGaussSampler::Distribution1DGaussSampler(double mean, double stddev)
";

%feature("docstring")  Distribution1DGaussSampler::randomSample "double Distribution1DGaussSampler::randomSample() const override
";


// File: classDistribution1DTriangleSampler.xml
%feature("docstring") Distribution1DTriangleSampler "";

%feature("docstring")  Distribution1DTriangleSampler::Distribution1DTriangleSampler "Distribution1DTriangleSampler::Distribution1DTriangleSampler(double omega)
";

%feature("docstring")  Distribution1DTriangleSampler::randomSample "double Distribution1DTriangleSampler::randomSample() const override
";


// File: classDistribution2DCauchySampler.xml
%feature("docstring") Distribution2DCauchySampler "";

%feature("docstring")  Distribution2DCauchySampler::Distribution2DCauchySampler "Distribution2DCauchySampler::Distribution2DCauchySampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DCauchySampler::randomSample "std::pair< double, double > Distribution2DCauchySampler::randomSample() const override
";


// File: classDistribution2DConeSampler.xml
%feature("docstring") Distribution2DConeSampler "";

%feature("docstring")  Distribution2DConeSampler::Distribution2DConeSampler "Distribution2DConeSampler::Distribution2DConeSampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DConeSampler::randomSample "std::pair< double, double > Distribution2DConeSampler::randomSample() const override
";


// File: classDistribution2DGateSampler.xml
%feature("docstring") Distribution2DGateSampler "";

%feature("docstring")  Distribution2DGateSampler::Distribution2DGateSampler "Distribution2DGateSampler::Distribution2DGateSampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DGateSampler::randomSample "std::pair< double, double > Distribution2DGateSampler::randomSample() const override
";


// File: classDistribution2DGaussSampler.xml
%feature("docstring") Distribution2DGaussSampler "";

%feature("docstring")  Distribution2DGaussSampler::Distribution2DGaussSampler "Distribution2DGaussSampler::Distribution2DGaussSampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DGaussSampler::randomSample "std::pair< double, double > Distribution2DGaussSampler::randomSample() const override
";


// File: classDoubleEllipse.xml
%feature("docstring") DoubleEllipse "";

%feature("docstring")  DoubleEllipse::DoubleEllipse "DoubleEllipse::DoubleEllipse(double r0_x, double r0_y, double z, double rz_x, double rz_y)
";

%feature("docstring")  DoubleEllipse::~DoubleEllipse "DoubleEllipse::~DoubleEllipse() override
";


// File: classFormFactorAnisoPyramid.xml
%feature("docstring") FormFactorAnisoPyramid "

A frustum (truncated pyramid) with rectangular base.

C++ includes: FormFactorAnisoPyramid.h
";

%feature("docstring")  FormFactorAnisoPyramid::className "std::string FormFactorAnisoPyramid::className() const final
";

%feature("docstring")  FormFactorAnisoPyramid::FormFactorAnisoPyramid "FormFactorAnisoPyramid::FormFactorAnisoPyramid(std::vector< double > P)
";

%feature("docstring")  FormFactorAnisoPyramid::FormFactorAnisoPyramid "FormFactorAnisoPyramid::FormFactorAnisoPyramid(double length, double width, double height, double alpha)
";

%feature("docstring")  FormFactorAnisoPyramid::clone "FormFactorAnisoPyramid* FormFactorAnisoPyramid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorAnisoPyramid::accept "void FormFactorAnisoPyramid::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorAnisoPyramid::getLength "double FormFactorAnisoPyramid::getLength() const
";

%feature("docstring")  FormFactorAnisoPyramid::getWidth "double FormFactorAnisoPyramid::getWidth() const
";

%feature("docstring")  FormFactorAnisoPyramid::getHeight "double FormFactorAnisoPyramid::getHeight() const
";

%feature("docstring")  FormFactorAnisoPyramid::getAlpha "double FormFactorAnisoPyramid::getAlpha() const
";


// File: classFormFactorBarGauss.xml
%feature("docstring") FormFactorBarGauss "

The form factor of an elongated bar, with Gaussian profile in elongation direction.

C++ includes: FormFactorBar.h
";

%feature("docstring")  FormFactorBarGauss::className "std::string FormFactorBarGauss::className() const final
";

%feature("docstring")  FormFactorBarGauss::FormFactorBarGauss "FormFactorBarGauss::FormFactorBarGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorBarGauss::FormFactorBarGauss "FormFactorBarGauss::FormFactorBarGauss(double length, double width, double height)
";

%feature("docstring")  FormFactorBarGauss::clone "FormFactorBarGauss * FormFactorBarGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBarGauss::accept "void FormFactorBarGauss::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorBarLorentz.xml
%feature("docstring") FormFactorBarLorentz "

The form factor of an elongated, with Lorentz form factor in elongation direction.

C++ includes: FormFactorBar.h
";

%feature("docstring")  FormFactorBarLorentz::className "std::string FormFactorBarLorentz::className() const final
";

%feature("docstring")  FormFactorBarLorentz::FormFactorBarLorentz "FormFactorBarLorentz::FormFactorBarLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorBarLorentz::FormFactorBarLorentz "FormFactorBarLorentz::FormFactorBarLorentz(double length, double width, double height)
";

%feature("docstring")  FormFactorBarLorentz::clone "FormFactorBarLorentz * FormFactorBarLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBarLorentz::accept "void FormFactorBarLorentz::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorBox.xml
%feature("docstring") FormFactorBox "

A rectangular prism (parallelepiped).

C++ includes: FormFactorBox.h
";

%feature("docstring")  FormFactorBox::className "std::string FormFactorBox::className() const final
";

%feature("docstring")  FormFactorBox::FormFactorBox "FormFactorBox::FormFactorBox(std::vector< double > P)
";

%feature("docstring")  FormFactorBox::FormFactorBox "FormFactorBox::FormFactorBox(double length, double width, double height)
";

%feature("docstring")  FormFactorBox::clone "FormFactorBox* FormFactorBox::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBox::accept "void FormFactorBox::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorBox::getLength "double FormFactorBox::getLength() const
";

%feature("docstring")  FormFactorBox::getWidth "double FormFactorBox::getWidth() const
";

%feature("docstring")  FormFactorBox::volume "double FormFactorBox::volume() const override

Returns the total volume of the particle of this form factor's shape. 
";

%feature("docstring")  FormFactorBox::radialExtension "double FormFactorBox::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorBox::evaluate_for_q "complex_t FormFactorBox::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorCantellatedCube.xml
%feature("docstring") FormFactorCantellatedCube "

A cube, with truncation of all edges and corners, as in Croset (2017) Fig 7

C++ includes: FormFactorCantellatedCube.h
";

%feature("docstring")  FormFactorCantellatedCube::className "std::string FormFactorCantellatedCube::className() const final
";

%feature("docstring")  FormFactorCantellatedCube::FormFactorCantellatedCube "FormFactorCantellatedCube::FormFactorCantellatedCube(std::vector< double > P)
";

%feature("docstring")  FormFactorCantellatedCube::FormFactorCantellatedCube "FormFactorCantellatedCube::FormFactorCantellatedCube(double length, double removed_length)
";

%feature("docstring")  FormFactorCantellatedCube::clone "FormFactorCantellatedCube* FormFactorCantellatedCube::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCantellatedCube::accept "void FormFactorCantellatedCube::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCantellatedCube::getLength "double FormFactorCantellatedCube::getLength() const
";

%feature("docstring")  FormFactorCantellatedCube::getRemovedLength "double FormFactorCantellatedCube::getRemovedLength() const
";


// File: classFormFactorComponents.xml
%feature("docstring") FormFactorComponents "

Predefined form factors for functional tests.

C++ includes: FormFactorComponents.h
";

%feature("docstring")  FormFactorComponents::FormFactorComponents "FormFactorComponents::FormFactorComponents()
";


// File: classFormFactorCone.xml
%feature("docstring") FormFactorCone "

A conical frustum (cone truncated parallel to the base) with circular base.

C++ includes: FormFactorCone.h
";

%feature("docstring")  FormFactorCone::className "std::string FormFactorCone::className() const final
";

%feature("docstring")  FormFactorCone::FormFactorCone "FormFactorCone::FormFactorCone(std::vector< double > P)
";

%feature("docstring")  FormFactorCone::FormFactorCone "FormFactorCone::FormFactorCone(double radius, double height, double alpha)
";

%feature("docstring")  FormFactorCone::clone "FormFactorCone* FormFactorCone::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCone::accept "void FormFactorCone::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCone::getHeight "double FormFactorCone::getHeight() const
";

%feature("docstring")  FormFactorCone::getAlpha "double FormFactorCone::getAlpha() const
";

%feature("docstring")  FormFactorCone::getRadius "double FormFactorCone::getRadius() const
";

%feature("docstring")  FormFactorCone::radialExtension "double FormFactorCone::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorCone::evaluate_for_q "complex_t FormFactorCone::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorCone6.xml
%feature("docstring") FormFactorCone6 "

A frustum (truncated pyramid) with regular hexagonal base.

C++ includes: FormFactorCone6.h
";

%feature("docstring")  FormFactorCone6::className "std::string FormFactorCone6::className() const final
";

%feature("docstring")  FormFactorCone6::FormFactorCone6 "FormFactorCone6::FormFactorCone6(std::vector< double > P)
";

%feature("docstring")  FormFactorCone6::FormFactorCone6 "FormFactorCone6::FormFactorCone6(double base_edge, double height, double alpha)
";

%feature("docstring")  FormFactorCone6::clone "FormFactorCone6* FormFactorCone6::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCone6::accept "void FormFactorCone6::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCone6::getBaseEdge "double FormFactorCone6::getBaseEdge() const
";

%feature("docstring")  FormFactorCone6::getHeight "double FormFactorCone6::getHeight() const
";

%feature("docstring")  FormFactorCone6::getAlpha "double FormFactorCone6::getAlpha() const
";


// File: classFormFactorCoreShell.xml
%feature("docstring") FormFactorCoreShell "

Form Factor for a core shell particle.

Used by  ParticleCoreShell.

C++ includes: FormFactorCoreShell.h
";

%feature("docstring")  FormFactorCoreShell::className "std::string FormFactorCoreShell::className() const final
";

%feature("docstring")  FormFactorCoreShell::FormFactorCoreShell "FormFactorCoreShell::FormFactorCoreShell(IFormFactor *core, IFormFactor *shell)
";

%feature("docstring")  FormFactorCoreShell::~FormFactorCoreShell "FormFactorCoreShell::~FormFactorCoreShell() override
";

%feature("docstring")  FormFactorCoreShell::clone "FormFactorCoreShell * FormFactorCoreShell::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCoreShell::accept "void FormFactorCoreShell::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCoreShell::radialExtension "double FormFactorCoreShell::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorCoreShell::bottomZ "double FormFactorCoreShell::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorCoreShell::topZ "double FormFactorCoreShell::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorCoreShell::setAmbientMaterial "void FormFactorCoreShell::setAmbientMaterial(const Material &material) override

Passes the material in which this particle is embedded. 
";

%feature("docstring")  FormFactorCoreShell::theFF "complex_t FormFactorCoreShell::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  FormFactorCoreShell::thePolFF "Eigen::Matrix2cd FormFactorCoreShell::thePolFF(const WavevectorInfo &wavevectors) const override

Calculates and returns a polarized form factor calculation in DWBA. 
";


// File: classFormFactorCosineRippleBox.xml
%feature("docstring") FormFactorCosineRippleBox "

The form factor for a cosine ripple, with box profile in elongation direction.

C++ includes: FormFactorCosineRipple.h
";

%feature("docstring")  FormFactorCosineRippleBox::className "std::string FormFactorCosineRippleBox::className() const final
";

%feature("docstring")  FormFactorCosineRippleBox::FormFactorCosineRippleBox "FormFactorCosineRippleBox::FormFactorCosineRippleBox(std::vector< double > P)
";

%feature("docstring")  FormFactorCosineRippleBox::FormFactorCosineRippleBox "FormFactorCosineRippleBox::FormFactorCosineRippleBox(double length, double width, double height)
";

%feature("docstring")  FormFactorCosineRippleBox::clone "FormFactorCosineRippleBox * FormFactorCosineRippleBox::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCosineRippleBox::accept "void FormFactorCosineRippleBox::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorCosineRippleGauss.xml
%feature("docstring") FormFactorCosineRippleGauss "

The form factor for a cosine ripple, with Gaussian profile in elongation direction.

C++ includes: FormFactorCosineRipple.h
";

%feature("docstring")  FormFactorCosineRippleGauss::className "std::string FormFactorCosineRippleGauss::className() const final
";

%feature("docstring")  FormFactorCosineRippleGauss::FormFactorCosineRippleGauss "FormFactorCosineRippleGauss::FormFactorCosineRippleGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorCosineRippleGauss::FormFactorCosineRippleGauss "FormFactorCosineRippleGauss::FormFactorCosineRippleGauss(double length, double width, double height)
";

%feature("docstring")  FormFactorCosineRippleGauss::clone "FormFactorCosineRippleGauss * FormFactorCosineRippleGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCosineRippleGauss::accept "void FormFactorCosineRippleGauss::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorCosineRippleLorentz.xml
%feature("docstring") FormFactorCosineRippleLorentz "

The form factor for a cosine ripple, with Lorentz form factor in elongation direction.

C++ includes: FormFactorCosineRipple.h
";

%feature("docstring")  FormFactorCosineRippleLorentz::className "std::string FormFactorCosineRippleLorentz::className() const final
";

%feature("docstring")  FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz "FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz "FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz(double length, double width, double height)
";

%feature("docstring")  FormFactorCosineRippleLorentz::clone "FormFactorCosineRippleLorentz * FormFactorCosineRippleLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCosineRippleLorentz::accept "void FormFactorCosineRippleLorentz::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorCrystal.xml
%feature("docstring") FormFactorCrystal "

The form factor of a  MesoCrystal.

C++ includes: FormFactorCrystal.h
";

%feature("docstring")  FormFactorCrystal::className "std::string FormFactorCrystal::className() const final
";

%feature("docstring")  FormFactorCrystal::FormFactorCrystal "FormFactorCrystal::FormFactorCrystal(const Lattice3D &lattice, const IFormFactor &basis_form_factor, const IFormFactor &meso_form_factor, double position_variance=0.0)
";

%feature("docstring")  FormFactorCrystal::~FormFactorCrystal "FormFactorCrystal::~FormFactorCrystal() override
";

%feature("docstring")  FormFactorCrystal::clone "FormFactorCrystal* FormFactorCrystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCrystal::accept "void FormFactorCrystal::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCrystal::setAmbientMaterial "void FormFactorCrystal::setAmbientMaterial(const Material &material) override

Passes the material in which this particle is embedded. 
";

%feature("docstring")  FormFactorCrystal::volume "double FormFactorCrystal::volume() const override

Returns the total volume of the particle of this form factor's shape. 
";

%feature("docstring")  FormFactorCrystal::radialExtension "double FormFactorCrystal::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorCrystal::bottomZ "double FormFactorCrystal::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorCrystal::topZ "double FormFactorCrystal::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorCrystal::theFF "complex_t FormFactorCrystal::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  FormFactorCrystal::thePolFF "Eigen::Matrix2cd FormFactorCrystal::thePolFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for matrix interactions. 
";


// File: classFormFactorCuboctahedron.xml
%feature("docstring") FormFactorCuboctahedron "

A truncated bifrustum with quadratic base.

C++ includes: FormFactorCuboctahedron.h
";

%feature("docstring")  FormFactorCuboctahedron::className "std::string FormFactorCuboctahedron::className() const final
";

%feature("docstring")  FormFactorCuboctahedron::FormFactorCuboctahedron "FormFactorCuboctahedron::FormFactorCuboctahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorCuboctahedron::FormFactorCuboctahedron "FormFactorCuboctahedron::FormFactorCuboctahedron(double length, double height, double height_ratio, double alpha)
";

%feature("docstring")  FormFactorCuboctahedron::clone "FormFactorCuboctahedron* FormFactorCuboctahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCuboctahedron::accept "void FormFactorCuboctahedron::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCuboctahedron::getLength "double FormFactorCuboctahedron::getLength() const
";

%feature("docstring")  FormFactorCuboctahedron::getHeight "double FormFactorCuboctahedron::getHeight() const
";

%feature("docstring")  FormFactorCuboctahedron::getHeightRatio "double FormFactorCuboctahedron::getHeightRatio() const
";

%feature("docstring")  FormFactorCuboctahedron::getAlpha "double FormFactorCuboctahedron::getAlpha() const
";


// File: classFormFactorCylinder.xml
%feature("docstring") FormFactorCylinder "

A circular cylinder.

C++ includes: FormFactorCylinder.h
";

%feature("docstring")  FormFactorCylinder::className "std::string FormFactorCylinder::className() const final
";

%feature("docstring")  FormFactorCylinder::FormFactorCylinder "FormFactorCylinder::FormFactorCylinder(std::vector< double > P)
";

%feature("docstring")  FormFactorCylinder::FormFactorCylinder "FormFactorCylinder::FormFactorCylinder(double radius, double height)
";

%feature("docstring")  FormFactorCylinder::clone "FormFactorCylinder* FormFactorCylinder::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCylinder::accept "void FormFactorCylinder::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorCylinder::getHeight "double FormFactorCylinder::getHeight() const
";

%feature("docstring")  FormFactorCylinder::getRadius "double FormFactorCylinder::getRadius() const
";

%feature("docstring")  FormFactorCylinder::radialExtension "double FormFactorCylinder::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorCylinder::evaluate_for_q "complex_t FormFactorCylinder::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorDecoratorMaterial.xml
%feature("docstring") FormFactorDecoratorMaterial "

Decorates a scalar formfactor with the correct factor for the material's refractive index and that of its surrounding material.

C++ includes: FormFactorDecoratorMaterial.h
";

%feature("docstring")  FormFactorDecoratorMaterial::className "std::string FormFactorDecoratorMaterial::className() const final
";

%feature("docstring")  FormFactorDecoratorMaterial::FormFactorDecoratorMaterial "FormFactorDecoratorMaterial::FormFactorDecoratorMaterial(const IFormFactor &ff)
";

%feature("docstring")  FormFactorDecoratorMaterial::~FormFactorDecoratorMaterial "FormFactorDecoratorMaterial::~FormFactorDecoratorMaterial() override
";

%feature("docstring")  FormFactorDecoratorMaterial::clone "FormFactorDecoratorMaterial * FormFactorDecoratorMaterial::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorDecoratorMaterial::accept "void FormFactorDecoratorMaterial::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorDecoratorMaterial::setMaterial "void FormFactorDecoratorMaterial::setMaterial(const Material &material)

Sets the material of the scatterer. 
";

%feature("docstring")  FormFactorDecoratorMaterial::setAmbientMaterial "void FormFactorDecoratorMaterial::setAmbientMaterial(const Material &material) override

Sets the ambient material. 
";

%feature("docstring")  FormFactorDecoratorMaterial::theFF "complex_t FormFactorDecoratorMaterial::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  FormFactorDecoratorMaterial::thePolFF "Eigen::Matrix2cd FormFactorDecoratorMaterial::thePolFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for matrix interactions. 
";


// File: classFormFactorDecoratorPositionFactor.xml
%feature("docstring") FormFactorDecoratorPositionFactor "

Decorates a form factor with a position dependent phase factor.

C++ includes: FormFactorDecoratorPositionFactor.h
";

%feature("docstring")  FormFactorDecoratorPositionFactor::className "std::string FormFactorDecoratorPositionFactor::className() const final
";

%feature("docstring")  FormFactorDecoratorPositionFactor::FormFactorDecoratorPositionFactor "FormFactorDecoratorPositionFactor::FormFactorDecoratorPositionFactor(const IFormFactor &ff, const R3 &position)
";

%feature("docstring")  FormFactorDecoratorPositionFactor::clone "FormFactorDecoratorPositionFactor* FormFactorDecoratorPositionFactor::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorDecoratorPositionFactor::accept "void FormFactorDecoratorPositionFactor::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorDecoratorPositionFactor::bottomZ "double FormFactorDecoratorPositionFactor::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorDecoratorPositionFactor::topZ "double FormFactorDecoratorPositionFactor::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorDecoratorPositionFactor::theFF "complex_t FormFactorDecoratorPositionFactor::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  FormFactorDecoratorPositionFactor::thePolFF "Eigen::Matrix2cd FormFactorDecoratorPositionFactor::thePolFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for matrix interactions. 
";


// File: classFormFactorDecoratorRotation.xml
%feature("docstring") FormFactorDecoratorRotation "

Equips a form factor with a rotation.

C++ includes: FormFactorDecoratorRotation.h
";

%feature("docstring")  FormFactorDecoratorRotation::className "std::string FormFactorDecoratorRotation::className() const final
";

%feature("docstring")  FormFactorDecoratorRotation::FormFactorDecoratorRotation "FormFactorDecoratorRotation::FormFactorDecoratorRotation(const IFormFactor &ff, const IRotation &rotation)

Constructor, setting form factor and rotation. 
";

%feature("docstring")  FormFactorDecoratorRotation::clone "FormFactorDecoratorRotation * FormFactorDecoratorRotation::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorDecoratorRotation::accept "void FormFactorDecoratorRotation::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorDecoratorRotation::bottomZ "double FormFactorDecoratorRotation::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorDecoratorRotation::topZ "double FormFactorDecoratorRotation::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorDecoratorRotation::theFF "complex_t FormFactorDecoratorRotation::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  FormFactorDecoratorRotation::thePolFF "Eigen::Matrix2cd FormFactorDecoratorRotation::thePolFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for matrix interactions. 
";


// File: classFormFactorDodecahedron.xml
%feature("docstring") FormFactorDodecahedron "

A regular dodecahedron.

C++ includes: FormFactorDodecahedron.h
";

%feature("docstring")  FormFactorDodecahedron::className "std::string FormFactorDodecahedron::className() const final
";

%feature("docstring")  FormFactorDodecahedron::FormFactorDodecahedron "FormFactorDodecahedron::FormFactorDodecahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorDodecahedron::FormFactorDodecahedron "FormFactorDodecahedron::FormFactorDodecahedron(double edge)
";

%feature("docstring")  FormFactorDodecahedron::clone "FormFactorDodecahedron* FormFactorDodecahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorDodecahedron::accept "void FormFactorDodecahedron::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorDodecahedron::getEdge "double FormFactorDodecahedron::getEdge() const
";


// File: classFormFactorEllipsoidalCylinder.xml
%feature("docstring") FormFactorEllipsoidalCylinder "

A cylinder with elliptical base.

C++ includes: FormFactorEllipsoidalCylinder.h
";

%feature("docstring")  FormFactorEllipsoidalCylinder::className "std::string FormFactorEllipsoidalCylinder::className() const final
";

%feature("docstring")  FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder "FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder(std::vector< double > P)
";

%feature("docstring")  FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder "FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder(double radius_x, double radius_y, double height)
";

%feature("docstring")  FormFactorEllipsoidalCylinder::clone "FormFactorEllipsoidalCylinder* FormFactorEllipsoidalCylinder::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorEllipsoidalCylinder::accept "void FormFactorEllipsoidalCylinder::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorEllipsoidalCylinder::getRadiusX "double FormFactorEllipsoidalCylinder::getRadiusX() const
";

%feature("docstring")  FormFactorEllipsoidalCylinder::getRadiusY "double FormFactorEllipsoidalCylinder::getRadiusY() const
";

%feature("docstring")  FormFactorEllipsoidalCylinder::getHeight "double FormFactorEllipsoidalCylinder::getHeight() const
";

%feature("docstring")  FormFactorEllipsoidalCylinder::radialExtension "double FormFactorEllipsoidalCylinder::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorEllipsoidalCylinder::evaluate_for_q "complex_t FormFactorEllipsoidalCylinder::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorFullSphere.xml
%feature("docstring") FormFactorFullSphere "

A full sphere.

C++ includes: FormFactorFullSphere.h
";

%feature("docstring")  FormFactorFullSphere::className "std::string FormFactorFullSphere::className() const final
";

%feature("docstring")  FormFactorFullSphere::FormFactorFullSphere "FormFactorFullSphere::FormFactorFullSphere(std::vector< double > P, bool position_at_center=false)
";

%feature("docstring")  FormFactorFullSphere::FormFactorFullSphere "FormFactorFullSphere::FormFactorFullSphere(double radius, bool position_at_center=false)
";

%feature("docstring")  FormFactorFullSphere::clone "FormFactorFullSphere* FormFactorFullSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorFullSphere::accept "void FormFactorFullSphere::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorFullSphere::getRadius "double FormFactorFullSphere::getRadius() const
";

%feature("docstring")  FormFactorFullSphere::radialExtension "double FormFactorFullSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorFullSphere::bottomZ "double FormFactorFullSphere::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorFullSphere::topZ "double FormFactorFullSphere::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorFullSphere::evaluate_for_q "complex_t FormFactorFullSphere::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorFullSpheroid.xml
%feature("docstring") FormFactorFullSpheroid "

A full spheroid (an ellipsoid with two equal axes, hence with circular cross section)

C++ includes: FormFactorFullSpheroid.h
";

%feature("docstring")  FormFactorFullSpheroid::className "std::string FormFactorFullSpheroid::className() const final
";

%feature("docstring")  FormFactorFullSpheroid::FormFactorFullSpheroid "FormFactorFullSpheroid::FormFactorFullSpheroid(std::vector< double > P)
";

%feature("docstring")  FormFactorFullSpheroid::FormFactorFullSpheroid "FormFactorFullSpheroid::FormFactorFullSpheroid(double radius, double height)
";

%feature("docstring")  FormFactorFullSpheroid::clone "FormFactorFullSpheroid* FormFactorFullSpheroid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorFullSpheroid::accept "void FormFactorFullSpheroid::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorFullSpheroid::getHeight "double FormFactorFullSpheroid::getHeight() const
";

%feature("docstring")  FormFactorFullSpheroid::getRadius "double FormFactorFullSpheroid::getRadius() const
";

%feature("docstring")  FormFactorFullSpheroid::radialExtension "double FormFactorFullSpheroid::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorFullSpheroid::evaluate_for_q "complex_t FormFactorFullSpheroid::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorGaussSphere.xml
%feature("docstring") FormFactorGaussSphere "

The form factor of a Gaussian sphere.

C++ includes: FormFactorGauss.h
";

%feature("docstring")  FormFactorGaussSphere::className "std::string FormFactorGaussSphere::className() const final
";

%feature("docstring")  FormFactorGaussSphere::FormFactorGaussSphere "FormFactorGaussSphere::FormFactorGaussSphere(std::vector< double > P)
";

%feature("docstring")  FormFactorGaussSphere::FormFactorGaussSphere "FormFactorGaussSphere::FormFactorGaussSphere(double mean_radius)
";

%feature("docstring")  FormFactorGaussSphere::clone "FormFactorGaussSphere* FormFactorGaussSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorGaussSphere::accept "void FormFactorGaussSphere::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorGaussSphere::getMeanRadius "double FormFactorGaussSphere::getMeanRadius() const
";

%feature("docstring")  FormFactorGaussSphere::radialExtension "double FormFactorGaussSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorGaussSphere::evaluate_for_q "complex_t FormFactorGaussSphere::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorHemiEllipsoid.xml
%feature("docstring") FormFactorHemiEllipsoid "

An hemi ellipsoid, obtained by truncating a full ellipsoid in the middle plane spanned by two principal axes.

C++ includes: FormFactorHemiEllipsoid.h
";

%feature("docstring")  FormFactorHemiEllipsoid::className "std::string FormFactorHemiEllipsoid::className() const final
";

%feature("docstring")  FormFactorHemiEllipsoid::FormFactorHemiEllipsoid "FormFactorHemiEllipsoid::FormFactorHemiEllipsoid(std::vector< double > P)
";

%feature("docstring")  FormFactorHemiEllipsoid::FormFactorHemiEllipsoid "FormFactorHemiEllipsoid::FormFactorHemiEllipsoid(double radius_x, double radius_y, double height)
";

%feature("docstring")  FormFactorHemiEllipsoid::~FormFactorHemiEllipsoid "FormFactorHemiEllipsoid::~FormFactorHemiEllipsoid() override=default
";

%feature("docstring")  FormFactorHemiEllipsoid::clone "FormFactorHemiEllipsoid* FormFactorHemiEllipsoid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorHemiEllipsoid::accept "void FormFactorHemiEllipsoid::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorHemiEllipsoid::getHeight "double FormFactorHemiEllipsoid::getHeight() const
";

%feature("docstring")  FormFactorHemiEllipsoid::getRadiusX "double FormFactorHemiEllipsoid::getRadiusX() const
";

%feature("docstring")  FormFactorHemiEllipsoid::getRadiusY "double FormFactorHemiEllipsoid::getRadiusY() const
";

%feature("docstring")  FormFactorHemiEllipsoid::radialExtension "double FormFactorHemiEllipsoid::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorHemiEllipsoid::evaluate_for_q "complex_t FormFactorHemiEllipsoid::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorHollowSphere.xml
%feature("docstring") FormFactorHollowSphere "

Integrated full sphere form factor over a uniform distribution of radii.

C++ includes: FormFactorHollowSphere.h
";

%feature("docstring")  FormFactorHollowSphere::className "std::string FormFactorHollowSphere::className() const final
";

%feature("docstring")  FormFactorHollowSphere::FormFactorHollowSphere "FormFactorHollowSphere::FormFactorHollowSphere(std::vector< double > P)
";

%feature("docstring")  FormFactorHollowSphere::FormFactorHollowSphere "FormFactorHollowSphere::FormFactorHollowSphere(double mean, double full_width)
";

%feature("docstring")  FormFactorHollowSphere::clone "FormFactorHollowSphere* FormFactorHollowSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorHollowSphere::accept "void FormFactorHollowSphere::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorHollowSphere::radialExtension "double FormFactorHollowSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorHollowSphere::evaluate_for_q "complex_t FormFactorHollowSphere::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorIcosahedron.xml
%feature("docstring") FormFactorIcosahedron "

A regular icosahedron.

C++ includes: FormFactorIcosahedron.h
";

%feature("docstring")  FormFactorIcosahedron::className "std::string FormFactorIcosahedron::className() const final
";

%feature("docstring")  FormFactorIcosahedron::FormFactorIcosahedron "FormFactorIcosahedron::FormFactorIcosahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorIcosahedron::FormFactorIcosahedron "FormFactorIcosahedron::FormFactorIcosahedron(double edge)
";

%feature("docstring")  FormFactorIcosahedron::clone "FormFactorIcosahedron* FormFactorIcosahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorIcosahedron::accept "void FormFactorIcosahedron::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorIcosahedron::getEdge "double FormFactorIcosahedron::getEdge() const
";


// File: classFormFactorLongBoxGauss.xml
%feature("docstring") FormFactorLongBoxGauss "

The form factor for a long rectangular box.

C++ includes: FormFactorLongBoxGauss.h
";

%feature("docstring")  FormFactorLongBoxGauss::className "std::string FormFactorLongBoxGauss::className() const final
";

%feature("docstring")  FormFactorLongBoxGauss::FormFactorLongBoxGauss "FormFactorLongBoxGauss::FormFactorLongBoxGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorLongBoxGauss::FormFactorLongBoxGauss "FormFactorLongBoxGauss::FormFactorLongBoxGauss(double length, double width, double height)
";

%feature("docstring")  FormFactorLongBoxGauss::clone "FormFactorLongBoxGauss* FormFactorLongBoxGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorLongBoxGauss::accept "void FormFactorLongBoxGauss::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorLongBoxGauss::getLength "double FormFactorLongBoxGauss::getLength() const
";

%feature("docstring")  FormFactorLongBoxGauss::getHeight "double FormFactorLongBoxGauss::getHeight() const
";

%feature("docstring")  FormFactorLongBoxGauss::getWidth "double FormFactorLongBoxGauss::getWidth() const
";

%feature("docstring")  FormFactorLongBoxGauss::radialExtension "double FormFactorLongBoxGauss::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorLongBoxGauss::evaluate_for_q "complex_t FormFactorLongBoxGauss::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorLongBoxLorentz.xml
%feature("docstring") FormFactorLongBoxLorentz "

The form factor for a long rectangular box.

C++ includes: FormFactorLongBoxLorentz.h
";

%feature("docstring")  FormFactorLongBoxLorentz::className "std::string FormFactorLongBoxLorentz::className() const final
";

%feature("docstring")  FormFactorLongBoxLorentz::FormFactorLongBoxLorentz "FormFactorLongBoxLorentz::FormFactorLongBoxLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorLongBoxLorentz::FormFactorLongBoxLorentz "FormFactorLongBoxLorentz::FormFactorLongBoxLorentz(double length, double width, double height)
";

%feature("docstring")  FormFactorLongBoxLorentz::clone "FormFactorLongBoxLorentz* FormFactorLongBoxLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorLongBoxLorentz::accept "void FormFactorLongBoxLorentz::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorLongBoxLorentz::getLength "double FormFactorLongBoxLorentz::getLength() const
";

%feature("docstring")  FormFactorLongBoxLorentz::getHeight "double FormFactorLongBoxLorentz::getHeight() const
";

%feature("docstring")  FormFactorLongBoxLorentz::getWidth "double FormFactorLongBoxLorentz::getWidth() const
";

%feature("docstring")  FormFactorLongBoxLorentz::radialExtension "double FormFactorLongBoxLorentz::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorLongBoxLorentz::evaluate_for_q "complex_t FormFactorLongBoxLorentz::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorPrism3.xml
%feature("docstring") FormFactorPrism3 "

A prism based on an equilateral triangle.

C++ includes: FormFactorPrism3.h
";

%feature("docstring")  FormFactorPrism3::className "std::string FormFactorPrism3::className() const final
";

%feature("docstring")  FormFactorPrism3::FormFactorPrism3 "FormFactorPrism3::FormFactorPrism3(std::vector< double > P)
";

%feature("docstring")  FormFactorPrism3::FormFactorPrism3 "FormFactorPrism3::FormFactorPrism3(double base_edge, double height)
";

%feature("docstring")  FormFactorPrism3::clone "FormFactorPrism3* FormFactorPrism3::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPrism3::accept "void FormFactorPrism3::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorPrism3::getBaseEdge "double FormFactorPrism3::getBaseEdge() const
";


// File: classFormFactorPrism6.xml
%feature("docstring") FormFactorPrism6 "

A prism based on a regular hexagonal.

C++ includes: FormFactorPrism6.h
";

%feature("docstring")  FormFactorPrism6::className "std::string FormFactorPrism6::className() const final
";

%feature("docstring")  FormFactorPrism6::FormFactorPrism6 "FormFactorPrism6::FormFactorPrism6(std::vector< double > P)
";

%feature("docstring")  FormFactorPrism6::FormFactorPrism6 "FormFactorPrism6::FormFactorPrism6(double base_edge, double height)
";

%feature("docstring")  FormFactorPrism6::clone "FormFactorPrism6* FormFactorPrism6::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPrism6::accept "void FormFactorPrism6::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorPrism6::getBaseEdge "double FormFactorPrism6::getBaseEdge() const
";


// File: classFormFactorPyramid.xml
%feature("docstring") FormFactorPyramid "

A frustum with a quadratic base.

C++ includes: FormFactorPyramid.h
";

%feature("docstring")  FormFactorPyramid::className "std::string FormFactorPyramid::className() const final
";

%feature("docstring")  FormFactorPyramid::FormFactorPyramid "FormFactorPyramid::FormFactorPyramid(std::vector< double > P)
";

%feature("docstring")  FormFactorPyramid::FormFactorPyramid "FormFactorPyramid::FormFactorPyramid(double base_edge, double height, double alpha)
";

%feature("docstring")  FormFactorPyramid::clone "FormFactorPyramid* FormFactorPyramid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPyramid::accept "void FormFactorPyramid::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorPyramid::getHeight "double FormFactorPyramid::getHeight() const
";

%feature("docstring")  FormFactorPyramid::getBaseEdge "double FormFactorPyramid::getBaseEdge() const
";

%feature("docstring")  FormFactorPyramid::getAlpha "double FormFactorPyramid::getAlpha() const
";


// File: classFormFactorSawtoothRippleBox.xml
%feature("docstring") FormFactorSawtoothRippleBox "

The form factor for a cosine ripple, with box profile in elongation direction.

C++ includes: FormFactorSawtoothRipple.h
";

%feature("docstring")  FormFactorSawtoothRippleBox::className "std::string FormFactorSawtoothRippleBox::className() const final
";

%feature("docstring")  FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox "FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox(std::vector< double > P)
";

%feature("docstring")  FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox "FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox(double length, double width, double height, double asymmetry)
";

%feature("docstring")  FormFactorSawtoothRippleBox::clone "FormFactorSawtoothRippleBox * FormFactorSawtoothRippleBox::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSawtoothRippleBox::accept "void FormFactorSawtoothRippleBox::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorSawtoothRippleGauss.xml
%feature("docstring") FormFactorSawtoothRippleGauss "

The form factor for a cosine ripple, with Gaussian profile in elongation direction.

C++ includes: FormFactorSawtoothRipple.h
";

%feature("docstring")  FormFactorSawtoothRippleGauss::className "std::string FormFactorSawtoothRippleGauss::className() const final
";

%feature("docstring")  FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss "FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss "FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss(double length, double width, double height, double asymmetry)
";

%feature("docstring")  FormFactorSawtoothRippleGauss::clone "FormFactorSawtoothRippleGauss * FormFactorSawtoothRippleGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSawtoothRippleGauss::accept "void FormFactorSawtoothRippleGauss::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorSawtoothRippleLorentz.xml
%feature("docstring") FormFactorSawtoothRippleLorentz "

The form factor for a cosine ripple, with Lorentz form factor in elongation direction.

C++ includes: FormFactorSawtoothRipple.h
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::className "std::string FormFactorSawtoothRippleLorentz::className() const final
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz "FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz "FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz(double length, double width, double height, double asymmetry)
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::clone "FormFactorSawtoothRippleLorentz * FormFactorSawtoothRippleLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::accept "void FormFactorSawtoothRippleLorentz::accept(INodeVisitor *visitor) const override
";


// File: classFormFactorSphereGaussianRadius.xml
%feature("docstring") FormFactorSphereGaussianRadius "

A sphere with gaussian radius distribution.

C++ includes: FormFactorSphereGaussianRadius.h
";

%feature("docstring")  FormFactorSphereGaussianRadius::className "std::string FormFactorSphereGaussianRadius::className() const final
";

%feature("docstring")  FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius "FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius(std::vector< double > P)
";

%feature("docstring")  FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius "FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius(double mean, double sigma)
";

%feature("docstring")  FormFactorSphereGaussianRadius::clone "FormFactorSphereGaussianRadius* FormFactorSphereGaussianRadius::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSphereGaussianRadius::accept "void FormFactorSphereGaussianRadius::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorSphereGaussianRadius::radialExtension "double FormFactorSphereGaussianRadius::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorSphereGaussianRadius::evaluate_for_q "complex_t FormFactorSphereGaussianRadius::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorSphereLogNormalRadius.xml
%feature("docstring") FormFactorSphereLogNormalRadius "

A sphere with log normal radius distribution.

C++ includes: FormFactorSphereLogNormalRadius.h
";

%feature("docstring")  FormFactorSphereLogNormalRadius::className "std::string FormFactorSphereLogNormalRadius::className() const final
";

%feature("docstring")  FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius "FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius(std::vector< double > P, size_t n_samples=0)
";

%feature("docstring")  FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius "FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius(double mean, double scale_param, size_t n_samples)
";

%feature("docstring")  FormFactorSphereLogNormalRadius::clone "FormFactorSphereLogNormalRadius * FormFactorSphereLogNormalRadius::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSphereLogNormalRadius::accept "void FormFactorSphereLogNormalRadius::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorSphereLogNormalRadius::radialExtension "double FormFactorSphereLogNormalRadius::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorSphereLogNormalRadius::evaluate_for_q "complex_t FormFactorSphereLogNormalRadius::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";

%feature("docstring")  FormFactorSphereLogNormalRadius::pythonConstructor "std::string FormFactorSphereLogNormalRadius::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classFormFactorTetrahedron.xml
%feature("docstring") FormFactorTetrahedron "

A frustum with equilateral trigonal base.

C++ includes: FormFactorTetrahedron.h
";

%feature("docstring")  FormFactorTetrahedron::className "std::string FormFactorTetrahedron::className() const final
";

%feature("docstring")  FormFactorTetrahedron::FormFactorTetrahedron "FormFactorTetrahedron::FormFactorTetrahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorTetrahedron::FormFactorTetrahedron "FormFactorTetrahedron::FormFactorTetrahedron(double base_edge, double height, double alpha)
";

%feature("docstring")  FormFactorTetrahedron::clone "FormFactorTetrahedron* FormFactorTetrahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTetrahedron::accept "void FormFactorTetrahedron::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorTetrahedron::getBaseEdge "double FormFactorTetrahedron::getBaseEdge() const
";

%feature("docstring")  FormFactorTetrahedron::getHeight "double FormFactorTetrahedron::getHeight() const
";

%feature("docstring")  FormFactorTetrahedron::getAlpha "double FormFactorTetrahedron::getAlpha() const
";


// File: classFormFactorTruncatedCube.xml
%feature("docstring") FormFactorTruncatedCube "

A cube, with tetrahedral truncation of all corners

C++ includes: FormFactorTruncatedCube.h
";

%feature("docstring")  FormFactorTruncatedCube::className "std::string FormFactorTruncatedCube::className() const final
";

%feature("docstring")  FormFactorTruncatedCube::FormFactorTruncatedCube "FormFactorTruncatedCube::FormFactorTruncatedCube(std::vector< double > P)
";

%feature("docstring")  FormFactorTruncatedCube::FormFactorTruncatedCube "FormFactorTruncatedCube::FormFactorTruncatedCube(double length, double removed_length)
";

%feature("docstring")  FormFactorTruncatedCube::clone "FormFactorTruncatedCube* FormFactorTruncatedCube::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTruncatedCube::accept "void FormFactorTruncatedCube::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorTruncatedCube::getLength "double FormFactorTruncatedCube::getLength() const
";

%feature("docstring")  FormFactorTruncatedCube::getRemovedLength "double FormFactorTruncatedCube::getRemovedLength() const
";


// File: classFormFactorTruncatedSphere.xml
%feature("docstring") FormFactorTruncatedSphere "

A truncated Sphere.

C++ includes: FormFactorTruncatedSphere.h
";

%feature("docstring")  FormFactorTruncatedSphere::className "std::string FormFactorTruncatedSphere::className() const final
";

%feature("docstring")  FormFactorTruncatedSphere::FormFactorTruncatedSphere "FormFactorTruncatedSphere::FormFactorTruncatedSphere(std::vector< double > P)
";

%feature("docstring")  FormFactorTruncatedSphere::FormFactorTruncatedSphere "FormFactorTruncatedSphere::FormFactorTruncatedSphere(double radius, double height, double dh)
";

%feature("docstring")  FormFactorTruncatedSphere::clone "FormFactorTruncatedSphere* FormFactorTruncatedSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTruncatedSphere::accept "void FormFactorTruncatedSphere::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorTruncatedSphere::getHeight "double FormFactorTruncatedSphere::getHeight() const
";

%feature("docstring")  FormFactorTruncatedSphere::getRadius "double FormFactorTruncatedSphere::getRadius() const
";

%feature("docstring")  FormFactorTruncatedSphere::getRemovedTop "double FormFactorTruncatedSphere::getRemovedTop() const
";

%feature("docstring")  FormFactorTruncatedSphere::radialExtension "double FormFactorTruncatedSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorTruncatedSphere::evaluate_for_q "complex_t FormFactorTruncatedSphere::evaluate_for_q(C3 q) const override

Complex form factor. 
";


// File: classFormFactorTruncatedSpheroid.xml
%feature("docstring") FormFactorTruncatedSpheroid "

A truncated spheroid. An ellipsoid with two equal axis, truncated by a plane perpendicular to the third axis.

C++ includes: FormFactorTruncatedSpheroid.h
";

%feature("docstring")  FormFactorTruncatedSpheroid::className "std::string FormFactorTruncatedSpheroid::className() const final
";

%feature("docstring")  FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid "FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid(std::vector< double > P)
";

%feature("docstring")  FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid "FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid(double radius, double height, double height_flattening, double dh)
";

%feature("docstring")  FormFactorTruncatedSpheroid::clone "FormFactorTruncatedSpheroid* FormFactorTruncatedSpheroid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTruncatedSpheroid::accept "void FormFactorTruncatedSpheroid::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorTruncatedSpheroid::getRadius "double FormFactorTruncatedSpheroid::getRadius() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::getHeight "double FormFactorTruncatedSpheroid::getHeight() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::getHeightFlattening "double FormFactorTruncatedSpheroid::getHeightFlattening() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::getRemovedTop "double FormFactorTruncatedSpheroid::getRemovedTop() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::radialExtension "double FormFactorTruncatedSpheroid::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorTruncatedSpheroid::evaluate_for_q "complex_t FormFactorTruncatedSpheroid::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classFormFactorWeighted.xml
%feature("docstring") FormFactorWeighted "

Coherent sum of different scalar  IFormFactors with different weights.

Used by  ParticleComposition. If same particles are at different positions, then consider FormFactorDecoratorMultiPositionFactor (restore from commit 0500a26de76).

C++ includes: FormFactorWeighted.h
";

%feature("docstring")  FormFactorWeighted::className "std::string FormFactorWeighted::className() const final
";

%feature("docstring")  FormFactorWeighted::FormFactorWeighted "FormFactorWeighted::FormFactorWeighted()=default
";

%feature("docstring")  FormFactorWeighted::~FormFactorWeighted "FormFactorWeighted::~FormFactorWeighted() override
";

%feature("docstring")  FormFactorWeighted::clone "FormFactorWeighted * FormFactorWeighted::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorWeighted::accept "void FormFactorWeighted::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FormFactorWeighted::radialExtension "double FormFactorWeighted::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorWeighted::bottomZ "double FormFactorWeighted::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorWeighted::topZ "double FormFactorWeighted::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  FormFactorWeighted::addFormFactor "void FormFactorWeighted::addFormFactor(const IFormFactor &form_factor, double weight=1.0)
";

%feature("docstring")  FormFactorWeighted::setAmbientMaterial "void FormFactorWeighted::setAmbientMaterial(const Material &material) override

Passes the material in which this particle is embedded. 
";

%feature("docstring")  FormFactorWeighted::theFF "complex_t FormFactorWeighted::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  FormFactorWeighted::thePolFF "Eigen::Matrix2cd FormFactorWeighted::thePolFF(const WavevectorInfo &wavevectors) const override

Calculates and returns a polarized form factor calculation in DWBA. 
";


// File: classFTDecayFunction1DCauchy.xml
%feature("docstring") FTDecayFunction1DCauchy "

One-dimensional Cauchy decay function in reciprocal space; corresponds to exp(-|x|/decay_length) in real space.

C++ includes: FTDecay1D.h
";

%feature("docstring")  FTDecayFunction1DCauchy::className "std::string FTDecayFunction1DCauchy::className() const final
";

%feature("docstring")  FTDecayFunction1DCauchy::FTDecayFunction1DCauchy "FTDecayFunction1DCauchy::FTDecayFunction1DCauchy(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction1DCauchy::FTDecayFunction1DCauchy "FTDecayFunction1DCauchy::FTDecayFunction1DCauchy(double decay_length)
";

%feature("docstring")  FTDecayFunction1DCauchy::clone "FTDecayFunction1DCauchy * FTDecayFunction1DCauchy::clone() const override
";

%feature("docstring")  FTDecayFunction1DCauchy::accept "void FTDecayFunction1DCauchy::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction1DCauchy::evaluate "double FTDecayFunction1DCauchy::evaluate(double q) const override
";


// File: classFTDecayFunction1DGauss.xml
%feature("docstring") FTDecayFunction1DGauss "

One-dimensional Gauss decay function in reciprocal space; corresponds to exp[-x^2/(2*decay_length^2)] in real space.

C++ includes: FTDecay1D.h
";

%feature("docstring")  FTDecayFunction1DGauss::className "std::string FTDecayFunction1DGauss::className() const final
";

%feature("docstring")  FTDecayFunction1DGauss::FTDecayFunction1DGauss "FTDecayFunction1DGauss::FTDecayFunction1DGauss(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction1DGauss::FTDecayFunction1DGauss "FTDecayFunction1DGauss::FTDecayFunction1DGauss(double decay_length)
";

%feature("docstring")  FTDecayFunction1DGauss::clone "FTDecayFunction1DGauss * FTDecayFunction1DGauss::clone() const override
";

%feature("docstring")  FTDecayFunction1DGauss::accept "void FTDecayFunction1DGauss::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction1DGauss::evaluate "double FTDecayFunction1DGauss::evaluate(double q) const override
";


// File: classFTDecayFunction1DTriangle.xml
%feature("docstring") FTDecayFunction1DTriangle "

One-dimensional triangle decay function in reciprocal space; corresponds to 1-|x|/decay_length if |x|<decay_length (and 0 otherwise) in real space.

C++ includes: FTDecay1D.h
";

%feature("docstring")  FTDecayFunction1DTriangle::className "std::string FTDecayFunction1DTriangle::className() const final
";

%feature("docstring")  FTDecayFunction1DTriangle::FTDecayFunction1DTriangle "FTDecayFunction1DTriangle::FTDecayFunction1DTriangle(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction1DTriangle::FTDecayFunction1DTriangle "FTDecayFunction1DTriangle::FTDecayFunction1DTriangle(double decay_length)
";

%feature("docstring")  FTDecayFunction1DTriangle::clone "FTDecayFunction1DTriangle * FTDecayFunction1DTriangle::clone() const override
";

%feature("docstring")  FTDecayFunction1DTriangle::accept "void FTDecayFunction1DTriangle::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction1DTriangle::evaluate "double FTDecayFunction1DTriangle::evaluate(double q) const override
";


// File: classFTDecayFunction1DVoigt.xml
%feature("docstring") FTDecayFunction1DVoigt "

One-dimensional pseudo-Voigt decay function in reciprocal space; corresponds to eta*Gauss + (1-eta)*Cauchy.

C++ includes: FTDecay1D.h
";

%feature("docstring")  FTDecayFunction1DVoigt::className "std::string FTDecayFunction1DVoigt::className() const final
";

%feature("docstring")  FTDecayFunction1DVoigt::FTDecayFunction1DVoigt "FTDecayFunction1DVoigt::FTDecayFunction1DVoigt(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction1DVoigt::FTDecayFunction1DVoigt "FTDecayFunction1DVoigt::FTDecayFunction1DVoigt(double decay_length, double eta)
";

%feature("docstring")  FTDecayFunction1DVoigt::clone "FTDecayFunction1DVoigt * FTDecayFunction1DVoigt::clone() const override
";

%feature("docstring")  FTDecayFunction1DVoigt::accept "void FTDecayFunction1DVoigt::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction1DVoigt::evaluate "double FTDecayFunction1DVoigt::evaluate(double q) const override
";

%feature("docstring")  FTDecayFunction1DVoigt::eta "double FTDecayFunction1DVoigt::eta() const
";

%feature("docstring")  FTDecayFunction1DVoigt::pythonConstructor "std::string FTDecayFunction1DVoigt::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classFTDecayFunction2DCauchy.xml
%feature("docstring") FTDecayFunction2DCauchy "

Two-dimensional Cauchy decay function in reciprocal space; corresponds to exp(-r) in real space, with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: FTDecay2D.h
";

%feature("docstring")  FTDecayFunction2DCauchy::className "std::string FTDecayFunction2DCauchy::className() const final
";

%feature("docstring")  FTDecayFunction2DCauchy::FTDecayFunction2DCauchy "FTDecayFunction2DCauchy::FTDecayFunction2DCauchy(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction2DCauchy::FTDecayFunction2DCauchy "FTDecayFunction2DCauchy::FTDecayFunction2DCauchy(double decay_length_x, double decay_length_y, double gamma)
";

%feature("docstring")  FTDecayFunction2DCauchy::clone "FTDecayFunction2DCauchy * FTDecayFunction2DCauchy::clone() const override
";

%feature("docstring")  FTDecayFunction2DCauchy::accept "void FTDecayFunction2DCauchy::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction2DCauchy::evaluate "double FTDecayFunction2DCauchy::evaluate(double qx, double qy) const override

evaluate Fourier transformed decay function for q in X,Y coordinates 
";


// File: classFTDecayFunction2DGauss.xml
%feature("docstring") FTDecayFunction2DGauss "

Two-dimensional Gauss decay function in reciprocal space; corresponds to exp(-r^2/2) in real space, with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: FTDecay2D.h
";

%feature("docstring")  FTDecayFunction2DGauss::className "std::string FTDecayFunction2DGauss::className() const final
";

%feature("docstring")  FTDecayFunction2DGauss::FTDecayFunction2DGauss "FTDecayFunction2DGauss::FTDecayFunction2DGauss(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction2DGauss::FTDecayFunction2DGauss "FTDecayFunction2DGauss::FTDecayFunction2DGauss(double decay_length_x, double decay_length_y, double gamma)
";

%feature("docstring")  FTDecayFunction2DGauss::clone "FTDecayFunction2DGauss * FTDecayFunction2DGauss::clone() const override
";

%feature("docstring")  FTDecayFunction2DGauss::accept "void FTDecayFunction2DGauss::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction2DGauss::evaluate "double FTDecayFunction2DGauss::evaluate(double qx, double qy) const override

evaluate Fourier transformed decay function for q in X,Y coordinates 
";


// File: classFTDecayFunction2DVoigt.xml
%feature("docstring") FTDecayFunction2DVoigt "

Two-dimensional pseudo-Voigt decay function in reciprocal space; corresponds to eta*Gauss + (1-eta)*Cauchy.

C++ includes: FTDecay2D.h
";

%feature("docstring")  FTDecayFunction2DVoigt::className "std::string FTDecayFunction2DVoigt::className() const final
";

%feature("docstring")  FTDecayFunction2DVoigt::FTDecayFunction2DVoigt "FTDecayFunction2DVoigt::FTDecayFunction2DVoigt(std::vector< double > P)
";

%feature("docstring")  FTDecayFunction2DVoigt::FTDecayFunction2DVoigt "FTDecayFunction2DVoigt::FTDecayFunction2DVoigt(double decay_length_x, double decay_length_y, double gamma, double eta)
";

%feature("docstring")  FTDecayFunction2DVoigt::clone "FTDecayFunction2DVoigt * FTDecayFunction2DVoigt::clone() const override
";

%feature("docstring")  FTDecayFunction2DVoigt::accept "void FTDecayFunction2DVoigt::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDecayFunction2DVoigt::evaluate "double FTDecayFunction2DVoigt::evaluate(double qx, double qy) const override

evaluate Fourier transformed decay function for q in X,Y coordinates 
";

%feature("docstring")  FTDecayFunction2DVoigt::eta "double FTDecayFunction2DVoigt::eta() const
";

%feature("docstring")  FTDecayFunction2DVoigt::pythonConstructor "std::string FTDecayFunction2DVoigt::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classFTDistribution1DCauchy.xml
%feature("docstring") FTDistribution1DCauchy "

Exponential  IFTDistribution1D exp(-|omega*x|); its Fourier transform evaluate(q) is a Cauchy-Lorentzian starting at evaluate(0)=1.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  FTDistribution1DCauchy::className "std::string FTDistribution1DCauchy::className() const final
";

%feature("docstring")  FTDistribution1DCauchy::FTDistribution1DCauchy "FTDistribution1DCauchy::FTDistribution1DCauchy(std::vector< double > P)
";

%feature("docstring")  FTDistribution1DCauchy::FTDistribution1DCauchy "FTDistribution1DCauchy::FTDistribution1DCauchy(double omega)
";

%feature("docstring")  FTDistribution1DCauchy::clone "FTDistribution1DCauchy * FTDistribution1DCauchy::clone() const override
";

%feature("docstring")  FTDistribution1DCauchy::accept "void FTDistribution1DCauchy::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution1DCauchy::evaluate "double FTDistribution1DCauchy::evaluate(double q) const override

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  FTDistribution1DCauchy::qSecondDerivative "double FTDistribution1DCauchy::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  FTDistribution1DCauchy::createSampler "std::unique_ptr< IDistribution1DSampler > FTDistribution1DCauchy::createSampler() const override
";


// File: classFTDistribution1DCosine.xml
%feature("docstring") FTDistribution1DCosine "

IFTDistribution1D consisting of one cosine wave [1+cos(pi*x/omega) if |x|<omega, and 0 otherwise]; its Fourier transform evaluate(q) starts at evaluate(0)=1.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  FTDistribution1DCosine::className "std::string FTDistribution1DCosine::className() const final
";

%feature("docstring")  FTDistribution1DCosine::FTDistribution1DCosine "FTDistribution1DCosine::FTDistribution1DCosine(std::vector< double > P)
";

%feature("docstring")  FTDistribution1DCosine::FTDistribution1DCosine "FTDistribution1DCosine::FTDistribution1DCosine(double omega)
";

%feature("docstring")  FTDistribution1DCosine::clone "FTDistribution1DCosine * FTDistribution1DCosine::clone() const override
";

%feature("docstring")  FTDistribution1DCosine::accept "void FTDistribution1DCosine::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution1DCosine::evaluate "double FTDistribution1DCosine::evaluate(double q) const override

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  FTDistribution1DCosine::qSecondDerivative "double FTDistribution1DCosine::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  FTDistribution1DCosine::createSampler "std::unique_ptr< IDistribution1DSampler > FTDistribution1DCosine::createSampler() const override
";


// File: classFTDistribution1DGate.xml
%feature("docstring") FTDistribution1DGate "

Square gate  IFTDistribution1D; its Fourier transform evaluate(q) is a sinc function starting at evaluate(0)=1.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  FTDistribution1DGate::className "std::string FTDistribution1DGate::className() const final
";

%feature("docstring")  FTDistribution1DGate::FTDistribution1DGate "FTDistribution1DGate::FTDistribution1DGate(std::vector< double > P)
";

%feature("docstring")  FTDistribution1DGate::FTDistribution1DGate "FTDistribution1DGate::FTDistribution1DGate(double omega)
";

%feature("docstring")  FTDistribution1DGate::clone "FTDistribution1DGate * FTDistribution1DGate::clone() const override
";

%feature("docstring")  FTDistribution1DGate::accept "void FTDistribution1DGate::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution1DGate::evaluate "double FTDistribution1DGate::evaluate(double q) const override

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  FTDistribution1DGate::qSecondDerivative "double FTDistribution1DGate::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  FTDistribution1DGate::createSampler "std::unique_ptr< IDistribution1DSampler > FTDistribution1DGate::createSampler() const override
";


// File: classFTDistribution1DGauss.xml
%feature("docstring") FTDistribution1DGauss "

Gaussian  IFTDistribution1D; its Fourier transform evaluate(q) is a Gaussian starting at evaluate(0)=1.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  FTDistribution1DGauss::className "std::string FTDistribution1DGauss::className() const final
";

%feature("docstring")  FTDistribution1DGauss::FTDistribution1DGauss "FTDistribution1DGauss::FTDistribution1DGauss(std::vector< double > P)
";

%feature("docstring")  FTDistribution1DGauss::FTDistribution1DGauss "FTDistribution1DGauss::FTDistribution1DGauss(double omega)
";

%feature("docstring")  FTDistribution1DGauss::clone "FTDistribution1DGauss * FTDistribution1DGauss::clone() const override
";

%feature("docstring")  FTDistribution1DGauss::accept "void FTDistribution1DGauss::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution1DGauss::evaluate "double FTDistribution1DGauss::evaluate(double q) const override

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  FTDistribution1DGauss::qSecondDerivative "double FTDistribution1DGauss::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  FTDistribution1DGauss::createSampler "std::unique_ptr< IDistribution1DSampler > FTDistribution1DGauss::createSampler() const override
";


// File: classFTDistribution1DTriangle.xml
%feature("docstring") FTDistribution1DTriangle "

Triangle  IFTDistribution1D [1-|x|/omega if |x|<omega, and 0 otherwise]; its Fourier transform evaluate(q) is a squared sinc function starting at evaluate(0)=1.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  FTDistribution1DTriangle::className "std::string FTDistribution1DTriangle::className() const final
";

%feature("docstring")  FTDistribution1DTriangle::FTDistribution1DTriangle "FTDistribution1DTriangle::FTDistribution1DTriangle(std::vector< double > P)
";

%feature("docstring")  FTDistribution1DTriangle::FTDistribution1DTriangle "FTDistribution1DTriangle::FTDistribution1DTriangle(double omega)
";

%feature("docstring")  FTDistribution1DTriangle::clone "FTDistribution1DTriangle * FTDistribution1DTriangle::clone() const override
";

%feature("docstring")  FTDistribution1DTriangle::accept "void FTDistribution1DTriangle::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution1DTriangle::evaluate "double FTDistribution1DTriangle::evaluate(double q) const override

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  FTDistribution1DTriangle::qSecondDerivative "double FTDistribution1DTriangle::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  FTDistribution1DTriangle::createSampler "std::unique_ptr< IDistribution1DSampler > FTDistribution1DTriangle::createSampler() const override
";


// File: classFTDistribution1DVoigt.xml
%feature("docstring") FTDistribution1DVoigt "

IFTDistribution1D that provides a Fourier transform evaluate(q) in form of a pseudo-Voigt decay function eta*Gauss + (1-eta)*Cauchy, with both components starting at 1 for q=0.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  FTDistribution1DVoigt::className "std::string FTDistribution1DVoigt::className() const final
";

%feature("docstring")  FTDistribution1DVoigt::FTDistribution1DVoigt "FTDistribution1DVoigt::FTDistribution1DVoigt(std::vector< double > P)
";

%feature("docstring")  FTDistribution1DVoigt::FTDistribution1DVoigt "FTDistribution1DVoigt::FTDistribution1DVoigt(double omega, double eta)
";

%feature("docstring")  FTDistribution1DVoigt::clone "FTDistribution1DVoigt * FTDistribution1DVoigt::clone() const override
";

%feature("docstring")  FTDistribution1DVoigt::accept "void FTDistribution1DVoigt::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution1DVoigt::evaluate "double FTDistribution1DVoigt::evaluate(double q) const override

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  FTDistribution1DVoigt::eta "double FTDistribution1DVoigt::eta() const
";

%feature("docstring")  FTDistribution1DVoigt::qSecondDerivative "double FTDistribution1DVoigt::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  FTDistribution1DVoigt::createSampler "std::unique_ptr< IDistribution1DSampler > FTDistribution1DVoigt::createSampler() const override
";

%feature("docstring")  FTDistribution1DVoigt::pythonConstructor "std::string FTDistribution1DVoigt::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classFTDistribution2DCauchy.xml
%feature("docstring") FTDistribution2DCauchy "

Two-dimensional Cauchy distribution in Fourier space; corresponds to a normalized exp(-r) in real space, with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: FTDistributions2D.h
";

%feature("docstring")  FTDistribution2DCauchy::className "std::string FTDistribution2DCauchy::className() const final
";

%feature("docstring")  FTDistribution2DCauchy::FTDistribution2DCauchy "FTDistribution2DCauchy::FTDistribution2DCauchy(std::vector< double > P)
";

%feature("docstring")  FTDistribution2DCauchy::FTDistribution2DCauchy "FTDistribution2DCauchy::FTDistribution2DCauchy(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  FTDistribution2DCauchy::clone "FTDistribution2DCauchy * FTDistribution2DCauchy::clone() const override
";

%feature("docstring")  FTDistribution2DCauchy::accept "void FTDistribution2DCauchy::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution2DCauchy::evaluate "double FTDistribution2DCauchy::evaluate(double qx, double qy) const override

evaluate Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  FTDistribution2DCauchy::createSampler "std::unique_ptr< IDistribution2DSampler > FTDistribution2DCauchy::createSampler() const override
";


// File: classFTDistribution2DComponents.xml
%feature("docstring") FTDistribution2DComponents "

Predefined Fourier transformed distributions for functional tests.

C++ includes: FTDistribution2DComponents.h
";

%feature("docstring")  FTDistribution2DComponents::FTDistribution2DComponents "FTDistribution2DComponents::FTDistribution2DComponents()
";


// File: classFTDistribution2DCone.xml
%feature("docstring") FTDistribution2DCone "

Two-dimensional cone distribution in Fourier space; corresponds to 1-r if r<1 (and 0 otherwise) in real space with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: FTDistributions2D.h
";

%feature("docstring")  FTDistribution2DCone::className "std::string FTDistribution2DCone::className() const final
";

%feature("docstring")  FTDistribution2DCone::FTDistribution2DCone "FTDistribution2DCone::FTDistribution2DCone(std::vector< double > P)
";

%feature("docstring")  FTDistribution2DCone::FTDistribution2DCone "FTDistribution2DCone::FTDistribution2DCone(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  FTDistribution2DCone::clone "FTDistribution2DCone * FTDistribution2DCone::clone() const override
";

%feature("docstring")  FTDistribution2DCone::accept "void FTDistribution2DCone::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution2DCone::evaluate "double FTDistribution2DCone::evaluate(double qx, double qy) const override

evaluate Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  FTDistribution2DCone::createSampler "std::unique_ptr< IDistribution2DSampler > FTDistribution2DCone::createSampler() const override
";


// File: classFTDistribution2DGate.xml
%feature("docstring") FTDistribution2DGate "

Two-dimensional gate distribution in Fourier space; corresponds to normalized constant if r<1 (and 0 otherwise) in real space, with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: FTDistributions2D.h
";

%feature("docstring")  FTDistribution2DGate::className "std::string FTDistribution2DGate::className() const final
";

%feature("docstring")  FTDistribution2DGate::FTDistribution2DGate "FTDistribution2DGate::FTDistribution2DGate(std::vector< double > P)
";

%feature("docstring")  FTDistribution2DGate::FTDistribution2DGate "FTDistribution2DGate::FTDistribution2DGate(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  FTDistribution2DGate::clone "FTDistribution2DGate * FTDistribution2DGate::clone() const override
";

%feature("docstring")  FTDistribution2DGate::accept "void FTDistribution2DGate::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution2DGate::evaluate "double FTDistribution2DGate::evaluate(double qx, double qy) const override

evaluate Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  FTDistribution2DGate::createSampler "std::unique_ptr< IDistribution2DSampler > FTDistribution2DGate::createSampler() const override
";


// File: classFTDistribution2DGauss.xml
%feature("docstring") FTDistribution2DGauss "

Two-dimensional Gauss distribution in Fourier space; corresponds to normalized exp(-r^2/2) in real space with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: FTDistributions2D.h
";

%feature("docstring")  FTDistribution2DGauss::className "std::string FTDistribution2DGauss::className() const final
";

%feature("docstring")  FTDistribution2DGauss::FTDistribution2DGauss "FTDistribution2DGauss::FTDistribution2DGauss(std::vector< double > P)
";

%feature("docstring")  FTDistribution2DGauss::FTDistribution2DGauss "FTDistribution2DGauss::FTDistribution2DGauss(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  FTDistribution2DGauss::clone "FTDistribution2DGauss * FTDistribution2DGauss::clone() const override
";

%feature("docstring")  FTDistribution2DGauss::accept "void FTDistribution2DGauss::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution2DGauss::evaluate "double FTDistribution2DGauss::evaluate(double qx, double qy) const override

evaluate Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  FTDistribution2DGauss::createSampler "std::unique_ptr< IDistribution2DSampler > FTDistribution2DGauss::createSampler() const override
";


// File: classFTDistribution2DVoigt.xml
%feature("docstring") FTDistribution2DVoigt "

Two-dimensional Voigt distribution in Fourier space; corresponds to eta*Gauss + (1-eta)*Cauchy

C++ includes: FTDistributions2D.h
";

%feature("docstring")  FTDistribution2DVoigt::className "std::string FTDistribution2DVoigt::className() const final
";

%feature("docstring")  FTDistribution2DVoigt::FTDistribution2DVoigt "FTDistribution2DVoigt::FTDistribution2DVoigt(std::vector< double > P)
";

%feature("docstring")  FTDistribution2DVoigt::FTDistribution2DVoigt "FTDistribution2DVoigt::FTDistribution2DVoigt(double omega_x, double omega_y, double gamma, double eta)
";

%feature("docstring")  FTDistribution2DVoigt::clone "FTDistribution2DVoigt * FTDistribution2DVoigt::clone() const override
";

%feature("docstring")  FTDistribution2DVoigt::accept "void FTDistribution2DVoigt::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  FTDistribution2DVoigt::evaluate "double FTDistribution2DVoigt::evaluate(double qx, double qy) const override

evaluate Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  FTDistribution2DVoigt::eta "double FTDistribution2DVoigt::eta() const
";

%feature("docstring")  FTDistribution2DVoigt::createSampler "std::unique_ptr< IDistribution2DSampler > FTDistribution2DVoigt::createSampler() const override
";

%feature("docstring")  FTDistribution2DVoigt::pythonConstructor "std::string FTDistribution2DVoigt::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classGaussFisherPeakShape.xml
%feature("docstring") GaussFisherPeakShape "

A peak shape that is Gaussian in the radial direction and uses the Mises-Fisher distribution in the angular direction.

C++ includes: IPeakShape.h
";

%feature("docstring")  GaussFisherPeakShape::className "std::string GaussFisherPeakShape::className() const final
";

%feature("docstring")  GaussFisherPeakShape::GaussFisherPeakShape "GaussFisherPeakShape::GaussFisherPeakShape(double max_intensity, double radial_size, double kappa)
";

%feature("docstring")  GaussFisherPeakShape::~GaussFisherPeakShape "GaussFisherPeakShape::~GaussFisherPeakShape() override
";

%feature("docstring")  GaussFisherPeakShape::clone "GaussFisherPeakShape * GaussFisherPeakShape::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  GaussFisherPeakShape::accept "void GaussFisherPeakShape::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  GaussFisherPeakShape::evaluate "double GaussFisherPeakShape::evaluate(R3 q, R3 q_lattice_point) const override

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  GaussFisherPeakShape::angularDisorder "bool GaussFisherPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classHexagonalLattice2D.xml
%feature("docstring") HexagonalLattice2D "

A two-dimensional Bravais lattice with hexagonal symmetry.

C++ includes: Lattice2D.h
";

%feature("docstring")  HexagonalLattice2D::className "std::string HexagonalLattice2D::className() const final
";

%feature("docstring")  HexagonalLattice2D::HexagonalLattice2D "HexagonalLattice2D::HexagonalLattice2D(double length, double xi)
";

%feature("docstring")  HexagonalLattice2D::clone "HexagonalLattice2D * HexagonalLattice2D::clone() const override
";

%feature("docstring")  HexagonalLattice2D::accept "void HexagonalLattice2D::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  HexagonalLattice2D::length1 "double HexagonalLattice2D::length1() const override
";

%feature("docstring")  HexagonalLattice2D::length2 "double HexagonalLattice2D::length2() const override
";

%feature("docstring")  HexagonalLattice2D::latticeAngle "double HexagonalLattice2D::latticeAngle() const override
";

%feature("docstring")  HexagonalLattice2D::unitCellArea "double HexagonalLattice2D::unitCellArea() const override
";


// File: classIBornFF.xml
%feature("docstring") IBornFF "

Abstract base class for Born form factors.

In contrast to the generic  IFormFactor, a Born form factor does not depend on the incoming and outgoing wave vectors ki and kf, except through their difference, the scattering vector q=ki-kf.

C++ includes: IBornFF.h
";

%feature("docstring")  IBornFF::IBornFF "IBornFF::IBornFF()
";

%feature("docstring")  IBornFF::IBornFF "IBornFF::IBornFF(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IBornFF::~IBornFF "IBornFF::~IBornFF() override
";

%feature("docstring")  IBornFF::clone "IBornFF* IBornFF::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IBornFF::setAmbientMaterial "void IBornFF::setAmbientMaterial(const Material &) override

Passes the material in which this particle is embedded. 
";

%feature("docstring")  IBornFF::theFF "complex_t IBornFF::theFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  IBornFF::thePolFF "Eigen::Matrix2cd IBornFF::thePolFF(const WavevectorInfo &wavevectors) const override

Returns scattering amplitude for matrix interactions. 
";

%feature("docstring")  IBornFF::bottomZ "double IBornFF::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IBornFF::topZ "double IBornFF::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IBornFF::evaluate_for_q "virtual complex_t IBornFF::evaluate_for_q(C3 q) const =0

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classICosineRipple.xml
%feature("docstring") ICosineRipple "

Base class for form factors with a cosine ripple profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  ICosineRipple::ICosineRipple "ICosineRipple::ICosineRipple(const NodeMeta &meta, const std::vector< double > &PValues)
";


// File: classIdentityRotation.xml
%feature("docstring") IdentityRotation "

The identity rotation, which leaves everything in place.

C++ includes: Rotations.h
";

%feature("docstring")  IdentityRotation::className "std::string IdentityRotation::className() const final
";

%feature("docstring")  IdentityRotation::IdentityRotation "IdentityRotation::IdentityRotation()
";

%feature("docstring")  IdentityRotation::clone "IdentityRotation* IdentityRotation::clone() const override
";

%feature("docstring")  IdentityRotation::createInverse "IdentityRotation* IdentityRotation::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  IdentityRotation::accept "void IdentityRotation::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  IdentityRotation::getTransform3D "Transform3D IdentityRotation::getTransform3D() const override

Returns transformation. 
";

%feature("docstring")  IdentityRotation::isIdentity "bool IdentityRotation::isIdentity() const override

Returns true if rotation matrix is identity matrix (no rotations) 
";


// File: classIDistribution1DSampler.xml
%feature("docstring") IDistribution1DSampler "";

%feature("docstring")  IDistribution1DSampler::IDistribution1DSampler "IDistribution1DSampler::IDistribution1DSampler()=default
";

%feature("docstring")  IDistribution1DSampler::~IDistribution1DSampler "IDistribution1DSampler::~IDistribution1DSampler()
";

%feature("docstring")  IDistribution1DSampler::randomSample "virtual double IDistribution1DSampler::randomSample() const =0
";


// File: classIDistribution2DSampler.xml
%feature("docstring") IDistribution2DSampler "";

%feature("docstring")  IDistribution2DSampler::IDistribution2DSampler "IDistribution2DSampler::IDistribution2DSampler()=default
";

%feature("docstring")  IDistribution2DSampler::~IDistribution2DSampler "IDistribution2DSampler::~IDistribution2DSampler()
";

%feature("docstring")  IDistribution2DSampler::randomSample "virtual std::pair<double, double> IDistribution2DSampler::randomSample() const =0
";


// File: classIFormFactor.xml
%feature("docstring") IFormFactor "

Abstract base class for all form factors.

The actual form factor is returned by the complex valued function IFormFactor::evaluate, which depends on the incoming and outgoing wave vectors ki and kf. If it only depends on the scattering vector q=ki-kf, then it is a  IBornFF.

C++ includes: IFormFactor.h
";

%feature("docstring")  IFormFactor::~IFormFactor "IFormFactor::~IFormFactor() override=default
";

%feature("docstring")  IFormFactor::clone "IFormFactor* IFormFactor::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IFormFactor::shapeName "std::string IFormFactor::shapeName() const
";

%feature("docstring")  IFormFactor::setAmbientMaterial "virtual void IFormFactor::setAmbientMaterial(const Material &)=0

Passes the material in which this particle is embedded. 
";

%feature("docstring")  IFormFactor::theFF "virtual complex_t IFormFactor::theFF(const WavevectorInfo &wavevectors) const =0

Returns scattering amplitude for complex wavevectors ki, kf. 
";

%feature("docstring")  IFormFactor::createSlicedFormFactor "IFormFactor * IFormFactor::createSlicedFormFactor(ZLimits limits, const IRotation &rot, R3 translation) const

Creates a (possibly sliced) form factor with the given rotation and translation. 
";

%feature("docstring")  IFormFactor::thePolFF "Eigen::Matrix2cd IFormFactor::thePolFF(const WavevectorInfo &wavevectors) const

Returns scattering amplitude for matrix interactions. 
";

%feature("docstring")  IFormFactor::pythonConstructor "std::string IFormFactor::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";

%feature("docstring")  IFormFactor::volume "double IFormFactor::volume() const

Returns the total volume of the particle of this form factor's shape. 
";

%feature("docstring")  IFormFactor::radialExtension "virtual double IFormFactor::radialExtension() const =0

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IFormFactor::bottomZ "virtual double IFormFactor::bottomZ(const IRotation &rotation) const =0

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactor::topZ "virtual double IFormFactor::topZ(const IRotation &rotation) const =0

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";


// File: classIFormFactorDecorator.xml
%feature("docstring") IFormFactorDecorator "

Encapsulates another formfactor and adds extra functionality (a scalar factor, a position-dependent phase factor, ...).

This class is designed according to the Decorator Pattern. It inherits from  IFormFactor and has a member of type IFormFactor*.

C++ includes: IFormFactorDecorator.h
";

%feature("docstring")  IFormFactorDecorator::IFormFactorDecorator "IFormFactorDecorator::IFormFactorDecorator(const IFormFactor &ff)
";

%feature("docstring")  IFormFactorDecorator::~IFormFactorDecorator "IFormFactorDecorator::~IFormFactorDecorator() override
";

%feature("docstring")  IFormFactorDecorator::clone "IFormFactorDecorator* IFormFactorDecorator::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IFormFactorDecorator::setAmbientMaterial "void IFormFactorDecorator::setAmbientMaterial(const Material &material) override

Passes the material in which this particle is embedded. 
";

%feature("docstring")  IFormFactorDecorator::volume "double IFormFactorDecorator::volume() const override

Returns the total volume of the particle of this form factor's shape. 
";

%feature("docstring")  IFormFactorDecorator::radialExtension "double IFormFactorDecorator::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IFormFactorDecorator::bottomZ "double IFormFactorDecorator::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactorDecorator::topZ "double IFormFactorDecorator::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactorDecorator::getFormFactor "const IFormFactor* IFormFactorDecorator::getFormFactor() const
";


// File: classIFormFactorPolyhedron.xml
%feature("docstring") IFormFactorPolyhedron "

A polyhedron, for form factor computation.

C++ includes: IFormFactorPolyhedron.h
";

%feature("docstring")  IFormFactorPolyhedron::IFormFactorPolyhedron "IFormFactorPolyhedron::IFormFactorPolyhedron(const NodeMeta &meta, const std::vector< double > &PValues)

The mathematics implemented here is described in full detail in a paper by Joachim Wuttke, entitled \"Form factor (Fourier shape transform) of polygon and polyhedron.\" 
";

%feature("docstring")  IFormFactorPolyhedron::~IFormFactorPolyhedron "IFormFactorPolyhedron::~IFormFactorPolyhedron() override
";

%feature("docstring")  IFormFactorPolyhedron::bottomZ "double IFormFactorPolyhedron::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactorPolyhedron::topZ "double IFormFactorPolyhedron::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactorPolyhedron::evaluate_for_q "complex_t IFormFactorPolyhedron::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";

%feature("docstring")  IFormFactorPolyhedron::volume "double IFormFactorPolyhedron::volume() const override

Returns the total volume of the particle of this form factor's shape. 
";

%feature("docstring")  IFormFactorPolyhedron::radialExtension "double IFormFactorPolyhedron::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IFormFactorPolyhedron::assert_platonic "void IFormFactorPolyhedron::assert_platonic() const

Assertions for Platonic solid. 
";


// File: classIFormFactorPrism.xml
%feature("docstring") IFormFactorPrism "

A prism with a polygonal base, for form factor computation.

C++ includes: IFormFactorPrism.h
";

%feature("docstring")  IFormFactorPrism::IFormFactorPrism "IFormFactorPrism::IFormFactorPrism(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IFormFactorPrism::~IFormFactorPrism "IFormFactorPrism::~IFormFactorPrism() override
";

%feature("docstring")  IFormFactorPrism::bottomZ "double IFormFactorPrism::bottomZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactorPrism::topZ "double IFormFactorPrism::topZ(const IRotation &rotation) const override

Returns the z-coordinate of the lowest point in this shape after a given rotation. 
";

%feature("docstring")  IFormFactorPrism::evaluate_for_q "complex_t IFormFactorPrism::evaluate_for_q(C3 q) const override

Returns the form factor F(q) of this polyhedron, respecting the offset height/2. 
";

%feature("docstring")  IFormFactorPrism::volume "double IFormFactorPrism::volume() const override

Returns the volume of this prism. 
";

%feature("docstring")  IFormFactorPrism::radialExtension "double IFormFactorPrism::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IFormFactorPrism::getHeight "double IFormFactorPrism::getHeight() const
";


// File: classIFTDecayFunction1D.xml
%feature("docstring") IFTDecayFunction1D "

Interface for a one-dimensional decay function, with evaluate(q) returning the Fourier transform, normalized to  $\\\\int dq\\\\; {\\\\rm evaluate}(q) = 1$.

C++ includes: FTDecay1D.h
";

%feature("docstring")  IFTDecayFunction1D::IFTDecayFunction1D "IFTDecayFunction1D::IFTDecayFunction1D(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IFTDecayFunction1D::clone "IFTDecayFunction1D* IFTDecayFunction1D::clone() const override=0
";

%feature("docstring")  IFTDecayFunction1D::evaluate "virtual double IFTDecayFunction1D::evaluate(double q) const =0
";

%feature("docstring")  IFTDecayFunction1D::decayLength "double IFTDecayFunction1D::decayLength() const
";

%feature("docstring")  IFTDecayFunction1D::pythonConstructor "std::string IFTDecayFunction1D::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";


// File: classIFTDecayFunction2D.xml
%feature("docstring") IFTDecayFunction2D "

Interface for two-dimensional decay function in reciprocal space.

C++ includes: FTDecay2D.h
";

%feature("docstring")  IFTDecayFunction2D::IFTDecayFunction2D "IFTDecayFunction2D::IFTDecayFunction2D(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IFTDecayFunction2D::clone "IFTDecayFunction2D* IFTDecayFunction2D::clone() const override=0
";

%feature("docstring")  IFTDecayFunction2D::decayLengthX "double IFTDecayFunction2D::decayLengthX() const

get decay length in distribution's X-direction 
";

%feature("docstring")  IFTDecayFunction2D::decayLengthY "double IFTDecayFunction2D::decayLengthY() const

get decay length in distribution's Y-direction 
";

%feature("docstring")  IFTDecayFunction2D::gamma "double IFTDecayFunction2D::gamma() const

get angle between first lattice vector and X-axis of distribution (both in direct space) 
";

%feature("docstring")  IFTDecayFunction2D::evaluate "virtual double IFTDecayFunction2D::evaluate(double qx, double qy) const =0

evaluate Fourier transformed decay function for q in X,Y coordinates 
";

%feature("docstring")  IFTDecayFunction2D::boundingReciprocalLatticeCoordinates "std::pair< double, double > IFTDecayFunction2D::boundingReciprocalLatticeCoordinates(double qX, double qY, double a, double b, double alpha) const

transform back to a*, b* basis:

Calculates bounding values of reciprocal lattice coordinates that contain the centered rectangle with a corner defined by qX and qY 
";

%feature("docstring")  IFTDecayFunction2D::pythonConstructor "std::string IFTDecayFunction2D::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";


// File: classIFTDistribution1D.xml
%feature("docstring") IFTDistribution1D "

Interface for a one-dimensional distribution, with normalization adjusted so that the Fourier transform evaluate(q) is a decay function that starts at evaluate(0)=1.

C++ includes: FTDistributions1D.h
";

%feature("docstring")  IFTDistribution1D::IFTDistribution1D "IFTDistribution1D::IFTDistribution1D(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IFTDistribution1D::clone "IFTDistribution1D* IFTDistribution1D::clone() const override=0
";

%feature("docstring")  IFTDistribution1D::evaluate "virtual double IFTDistribution1D::evaluate(double q) const =0

Returns Fourier transform of this distribution; is a decay function starting at evaluate(0)=1. 
";

%feature("docstring")  IFTDistribution1D::omega "double IFTDistribution1D::omega() const
";

%feature("docstring")  IFTDistribution1D::qSecondDerivative "virtual double IFTDistribution1D::qSecondDerivative() const =0

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  IFTDistribution1D::createSampler "virtual std::unique_ptr<IDistribution1DSampler> IFTDistribution1D::createSampler() const =0
";

%feature("docstring")  IFTDistribution1D::pythonConstructor "std::string IFTDistribution1D::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";


// File: classIFTDistribution2D.xml
%feature("docstring") IFTDistribution2D "

Interface for two-dimensional distributions in Fourier space.

C++ includes: FTDistributions2D.h
";

%feature("docstring")  IFTDistribution2D::IFTDistribution2D "IFTDistribution2D::IFTDistribution2D(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IFTDistribution2D::clone "IFTDistribution2D* IFTDistribution2D::clone() const override=0
";

%feature("docstring")  IFTDistribution2D::omegaX "double IFTDistribution2D::omegaX() const
";

%feature("docstring")  IFTDistribution2D::omegaY "double IFTDistribution2D::omegaY() const
";

%feature("docstring")  IFTDistribution2D::gamma "double IFTDistribution2D::gamma() const
";

%feature("docstring")  IFTDistribution2D::delta "double IFTDistribution2D::delta() const

Angle in direct space between X- and Y-axis of distribution. 
";

%feature("docstring")  IFTDistribution2D::evaluate "virtual double IFTDistribution2D::evaluate(double qx, double qy) const =0

evaluate Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  IFTDistribution2D::createSampler "virtual std::unique_ptr<IDistribution2DSampler> IFTDistribution2D::createSampler() const =0
";

%feature("docstring")  IFTDistribution2D::pythonConstructor "std::string IFTDistribution2D::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";


// File: classIInterference.xml
%feature("docstring") IInterference "

Abstract base class of interference functions.

C++ includes: IInterference.h
";

%feature("docstring")  IInterference::IInterference "IInterference::IInterference(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IInterference::IInterference "IInterference::IInterference(double position_var)
";

%feature("docstring")  IInterference::clone "IInterference* IInterference::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IInterference::evaluate "double IInterference::evaluate(R3 q, double outer_iff=1.0) const

Evaluates the interference function for a given wavevector transfer. 
";

%feature("docstring")  IInterference::setPositionVariance "void IInterference::setPositionVariance(double var)

Sets the variance of the position for the calculation of the DW factor It is defined as the variance in each relevant dimension 
";

%feature("docstring")  IInterference::positionVariance "double IInterference::positionVariance() const

Returns the position variance. 
";

%feature("docstring")  IInterference::getParticleDensity "virtual double IInterference::getParticleDensity() const

If defined by this interference function's parameters, returns the particle density (per area). Otherwise, returns zero or a user-defined value 
";

%feature("docstring")  IInterference::supportsMultilayer "virtual bool IInterference::supportsMultilayer() const

Indicates if this interference function can be used with a multilayer (DWBA mode) 
";

%feature("docstring")  IInterference::DWfactor "double IInterference::DWfactor(R3 q) const

Evaluates the Debye-Waller factor for a given wavevector transfer. 
";


// File: classInterference1DLattice.xml
%feature("docstring") Interference1DLattice "

Interference function of a 1D lattice.

C++ includes: Interference1DLattice.h
";

%feature("docstring")  Interference1DLattice::className "std::string Interference1DLattice::className() const final
";

%feature("docstring")  Interference1DLattice::Interference1DLattice "Interference1DLattice::Interference1DLattice(double length, double xi)

Constructor of interference function of one-dimensional lattice.

Parameters:
-----------

length: 
lattice constant in nanometers

xi: 
rotation of lattice with respect to x-axis in radians 
";

%feature("docstring")  Interference1DLattice::~Interference1DLattice "Interference1DLattice::~Interference1DLattice() override
";

%feature("docstring")  Interference1DLattice::clone "Interference1DLattice * Interference1DLattice::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Interference1DLattice::accept "void Interference1DLattice::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Interference1DLattice::setDecayFunction "void Interference1DLattice::setDecayFunction(const IFTDecayFunction1D &decay)

Sets one-dimensional decay function.

Parameters:
-----------

decay: 
one-dimensional decay function in reciprocal space 
";

%feature("docstring")  Interference1DLattice::getLength "double Interference1DLattice::getLength() const
";

%feature("docstring")  Interference1DLattice::getXi "double Interference1DLattice::getXi() const
";

%feature("docstring")  Interference1DLattice::getChildren "std::vector< const INode * > Interference1DLattice::getChildren() const override
";


// File: classInterference2DLattice.xml
%feature("docstring") Interference2DLattice "

Interference function of a 2D lattice.

C++ includes: Interference2DLattice.h
";

%feature("docstring")  Interference2DLattice::className "std::string Interference2DLattice::className() const final
";

%feature("docstring")  Interference2DLattice::Interference2DLattice "Interference2DLattice::Interference2DLattice(const Lattice2D &lattice)
";

%feature("docstring")  Interference2DLattice::~Interference2DLattice "Interference2DLattice::~Interference2DLattice() override
";

%feature("docstring")  Interference2DLattice::clone "Interference2DLattice * Interference2DLattice::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Interference2DLattice::accept "void Interference2DLattice::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Interference2DLattice::setDecayFunction "void Interference2DLattice::setDecayFunction(const IFTDecayFunction2D &decay)

Sets two-dimensional decay function.

Parameters:
-----------

decay: 
two-dimensional decay function in reciprocal space 
";

%feature("docstring")  Interference2DLattice::setIntegrationOverXi "void Interference2DLattice::setIntegrationOverXi(bool integrate_xi)
";

%feature("docstring")  Interference2DLattice::integrationOverXi "bool Interference2DLattice::integrationOverXi() const
";

%feature("docstring")  Interference2DLattice::lattice "const Lattice2D & Interference2DLattice::lattice() const
";

%feature("docstring")  Interference2DLattice::getParticleDensity "double Interference2DLattice::getParticleDensity() const override

Returns the particle density associated with this 2d lattice. 
";

%feature("docstring")  Interference2DLattice::getChildren "std::vector< const INode * > Interference2DLattice::getChildren() const override
";

%feature("docstring")  Interference2DLattice::onChange "void Interference2DLattice::onChange() override
";


// File: classInterference2DParaCrystal.xml
%feature("docstring") Interference2DParaCrystal "

Interference function of a 2D paracrystal.

C++ includes: Interference2DParaCrystal.h
";

%feature("docstring")  Interference2DParaCrystal::className "std::string Interference2DParaCrystal::className() const final
";

%feature("docstring")  Interference2DParaCrystal::Interference2DParaCrystal "Interference2DParaCrystal::Interference2DParaCrystal(const Lattice2D &lattice, double damping_length, double domain_size_1, double domain_size_2)
";

%feature("docstring")  Interference2DParaCrystal::~Interference2DParaCrystal "Interference2DParaCrystal::~Interference2DParaCrystal() override
";

%feature("docstring")  Interference2DParaCrystal::clone "Interference2DParaCrystal * Interference2DParaCrystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Interference2DParaCrystal::accept "void Interference2DParaCrystal::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Interference2DParaCrystal::setDomainSizes "void Interference2DParaCrystal::setDomainSizes(double size_1, double size_2)

Sets the sizes of coherence domains.

Parameters:
-----------

size_1: 
coherence domain size along the first basis vector in nanometers

size_2: 
coherence domain size along the second basis vector in nanometers 
";

%feature("docstring")  Interference2DParaCrystal::setProbabilityDistributions "void Interference2DParaCrystal::setProbabilityDistributions(const IFTDistribution2D &pdf_1, const IFTDistribution2D &pdf_2)

Sets the probability distributions (Fourier transformed) for the two lattice directions.

Parameters:
-----------

pdf_1: 
probability distribution in first lattice direction

pdf_2: 
probability distribution in second lattice direction 
";

%feature("docstring")  Interference2DParaCrystal::setDampingLength "void Interference2DParaCrystal::setDampingLength(double damping_length)

Sets the damping length.

Parameters:
-----------

damping_length: 
the damping (coherence) length of the paracrystal in nanometers 
";

%feature("docstring")  Interference2DParaCrystal::domainSizes "std::vector< double > Interference2DParaCrystal::domainSizes() const
";

%feature("docstring")  Interference2DParaCrystal::setIntegrationOverXi "void Interference2DParaCrystal::setIntegrationOverXi(bool integrate_xi)

Enables/disables averaging over the lattice rotation angle.

Parameters:
-----------

integrate_xi: 
integration flag 
";

%feature("docstring")  Interference2DParaCrystal::integrationOverXi "bool Interference2DParaCrystal::integrationOverXi() const
";

%feature("docstring")  Interference2DParaCrystal::dampingLength "double Interference2DParaCrystal::dampingLength() const
";

%feature("docstring")  Interference2DParaCrystal::lattice "const Lattice2D & Interference2DParaCrystal::lattice() const
";

%feature("docstring")  Interference2DParaCrystal::getParticleDensity "double Interference2DParaCrystal::getParticleDensity() const override

If defined by this interference function's parameters, returns the particle density (per area). Otherwise, returns zero or a user-defined value 
";

%feature("docstring")  Interference2DParaCrystal::getChildren "std::vector< const INode * > Interference2DParaCrystal::getChildren() const override
";

%feature("docstring")  Interference2DParaCrystal::pdf1 "const IFTDistribution2D* Interference2DParaCrystal::pdf1() const
";

%feature("docstring")  Interference2DParaCrystal::pdf2 "const IFTDistribution2D* Interference2DParaCrystal::pdf2() const
";


// File: classInterference2DSuperLattice.xml
%feature("docstring") Interference2DSuperLattice "

Interference function of a 2D superlattice with a configurable interference function for each lattice site.

C++ includes: Interference2DSuperLattice.h
";

%feature("docstring")  Interference2DSuperLattice::className "std::string Interference2DSuperLattice::className() const final
";

%feature("docstring")  Interference2DSuperLattice::Interference2DSuperLattice "Interference2DSuperLattice::Interference2DSuperLattice(const Lattice2D &lattice, unsigned size_1, unsigned size_2)
";

%feature("docstring")  Interference2DSuperLattice::Interference2DSuperLattice "Interference2DSuperLattice::Interference2DSuperLattice(double length_1, double length_2, double alpha, double xi, unsigned size_1, unsigned size_2)

Constructor of two-dimensional interference function.

Parameters:
-----------

length_1: 
length of first lattice vector in nanometers

length_2: 
length of second lattice vector in nanometers

alpha: 
angle between lattice vectors in radians

xi: 
rotation of lattice with respect to x-axis (beam direction) in radians

size_1: 
correlation length in direction 1

size_2: 
correlation length in direction 2 
";

%feature("docstring")  Interference2DSuperLattice::~Interference2DSuperLattice "Interference2DSuperLattice::~Interference2DSuperLattice() override
";

%feature("docstring")  Interference2DSuperLattice::clone "Interference2DSuperLattice * Interference2DSuperLattice::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Interference2DSuperLattice::accept "void Interference2DSuperLattice::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Interference2DSuperLattice::setSubstructureIFF "void Interference2DSuperLattice::setSubstructureIFF(const IInterference &sub_iff)
";

%feature("docstring")  Interference2DSuperLattice::substructureIFF "const IInterference & Interference2DSuperLattice::substructureIFF() const
";

%feature("docstring")  Interference2DSuperLattice::evaluate "double Interference2DSuperLattice::evaluate(R3 q, double outer_iff=1.0) const override

Evaluates the interference function for a given wavevector transfer. 
";

%feature("docstring")  Interference2DSuperLattice::domainSize1 "unsigned Interference2DSuperLattice::domainSize1() const
";

%feature("docstring")  Interference2DSuperLattice::domainSize2 "unsigned Interference2DSuperLattice::domainSize2() const
";

%feature("docstring")  Interference2DSuperLattice::setIntegrationOverXi "void Interference2DSuperLattice::setIntegrationOverXi(bool integrate_xi)
";

%feature("docstring")  Interference2DSuperLattice::integrationOverXi "bool Interference2DSuperLattice::integrationOverXi() const
";

%feature("docstring")  Interference2DSuperLattice::lattice "const Lattice2D & Interference2DSuperLattice::lattice() const
";

%feature("docstring")  Interference2DSuperLattice::getChildren "std::vector< const INode * > Interference2DSuperLattice::getChildren() const override
";


// File: classInterference3DLattice.xml
%feature("docstring") Interference3DLattice "

Interference function of a 3D lattice.

C++ includes: Interference3DLattice.h
";

%feature("docstring")  Interference3DLattice::className "std::string Interference3DLattice::className() const final
";

%feature("docstring")  Interference3DLattice::Interference3DLattice "Interference3DLattice::Interference3DLattice(const Lattice3D &lattice)
";

%feature("docstring")  Interference3DLattice::~Interference3DLattice "Interference3DLattice::~Interference3DLattice() override
";

%feature("docstring")  Interference3DLattice::clone "Interference3DLattice * Interference3DLattice::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Interference3DLattice::accept "void Interference3DLattice::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Interference3DLattice::setPeakShape "void Interference3DLattice::setPeakShape(const IPeakShape &peak_shape)
";

%feature("docstring")  Interference3DLattice::lattice "const Lattice3D & Interference3DLattice::lattice() const
";

%feature("docstring")  Interference3DLattice::supportsMultilayer "bool Interference3DLattice::supportsMultilayer() const override

Indicates if this interference function can be used with a multilayer (DWBA mode) 
";

%feature("docstring")  Interference3DLattice::getChildren "std::vector< const INode * > Interference3DLattice::getChildren() const override
";

%feature("docstring")  Interference3DLattice::onChange "void Interference3DLattice::onChange() override
";


// File: classInterferenceFinite2DLattice.xml
%feature("docstring") InterferenceFinite2DLattice "

Interference function of a finite 2D lattice.

C++ includes: InterferenceFinite2DLattice.h
";

%feature("docstring")  InterferenceFinite2DLattice::className "std::string InterferenceFinite2DLattice::className() const final
";

%feature("docstring")  InterferenceFinite2DLattice::InterferenceFinite2DLattice "InterferenceFinite2DLattice::InterferenceFinite2DLattice(const Lattice2D &lattice, unsigned N_1, unsigned N_2)

Constructor of two-dimensional finite lattice interference function.

Parameters:
-----------

lattice: 
object specifying a 2d lattice structure

N_1: 
number of lattice cells in the first lattice direction

N_2: 
number of lattice cells in the second lattice direction 
";

%feature("docstring")  InterferenceFinite2DLattice::~InterferenceFinite2DLattice "InterferenceFinite2DLattice::~InterferenceFinite2DLattice() override
";

%feature("docstring")  InterferenceFinite2DLattice::clone "InterferenceFinite2DLattice * InterferenceFinite2DLattice::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  InterferenceFinite2DLattice::accept "void InterferenceFinite2DLattice::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  InterferenceFinite2DLattice::numberUnitCells1 "unsigned InterferenceFinite2DLattice::numberUnitCells1() const
";

%feature("docstring")  InterferenceFinite2DLattice::numberUnitCells2 "unsigned InterferenceFinite2DLattice::numberUnitCells2() const
";

%feature("docstring")  InterferenceFinite2DLattice::setIntegrationOverXi "void InterferenceFinite2DLattice::setIntegrationOverXi(bool integrate_xi)
";

%feature("docstring")  InterferenceFinite2DLattice::integrationOverXi "bool InterferenceFinite2DLattice::integrationOverXi() const
";

%feature("docstring")  InterferenceFinite2DLattice::lattice "const Lattice2D & InterferenceFinite2DLattice::lattice() const
";

%feature("docstring")  InterferenceFinite2DLattice::getParticleDensity "double InterferenceFinite2DLattice::getParticleDensity() const override

Returns the particle density associated with this 2d lattice. 
";

%feature("docstring")  InterferenceFinite2DLattice::getChildren "std::vector< const INode * > InterferenceFinite2DLattice::getChildren() const override
";


// File: classInterferenceFinite3DLattice.xml
%feature("docstring") InterferenceFinite3DLattice "

Interference function of a finite 3D lattice.

C++ includes: InterferenceFinite3DLattice.h
";

%feature("docstring")  InterferenceFinite3DLattice::className "std::string InterferenceFinite3DLattice::className() const final
";

%feature("docstring")  InterferenceFinite3DLattice::InterferenceFinite3DLattice "InterferenceFinite3DLattice::InterferenceFinite3DLattice(const Lattice3D &lattice, unsigned N_1, unsigned N_2, unsigned N_3)
";

%feature("docstring")  InterferenceFinite3DLattice::~InterferenceFinite3DLattice "InterferenceFinite3DLattice::~InterferenceFinite3DLattice() override
";

%feature("docstring")  InterferenceFinite3DLattice::clone "InterferenceFinite3DLattice * InterferenceFinite3DLattice::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  InterferenceFinite3DLattice::accept "void InterferenceFinite3DLattice::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  InterferenceFinite3DLattice::numberUnitCells1 "unsigned InterferenceFinite3DLattice::numberUnitCells1() const
";

%feature("docstring")  InterferenceFinite3DLattice::numberUnitCells2 "unsigned InterferenceFinite3DLattice::numberUnitCells2() const
";

%feature("docstring")  InterferenceFinite3DLattice::numberUnitCells3 "unsigned InterferenceFinite3DLattice::numberUnitCells3() const
";

%feature("docstring")  InterferenceFinite3DLattice::lattice "const Lattice3D & InterferenceFinite3DLattice::lattice() const
";

%feature("docstring")  InterferenceFinite3DLattice::supportsMultilayer "bool InterferenceFinite3DLattice::supportsMultilayer() const override

Indicates if this interference function can be used with a multilayer (DWBA mode) 
";

%feature("docstring")  InterferenceFinite3DLattice::getChildren "std::vector< const INode * > InterferenceFinite3DLattice::getChildren() const override
";


// File: classInterferenceHardDisk.xml
%feature("docstring") InterferenceHardDisk "

Percus-Yevick hard disk interference function.

M.S. Ripoll & C.F. Tejero (1995) Approximate analytical expression for the direct correlation function of hard discs within the Percus-Yevick equation, Molecular Physics, 85:2, 423-428, DOI: 10.1080/00268979500101211

C++ includes: InterferenceHardDisk.h
";

%feature("docstring")  InterferenceHardDisk::className "std::string InterferenceHardDisk::className() const final
";

%feature("docstring")  InterferenceHardDisk::InterferenceHardDisk "InterferenceHardDisk::InterferenceHardDisk(double radius, double density, double position_var=0)
";

%feature("docstring")  InterferenceHardDisk::~InterferenceHardDisk "InterferenceHardDisk::~InterferenceHardDisk() override=default
";

%feature("docstring")  InterferenceHardDisk::clone "InterferenceHardDisk * InterferenceHardDisk::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  InterferenceHardDisk::accept "void InterferenceHardDisk::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  InterferenceHardDisk::getParticleDensity "double InterferenceHardDisk::getParticleDensity() const override

If defined by this interference function's parameters, returns the particle density (per area). Otherwise, returns zero or a user-defined value 
";

%feature("docstring")  InterferenceHardDisk::radius "double InterferenceHardDisk::radius() const
";

%feature("docstring")  InterferenceHardDisk::density "double InterferenceHardDisk::density() const
";


// File: classInterferenceNone.xml
%feature("docstring") InterferenceNone "

Default interference function (i.e. absence of any interference).

C++ includes: InterferenceNone.h
";

%feature("docstring")  InterferenceNone::className "std::string InterferenceNone::className() const final
";

%feature("docstring")  InterferenceNone::InterferenceNone "InterferenceNone::InterferenceNone()
";

%feature("docstring")  InterferenceNone::clone "InterferenceNone * InterferenceNone::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  InterferenceNone::accept "void InterferenceNone::accept(INodeVisitor *visitor) const override
";


// File: classInterferenceRadialParaCrystal.xml
%feature("docstring") InterferenceRadialParaCrystal "

Interference function of radial paracrystal.

C++ includes: InterferenceRadialParaCrystal.h
";

%feature("docstring")  InterferenceRadialParaCrystal::className "std::string InterferenceRadialParaCrystal::className() const final
";

%feature("docstring")  InterferenceRadialParaCrystal::InterferenceRadialParaCrystal "InterferenceRadialParaCrystal::InterferenceRadialParaCrystal(double peak_distance, double damping_length)

Constructor of interference function of radial paracrystal.

Parameters:
-----------

peak_distance: 
average distance to the next neighbor in nanometers

damping_length: 
the damping (coherence) length of the paracrystal in nanometers 
";

%feature("docstring")  InterferenceRadialParaCrystal::clone "InterferenceRadialParaCrystal * InterferenceRadialParaCrystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  InterferenceRadialParaCrystal::accept "void InterferenceRadialParaCrystal::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  InterferenceRadialParaCrystal::setKappa "void InterferenceRadialParaCrystal::setKappa(double kappa)

Sets size spacing coupling parameter of the Size Spacing Correlation Approximation. 
";

%feature("docstring")  InterferenceRadialParaCrystal::kappa "double InterferenceRadialParaCrystal::kappa() const
";

%feature("docstring")  InterferenceRadialParaCrystal::setDomainSize "void InterferenceRadialParaCrystal::setDomainSize(double size)

Sets domain size (finite size corrections).

Parameters:
-----------

size: 
size of coherence domain along the lattice main axis in nanometers 
";

%feature("docstring")  InterferenceRadialParaCrystal::domainSize "double InterferenceRadialParaCrystal::domainSize() const
";

%feature("docstring")  InterferenceRadialParaCrystal::FTPDF "complex_t InterferenceRadialParaCrystal::FTPDF(double qpar) const
";

%feature("docstring")  InterferenceRadialParaCrystal::setProbabilityDistribution "void InterferenceRadialParaCrystal::setProbabilityDistribution(const IFTDistribution1D &pdf)

Sets one-dimensional probability distribution.

Parameters:
-----------

pdf: 
probability distribution (Fourier transform of probability density) 
";

%feature("docstring")  InterferenceRadialParaCrystal::peakDistance "double InterferenceRadialParaCrystal::peakDistance() const
";

%feature("docstring")  InterferenceRadialParaCrystal::dampingLength "double InterferenceRadialParaCrystal::dampingLength() const
";

%feature("docstring")  InterferenceRadialParaCrystal::getChildren "std::vector< const INode * > InterferenceRadialParaCrystal::getChildren() const override
";

%feature("docstring")  InterferenceRadialParaCrystal::randomSample "double InterferenceRadialParaCrystal::randomSample() const
";


// File: classInterferenceTwin.xml
%feature("docstring") InterferenceTwin "

Interference function for two particles at a mean distance and given standard deviation from each other in a given direction.

C++ includes: InterferenceTwin.h
";

%feature("docstring")  InterferenceTwin::className "std::string InterferenceTwin::className() const final
";

%feature("docstring")  InterferenceTwin::InterferenceTwin "InterferenceTwin::InterferenceTwin(const R3 &direction, double mean_distance, double std_dev)
";

%feature("docstring")  InterferenceTwin::clone "InterferenceTwin * InterferenceTwin::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  InterferenceTwin::accept "void InterferenceTwin::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  InterferenceTwin::direction "R3 InterferenceTwin::direction() const
";

%feature("docstring")  InterferenceTwin::meanDistance "double InterferenceTwin::meanDistance() const
";

%feature("docstring")  InterferenceTwin::stdDev "double InterferenceTwin::stdDev() const
";


// File: classIParticle.xml
%feature("docstring") IParticle "

Abstract base class for  Particle,  ParticleComposition,  ParticleCoreShell,  MesoCrystal. Provides position/rotation and form factor. Abundance is inherited from  IParticle.

C++ includes: IParticle.h
";

%feature("docstring")  IParticle::~IParticle "IParticle::~IParticle() override
";

%feature("docstring")  IParticle::clone "IParticle* IParticle::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IParticle::createFormFactor "IFormFactor * IParticle::createFormFactor() const

Creates a form factor for this particle. 
";

%feature("docstring")  IParticle::createSlicedParticle "SlicedParticle IParticle::createSlicedParticle(const ZLimits &limits) const

Creates a sliced form factor for this particle. 
";

%feature("docstring")  IParticle::abundance "double IParticle::abundance() const
";

%feature("docstring")  IParticle::setAbundance "void IParticle::setAbundance(double abundance)

Sets particle abundance.

Parameters:
-----------

abundance: 
proportion of this type of particles normalized to the total number of particles in the layout. 
";

%feature("docstring")  IParticle::position "R3 IParticle::position() const

Returns particle position. 
";

%feature("docstring")  IParticle::setPosition "void IParticle::setPosition(R3 position)

Sets relative position of the particle's reference point in the coordinate system of parent.

Parameters:
-----------

position: 
relative position vector (components are in nanometers) 
";

%feature("docstring")  IParticle::setPosition "void IParticle::setPosition(double x, double y, double z)

Sets relative position of the particle's reference point in the coordinate system of parent.

Parameters:
-----------

x: 
x-coordinate in nanometers

y: 
y-coordinate in nanometers

z: 
z-coordinate in nanometers 
";

%feature("docstring")  IParticle::translate "void IParticle::translate(R3 translation)

Translates the particle. 
";

%feature("docstring")  IParticle::rotation "const IRotation * IParticle::rotation() const

Returns rotation object. 
";

%feature("docstring")  IParticle::setRotation "void IParticle::setRotation(const IRotation &rotation)

Sets transformation. 
";

%feature("docstring")  IParticle::rotate "void IParticle::rotate(const IRotation &rotation)

Rotates the particle. 
";

%feature("docstring")  IParticle::getChildren "std::vector< const INode * > IParticle::getChildren() const override
";

%feature("docstring")  IParticle::decompose "SafePointerVector< IParticle > IParticle::decompose() const

Decompose in constituent  IParticle objects. 
";

%feature("docstring")  IParticle::zSpan "ZLimits IParticle::zSpan() const

Top and bottom z-coordinate. 
";


// File: classIPeakShape.xml
%feature("docstring") IPeakShape "

Abstract base class class that defines the peak shape of a Bragg peak.

C++ includes: IPeakShape.h
";

%feature("docstring")  IPeakShape::IPeakShape "IPeakShape::IPeakShape()=default
";

%feature("docstring")  IPeakShape::IPeakShape "IPeakShape::IPeakShape(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IPeakShape::~IPeakShape "IPeakShape::~IPeakShape() override
";

%feature("docstring")  IPeakShape::clone "IPeakShape* IPeakShape::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IPeakShape::evaluate "virtual double IPeakShape::evaluate(R3 q, R3 q_lattice_point) const =0

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  IPeakShape::angularDisorder "virtual bool IPeakShape::angularDisorder() const

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classIProfileRectangularRipple.xml
%feature("docstring") IProfileRectangularRipple "

Base class for form factors with a rectangular ripple (bar) profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  IProfileRectangularRipple::IProfileRectangularRipple "IProfileRectangularRipple::IProfileRectangularRipple(const NodeMeta &meta, const std::vector< double > &PValues)
";


// File: classIProfileRipple.xml
%feature("docstring") IProfileRipple "

Base class for form factors with a cosine ripple profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  IProfileRipple::IProfileRipple "IProfileRipple::IProfileRipple(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IProfileRipple::getLength "double IProfileRipple::getLength() const
";

%feature("docstring")  IProfileRipple::getHeight "double IProfileRipple::getHeight() const
";

%feature("docstring")  IProfileRipple::getWidth "double IProfileRipple::getWidth() const
";

%feature("docstring")  IProfileRipple::radialExtension "double IProfileRipple::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IProfileRipple::evaluate_for_q "complex_t IProfileRipple::evaluate_for_q(C3 q) const override

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f. This method is public only for convenience of plotting form factors in Python. 
";


// File: classIRegistry.xml
%feature("docstring") IRegistry "

Templated object registry.

C++ includes: IRegistry.h
";

%feature("docstring")  IRegistry::getItem "const ValueType* IRegistry< ValueType >::getItem(const std::string &key) const
";

%feature("docstring")  IRegistry::keys "std::vector<std::string> IRegistry< ValueType >::keys() const
";

%feature("docstring")  IRegistry::size "size_t IRegistry< ValueType >::size() const
";


// File: classIRotation.xml
%feature("docstring") IRotation "

Abstract base class for rotations.

C++ includes: Rotations.h
";

%feature("docstring")  IRotation::IRotation "IRotation::IRotation(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  IRotation::clone "IRotation* IRotation::clone() const override=0
";

%feature("docstring")  IRotation::createInverse "virtual IRotation* IRotation::createInverse() const =0

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  IRotation::getTransform3D "virtual Transform3D IRotation::getTransform3D() const =0

Returns transformation. 
";

%feature("docstring")  IRotation::transformed "R3 IRotation::transformed(const R3 &v) const
";

%feature("docstring")  IRotation::isIdentity "bool IRotation::isIdentity() const

Returns true if rotation matrix is identity matrix (no rotations) 
";

%feature("docstring")  IRotation::zInvariant "bool IRotation::zInvariant() const
";


// File: classISampleNode.xml
%feature("docstring") ISampleNode "

Abstract base class for sample components and properties related to scattering.

C++ includes: ISampleNode.h
";

%feature("docstring")  ISampleNode::ISampleNode "ISampleNode::ISampleNode()=default
";

%feature("docstring")  ISampleNode::ISampleNode "ISampleNode::ISampleNode(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  ISampleNode::clone "ISampleNode* ISampleNode::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ISampleNode::material "virtual const Material* ISampleNode::material() const

Returns nullptr, unless overwritten to return a specific material. 
";

%feature("docstring")  ISampleNode::containedMaterials "std::vector< const Material * > ISampleNode::containedMaterials() const

Returns set of unique materials contained in this  ISampleNode. 
";

%feature("docstring")  ISampleNode::isMagnetic "bool ISampleNode::isMagnetic() const

Returns true if there is any magnetic material in this  ISampleNode. 
";


// File: classISawtoothRipple.xml
%feature("docstring") ISawtoothRipple "

Base class for form factors with a triangular ripple profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  ISawtoothRipple::ISawtoothRipple "ISawtoothRipple::ISawtoothRipple(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  ISawtoothRipple::getAsymmetry "double ISawtoothRipple::getAsymmetry() const
";


// File: classISelectionRule.xml
%feature("docstring") ISelectionRule "

Abstract base class for selection rules.

C++ includes: ISelectionRule.h
";

%feature("docstring")  ISelectionRule::~ISelectionRule "virtual ISelectionRule::~ISelectionRule()=default
";

%feature("docstring")  ISelectionRule::clone "virtual ISelectionRule* ISelectionRule::clone() const =0
";

%feature("docstring")  ISelectionRule::coordinateSelected "virtual bool ISelectionRule::coordinateSelected(const I3 &coordinate) const =0
";


// File: classIShape3D.xml
%feature("docstring") IShape3D "

Abstract base class for different shapes.

In contrast to the form factors, these shapes only provide an interface for returning a set of vertices.

C++ includes: IShape3D.h
";

%feature("docstring")  IShape3D::IShape3D "IShape3D::IShape3D()=default
";

%feature("docstring")  IShape3D::~IShape3D "virtual IShape3D::~IShape3D()=default
";

%feature("docstring")  IShape3D::vertices "std::vector< R3 > IShape3D::vertices() const

Retrieves a list of the vertices constituting this concrete shape. 
";


// File: classIsotropicGaussPeakShape.xml
%feature("docstring") IsotropicGaussPeakShape "

Class that implements an isotropic Gaussian peak shape of a Bragg peak.

C++ includes: IPeakShape.h
";

%feature("docstring")  IsotropicGaussPeakShape::className "std::string IsotropicGaussPeakShape::className() const final
";

%feature("docstring")  IsotropicGaussPeakShape::IsotropicGaussPeakShape "IsotropicGaussPeakShape::IsotropicGaussPeakShape(double max_intensity, double domainsize)
";

%feature("docstring")  IsotropicGaussPeakShape::~IsotropicGaussPeakShape "IsotropicGaussPeakShape::~IsotropicGaussPeakShape() override
";

%feature("docstring")  IsotropicGaussPeakShape::clone "IsotropicGaussPeakShape * IsotropicGaussPeakShape::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IsotropicGaussPeakShape::accept "void IsotropicGaussPeakShape::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  IsotropicGaussPeakShape::evaluate "double IsotropicGaussPeakShape::evaluate(R3 q, R3 q_lattice_point) const override

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";


// File: classIsotropicLorentzPeakShape.xml
%feature("docstring") IsotropicLorentzPeakShape "

An isotropic Lorentzian peak shape of a Bragg peak.

C++ includes: IPeakShape.h
";

%feature("docstring")  IsotropicLorentzPeakShape::className "std::string IsotropicLorentzPeakShape::className() const final
";

%feature("docstring")  IsotropicLorentzPeakShape::IsotropicLorentzPeakShape "IsotropicLorentzPeakShape::IsotropicLorentzPeakShape(double max_intensity, double domainsize)
";

%feature("docstring")  IsotropicLorentzPeakShape::~IsotropicLorentzPeakShape "IsotropicLorentzPeakShape::~IsotropicLorentzPeakShape() override
";

%feature("docstring")  IsotropicLorentzPeakShape::clone "IsotropicLorentzPeakShape * IsotropicLorentzPeakShape::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IsotropicLorentzPeakShape::accept "void IsotropicLorentzPeakShape::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  IsotropicLorentzPeakShape::evaluate "double IsotropicLorentzPeakShape::evaluate(R3 q, R3 q_lattice_point) const override

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";


// File: classLattice2D.xml
%feature("docstring") Lattice2D "

A two-dimensional Bravais lattice.

C++ includes: Lattice2D.h
";

%feature("docstring")  Lattice2D::Lattice2D "Lattice2D::Lattice2D(const NodeMeta &meta, const std::vector< double > &PValues)
";

%feature("docstring")  Lattice2D::Lattice2D "Lattice2D::Lattice2D(double xi)
";

%feature("docstring")  Lattice2D::clone "Lattice2D* Lattice2D::clone() const override=0
";

%feature("docstring")  Lattice2D::length1 "virtual double Lattice2D::length1() const =0
";

%feature("docstring")  Lattice2D::length2 "virtual double Lattice2D::length2() const =0
";

%feature("docstring")  Lattice2D::latticeAngle "virtual double Lattice2D::latticeAngle() const =0
";

%feature("docstring")  Lattice2D::unitCellArea "virtual double Lattice2D::unitCellArea() const =0
";

%feature("docstring")  Lattice2D::rotationAngle "double Lattice2D::rotationAngle() const
";

%feature("docstring")  Lattice2D::reciprocalBases "Lattice2D::ReciprocalBases Lattice2D::reciprocalBases() const
";

%feature("docstring")  Lattice2D::setRotationEnabled "void Lattice2D::setRotationEnabled(bool enabled)
";


// File: classLattice3D.xml
%feature("docstring") Lattice3D "

A Bravais lattice, characterized by three basis vectors, and optionally an  ISelectionRule.

C++ includes: Lattice3D.h
";

%feature("docstring")  Lattice3D::className "std::string Lattice3D::className() const final
";

%feature("docstring")  Lattice3D::Lattice3D "Lattice3D::Lattice3D(R3 a, R3 b, R3 c)
";

%feature("docstring")  Lattice3D::Lattice3D "Lattice3D::Lattice3D(const Lattice3D &lattice)
";

%feature("docstring")  Lattice3D::~Lattice3D "Lattice3D::~Lattice3D() override
";

%feature("docstring")  Lattice3D::accept "void Lattice3D::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Lattice3D::transformed "Lattice3D Lattice3D::transformed(const Transform3D &transform) const

Creates transformed lattice. 
";

%feature("docstring")  Lattice3D::getBasisVectorA "R3 Lattice3D::getBasisVectorA() const

Returns basis vector a. 
";

%feature("docstring")  Lattice3D::getBasisVectorB "R3 Lattice3D::getBasisVectorB() const

Returns basis vector b. 
";

%feature("docstring")  Lattice3D::getBasisVectorC "R3 Lattice3D::getBasisVectorC() const

Returns basis vector c. 
";

%feature("docstring")  Lattice3D::getMillerDirection "R3 Lattice3D::getMillerDirection(double h, double k, double l) const

Returns normalized direction corresponding to the given Miller indices.

Currently unused but may be useful for checks. 
";

%feature("docstring")  Lattice3D::unitCellVolume "double Lattice3D::unitCellVolume() const

Returns the volume of the unit cell. 
";

%feature("docstring")  Lattice3D::getReciprocalLatticeBasis "void Lattice3D::getReciprocalLatticeBasis(R3 &ra, R3 &rb, R3 &rc) const

Returns the reciprocal basis vectors.

Currently only used in tests. 
";

%feature("docstring")  Lattice3D::getNearestReciprocalLatticeVectorCoordinates "I3 Lattice3D::getNearestReciprocalLatticeVectorCoordinates(R3 q) const

Returns the nearest reciprocal lattice point from a given vector. 
";

%feature("docstring")  Lattice3D::reciprocalLatticeVectorsWithinRadius "std::vector< R3 > Lattice3D::reciprocalLatticeVectorsWithinRadius(R3 q, double dq) const

Returns a list of reciprocal lattice vectors within distance dq of a vector q. 
";

%feature("docstring")  Lattice3D::setSelectionRule "void Lattice3D::setSelectionRule(const ISelectionRule &selection_rule)

Sets a selection rule for the reciprocal vectors. 
";


// File: classLayer.xml
%feature("docstring") Layer "

A layer in a  MultiLayer sample.

C++ includes: Layer.h
";

%feature("docstring")  Layer::className "std::string Layer::className() const final
";

%feature("docstring")  Layer::Layer "Layer::Layer(Material material, double thickness=0)

Constructor of a layer with thickness and material

Parameters:
-----------

material: 
material the layer is made of

thickness: 
thickness of a layer in nanometers 
";

%feature("docstring")  Layer::~Layer "Layer::~Layer() override
";

%feature("docstring")  Layer::clone "Layer * Layer::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Layer::accept "void Layer::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Layer::thickness "double Layer::thickness() const
";

%feature("docstring")  Layer::material "const Material* Layer::material() const override

Returns nullptr, unless overwritten to return a specific material. 
";

%feature("docstring")  Layer::addLayout "void Layer::addLayout(const ParticleLayout &layout)
";

%feature("docstring")  Layer::numberOfLayouts "size_t Layer::numberOfLayouts() const
";

%feature("docstring")  Layer::layouts "std::vector< const ParticleLayout * > Layer::layouts() const
";

%feature("docstring")  Layer::getChildren "std::vector< const INode * > Layer::getChildren() const override
";

%feature("docstring")  Layer::setNumberOfSlices "void Layer::setNumberOfSlices(unsigned int n_slices)
";

%feature("docstring")  Layer::numberOfSlices "unsigned int Layer::numberOfSlices() const
";


// File: classLayerInterface.xml
%feature("docstring") LayerInterface "

Interface between two layers, possibly with roughness.

C++ includes: LayerInterface.h
";

%feature("docstring")  LayerInterface::className "std::string LayerInterface::className() const final
";

%feature("docstring")  LayerInterface::~LayerInterface "LayerInterface::~LayerInterface() override
";

%feature("docstring")  LayerInterface::clone "LayerInterface * LayerInterface::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  LayerInterface::accept "void LayerInterface::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  LayerInterface::setRoughness "void LayerInterface::setRoughness(const LayerRoughness &roughness)

Sets roughness of the interface. 
";

%feature("docstring")  LayerInterface::getRoughness "const LayerRoughness * LayerInterface::getRoughness() const

Returns roughness of the interface. 
";

%feature("docstring")  LayerInterface::topLayer "const Layer * LayerInterface::topLayer() const
";

%feature("docstring")  LayerInterface::bottomLayer "const Layer * LayerInterface::bottomLayer() const
";

%feature("docstring")  LayerInterface::getChildren "std::vector< const INode * > LayerInterface::getChildren() const override
";


// File: classLayerRoughness.xml
%feature("docstring") LayerRoughness "

A roughness of interface between two layers.

Based on the article \"X-ray reflection and transmission by rough surfaces\" by D. K. G. de Boer, Physical Review B 51, 5297 (1995)

C++ includes: LayerRoughness.h
";

%feature("docstring")  LayerRoughness::className "std::string LayerRoughness::className() const final
";

%feature("docstring")  LayerRoughness::LayerRoughness "LayerRoughness::LayerRoughness(double sigma, double hurstParameter=0, double lateralCorrLength=0)

Constructor of layer roughness.

Parameters:
-----------

sigma: 
rms of the roughness in nanometers

hurstParameter: 
hurst parameter which describes how jagged the interface, dimensionless [0.0, 1.0], where 0.0 gives more spikes, 1.0 more smoothness

lateralCorrLength: 
lateral correlation length of the roughness in nanometers 
";

%feature("docstring")  LayerRoughness::LayerRoughness "LayerRoughness::LayerRoughness()
";

%feature("docstring")  LayerRoughness::clone "LayerRoughness* LayerRoughness::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  LayerRoughness::accept "void LayerRoughness::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  LayerRoughness::getSpectralFun "double LayerRoughness::getSpectralFun(R3 kvec) const

Returns power spectral density of the surface roughness.

Power spectral density of the surface roughness is a result of two-dimensional Fourier transform of the correlation function of the roughness profile.

Based on the article D.K.G. de Boer, Physical review B, Volume 51, Number 8, 15 February 1995 \"X-ray reflection and transmission by rough surfaces\" 
";

%feature("docstring")  LayerRoughness::getCorrFun "double LayerRoughness::getCorrFun(R3 k) const

Correlation function of the roughness profile. 
";

%feature("docstring")  LayerRoughness::setSigma "void LayerRoughness::setSigma(double sigma)

Sets rms of roughness. 
";

%feature("docstring")  LayerRoughness::getSigma "double LayerRoughness::getSigma() const

Returns rms of roughness. 
";

%feature("docstring")  LayerRoughness::setHurstParameter "void LayerRoughness::setHurstParameter(double hurstParameter)

Sets hurst parameter. It describes how jagged the surface is. 
";

%feature("docstring")  LayerRoughness::getHurstParameter "double LayerRoughness::getHurstParameter() const

Returns hurst parameter. 
";

%feature("docstring")  LayerRoughness::setLatteralCorrLength "void LayerRoughness::setLatteralCorrLength(double lateralCorrLength)

Sets lateral correlation length. 
";

%feature("docstring")  LayerRoughness::getLatteralCorrLength "double LayerRoughness::getLatteralCorrLength() const

Returns lateral correlation length. 
";

%feature("docstring")  LayerRoughness::pythonConstructor "std::string LayerRoughness::pythonConstructor() const

Creates the Python constructor of this class. 
";


// File: classLorentzFisherPeakShape.xml
%feature("docstring") LorentzFisherPeakShape "

A peak shape that is Lorentzian in the radial direction and uses the Mises-Fisher distribution in the angular direction.

C++ includes: IPeakShape.h
";

%feature("docstring")  LorentzFisherPeakShape::className "std::string LorentzFisherPeakShape::className() const final
";

%feature("docstring")  LorentzFisherPeakShape::LorentzFisherPeakShape "LorentzFisherPeakShape::LorentzFisherPeakShape(double max_intensity, double radial_size, double kappa)
";

%feature("docstring")  LorentzFisherPeakShape::~LorentzFisherPeakShape "LorentzFisherPeakShape::~LorentzFisherPeakShape() override
";

%feature("docstring")  LorentzFisherPeakShape::clone "LorentzFisherPeakShape * LorentzFisherPeakShape::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  LorentzFisherPeakShape::accept "void LorentzFisherPeakShape::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  LorentzFisherPeakShape::evaluate "double LorentzFisherPeakShape::evaluate(R3 q, R3 q_lattice_point) const override

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  LorentzFisherPeakShape::angularDisorder "bool LorentzFisherPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classMagneticMaterialImpl.xml
%feature("docstring") MagneticMaterialImpl "

Basic implementation for magnetized material. Inherited by  RefractiveMaterialImpl and  MaterialBySLDImpl. Incorporates data and methods required to handle material magnetization.

C++ includes: MagneticMaterialImpl.h
";

%feature("docstring")  MagneticMaterialImpl::MagneticMaterialImpl "MagneticMaterialImpl::MagneticMaterialImpl(const std::string &name, R3 magnetization)

Constructs basic material with name and magnetization. 
";

%feature("docstring")  MagneticMaterialImpl::~MagneticMaterialImpl "MagneticMaterialImpl::~MagneticMaterialImpl() override=default
";

%feature("docstring")  MagneticMaterialImpl::clone "MagneticMaterialImpl* MagneticMaterialImpl::clone() const override=0

Returns pointer to a copy of material. 
";

%feature("docstring")  MagneticMaterialImpl::inverted "MagneticMaterialImpl * MagneticMaterialImpl::inverted() const override

Constructs a material with inverted magnetization. 
";

%feature("docstring")  MagneticMaterialImpl::isScalarMaterial "bool MagneticMaterialImpl::isScalarMaterial() const override

Indicates whether the interaction with the material is scalar. This means that different polarization states will be diffracted equally 
";

%feature("docstring")  MagneticMaterialImpl::isMagneticMaterial "bool MagneticMaterialImpl::isMagneticMaterial() const override
";

%feature("docstring")  MagneticMaterialImpl::magnetization "R3 MagneticMaterialImpl::magnetization() const override

Returns the magnetization (in A/m) 
";

%feature("docstring")  MagneticMaterialImpl::polarizedSubtrSLD "Eigen::Matrix2cd MagneticMaterialImpl::polarizedSubtrSLD(const WavevectorInfo &wavevectors) const override

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld) matrix with magnetization corrections. 
";

%feature("docstring")  MagneticMaterialImpl::rotatedMaterial "MagneticMaterialImpl * MagneticMaterialImpl::rotatedMaterial(const Transform3D &transform) const override
";


// File: classMaterial.xml
%feature("docstring") Material "

A wrapper for underlying material implementation

C++ includes: Material.h
";

%feature("docstring")  Material::Material "Material::Material(std::unique_ptr< BaseMaterialImpl > material_impl)

Creates material with particular material implementation. 
";

%feature("docstring")  Material::Material "Material::Material(const Material &material)
";

%feature("docstring")  Material::Material "Material::Material(Material &&material)=default
";

%feature("docstring")  Material::inverted "Material Material::inverted() const

Constructs a material with inverted magnetization. 
";

%feature("docstring")  Material::refractiveIndex "complex_t Material::refractiveIndex(double wavelength) const

Returns refractive index. 
";

%feature("docstring")  Material::refractiveIndex2 "complex_t Material::refractiveIndex2(double wavelength) const

Returns squared refractive index. 
";

%feature("docstring")  Material::isScalarMaterial "bool Material::isScalarMaterial() const

Indicates whether the interaction with the material is scalar. This means that different polarization states will be diffracted equally 
";

%feature("docstring")  Material::isMagneticMaterial "bool Material::isMagneticMaterial() const
";

%feature("docstring")  Material::materialName "std::string Material::materialName() const

Returns the name of material. 
";

%feature("docstring")  Material::typeID "MATERIAL_TYPES Material::typeID() const

Returns the type of underlying material implementation. 
";

%feature("docstring")  Material::magnetization "R3 Material::magnetization() const

Get the magnetization (in A/m) 
";

%feature("docstring")  Material::materialData "complex_t Material::materialData() const

Returns delta + i beta. 
";

%feature("docstring")  Material::isEmpty "bool Material::isEmpty() const

Returns true if material underlying data is nullptr. 
";

%feature("docstring")  Material::isDefaultMaterial "bool Material::isDefaultMaterial() const

Returns true if material has refractive index of (1.0, 0.0) and zero magnetization. 
";

%feature("docstring")  Material::scalarSubtrSLD "complex_t Material::scalarSubtrSLD(const WavevectorInfo &wavevectors) const

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld (in  $nm^{-2}$) being the scattering length density 
";

%feature("docstring")  Material::polarizedSubtrSLD "Eigen::Matrix2cd Material::polarizedSubtrSLD(const WavevectorInfo &wavevectors) const

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld) matrix with magnetization corrections. 
";

%feature("docstring")  Material::rotatedMaterial "Material Material::rotatedMaterial(const Transform3D &transform) const
";


// File: classMaterialBySLDImpl.xml
%feature("docstring") MaterialBySLDImpl "

Material implementation based on wavelength-independent data (valid for a range of wavelengths)

C++ includes: MaterialBySLDImpl.h
";

%feature("docstring")  MaterialBySLDImpl::~MaterialBySLDImpl "MaterialBySLDImpl::~MaterialBySLDImpl() override=default
";

%feature("docstring")  MaterialBySLDImpl::clone "MaterialBySLDImpl * MaterialBySLDImpl::clone() const override

Returns pointer to a copy of material. 
";

%feature("docstring")  MaterialBySLDImpl::refractiveIndex "complex_t MaterialBySLDImpl::refractiveIndex(double wavelength) const override

Returns refractive index. 
";

%feature("docstring")  MaterialBySLDImpl::refractiveIndex2 "complex_t MaterialBySLDImpl::refractiveIndex2(double wavelength) const override

Returns squared refractive index. 
";

%feature("docstring")  MaterialBySLDImpl::materialData "complex_t MaterialBySLDImpl::materialData() const override

Returns underlying material data. 
";

%feature("docstring")  MaterialBySLDImpl::typeID "MATERIAL_TYPES MaterialBySLDImpl::typeID() const override

Returns type of material implementation. 
";

%feature("docstring")  MaterialBySLDImpl::scalarSubtrSLD "complex_t MaterialBySLDImpl::scalarSubtrSLD(double lambda0) const override

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld (in  $nm^{-2}$) being the scattering length density 
";

%feature("docstring")  MaterialBySLDImpl::print "void MaterialBySLDImpl::print(std::ostream &ostr) const override

Prints object data. 
";


// File: classMesoCrystal.xml
%feature("docstring") MesoCrystal "

A particle with an internal structure of smaller particles.

C++ includes: MesoCrystal.h
";

%feature("docstring")  MesoCrystal::className "std::string MesoCrystal::className() const final
";

%feature("docstring")  MesoCrystal::MesoCrystal "MesoCrystal::MesoCrystal(const Crystal &particle_structure, const IFormFactor &form_factor)
";

%feature("docstring")  MesoCrystal::~MesoCrystal "MesoCrystal::~MesoCrystal() override
";

%feature("docstring")  MesoCrystal::clone "MesoCrystal * MesoCrystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  MesoCrystal::accept "void MesoCrystal::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  MesoCrystal::createSlicedParticle "SlicedParticle MesoCrystal::createSlicedParticle(const ZLimits &limits) const override

Creates a sliced form factor for this particle. 
";

%feature("docstring")  MesoCrystal::getChildren "std::vector< const INode * > MesoCrystal::getChildren() const override
";


// File: classMisesFisherGaussPeakShape.xml
%feature("docstring") MisesFisherGaussPeakShape "

A peak shape that is Gaussian in the radial direction and a convolution of a Mises-Fisher distribution with a Mises distribution on the two-sphere.

C++ includes: IPeakShape.h
";

%feature("docstring")  MisesFisherGaussPeakShape::className "std::string MisesFisherGaussPeakShape::className() const final
";

%feature("docstring")  MisesFisherGaussPeakShape::MisesFisherGaussPeakShape "MisesFisherGaussPeakShape::MisesFisherGaussPeakShape(double max_intensity, double radial_size, R3 zenith, double kappa_1, double kappa_2)
";

%feature("docstring")  MisesFisherGaussPeakShape::~MisesFisherGaussPeakShape "MisesFisherGaussPeakShape::~MisesFisherGaussPeakShape() override
";

%feature("docstring")  MisesFisherGaussPeakShape::clone "MisesFisherGaussPeakShape * MisesFisherGaussPeakShape::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  MisesFisherGaussPeakShape::accept "void MisesFisherGaussPeakShape::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  MisesFisherGaussPeakShape::evaluate "double MisesFisherGaussPeakShape::evaluate(R3 q, R3 q_lattice_point) const override

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  MisesFisherGaussPeakShape::angularDisorder "bool MisesFisherGaussPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classMisesGaussPeakShape.xml
%feature("docstring") MisesGaussPeakShape "

A peak shape that is a convolution of a Mises-Fisher distribution with a 3d Gaussian.

C++ includes: IPeakShape.h
";

%feature("docstring")  MisesGaussPeakShape::className "std::string MisesGaussPeakShape::className() const final
";

%feature("docstring")  MisesGaussPeakShape::MisesGaussPeakShape "MisesGaussPeakShape::MisesGaussPeakShape(double max_intensity, double radial_size, R3 zenith, double kappa)
";

%feature("docstring")  MisesGaussPeakShape::~MisesGaussPeakShape "MisesGaussPeakShape::~MisesGaussPeakShape() override
";

%feature("docstring")  MisesGaussPeakShape::clone "MisesGaussPeakShape * MisesGaussPeakShape::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  MisesGaussPeakShape::accept "void MisesGaussPeakShape::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  MisesGaussPeakShape::evaluate "double MisesGaussPeakShape::evaluate(R3 q, R3 q_lattice_point) const override

Evaluates the peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  MisesGaussPeakShape::angularDisorder "bool MisesGaussPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classMultiLayer.xml
%feature("docstring") MultiLayer "

Our sample model: a stack of layers one below the other. Example of system of 4 layers (3 interfaces):

ambience layer #0 ------ interface #0 z=0.0 Fe, 20A layer #1 ------ interface #1 z=-20.0 Cr, 40A layer #2 ------ interface #2 z=-60.0 substrate layer #3

C++ includes: MultiLayer.h
";

%feature("docstring")  MultiLayer::className "std::string MultiLayer::className() const final
";

%feature("docstring")  MultiLayer::MultiLayer "MultiLayer::MultiLayer(std::string name=\"Unnamed\")
";

%feature("docstring")  MultiLayer::~MultiLayer "MultiLayer::~MultiLayer() override
";

%feature("docstring")  MultiLayer::clone "MultiLayer * MultiLayer::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  MultiLayer::accept "void MultiLayer::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  MultiLayer::numberOfLayers "size_t MultiLayer::numberOfLayers() const
";

%feature("docstring")  MultiLayer::addLayer "void MultiLayer::addLayer(const Layer &layer)

Adds layer with default (zero) roughness. 
";

%feature("docstring")  MultiLayer::addLayerWithTopRoughness "void MultiLayer::addLayerWithTopRoughness(const Layer &layer, const LayerRoughness &roughness)

Adds layer with top roughness. 
";

%feature("docstring")  MultiLayer::setRoughnessModel "void MultiLayer::setRoughnessModel(RoughnessModel roughnessModel)
";

%feature("docstring")  MultiLayer::setCrossCorrLength "void MultiLayer::setCrossCorrLength(double crossCorrLength)

Sets cross correlation length of roughnesses between interfaces. 
";

%feature("docstring")  MultiLayer::setExternalField "void MultiLayer::setExternalField(R3 ext_field)

Sets the external field applied to the multilayer (units: A/m) 
";

%feature("docstring")  MultiLayer::layer "const Layer * MultiLayer::layer(size_t i_layer) const

Returns layer with given index. 
";

%feature("docstring")  MultiLayer::layerInterface "const LayerInterface * MultiLayer::layerInterface(size_t i_interface) const

Returns interface with given index. 
";

%feature("docstring")  MultiLayer::roughnessModel "RoughnessModel MultiLayer::roughnessModel() const
";

%feature("docstring")  MultiLayer::crossCorrLength "double MultiLayer::crossCorrLength() const

Returns cross correlation length of roughnesses between interfaces. 
";

%feature("docstring")  MultiLayer::externalField "R3 MultiLayer::externalField() const

Returns the external field applied to the multilayer (units: A/m) 
";

%feature("docstring")  MultiLayer::getChildren "std::vector< const INode * > MultiLayer::getChildren() const override
";

%feature("docstring")  MultiLayer::setSampleName "void MultiLayer::setSampleName(const std::string &name)
";

%feature("docstring")  MultiLayer::sampleName "const std::string& MultiLayer::sampleName() const
";


// File: structOneAdmixture.xml
%feature("docstring") OneAdmixture "

An admixture to a slice, consisting of a certain volume fraction of a homogeneous material.

C++ includes: Admixtures.h
";


// File: classParticle.xml
%feature("docstring") Particle "

A particle with a form factor and refractive index.

C++ includes: Particle.h
";

%feature("docstring")  Particle::className "std::string Particle::className() const override
";

%feature("docstring")  Particle::Particle "Particle::Particle(Material material, const IFormFactor &form_factor)
";

%feature("docstring")  Particle::Particle "Particle::Particle(Material material, const IFormFactor &form_factor, const IRotation &rotation)
";

%feature("docstring")  Particle::~Particle "Particle::~Particle() override
";

%feature("docstring")  Particle::clone "Particle * Particle::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Particle::accept "void Particle::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  Particle::createSlicedParticle "SlicedParticle Particle::createSlicedParticle(const ZLimits &limits) const override

Creates a sliced form factor for this particle. 
";

%feature("docstring")  Particle::material "const Material* Particle::material() const override

Returns nullptr, unless overwritten to return a specific material. 
";

%feature("docstring")  Particle::getChildren "std::vector< const INode * > Particle::getChildren() const override
";


// File: classParticleComposition.xml
%feature("docstring") ParticleComposition "

A composition of particles at fixed positions

C++ includes: ParticleComposition.h
";

%feature("docstring")  ParticleComposition::className "std::string ParticleComposition::className() const final
";

%feature("docstring")  ParticleComposition::ParticleComposition "ParticleComposition::ParticleComposition()
";

%feature("docstring")  ParticleComposition::ParticleComposition "ParticleComposition::ParticleComposition(const IParticle &particle, std::vector< R3 > positions)
";

%feature("docstring")  ParticleComposition::~ParticleComposition "ParticleComposition::~ParticleComposition() override
";

%feature("docstring")  ParticleComposition::clone "ParticleComposition * ParticleComposition::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ParticleComposition::accept "void ParticleComposition::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  ParticleComposition::createFormFactor "IFormFactor * ParticleComposition::createFormFactor() const override

Creates a form factor for this particle. 
";

%feature("docstring")  ParticleComposition::addParticle "void ParticleComposition::addParticle(const IParticle &particle)
";

%feature("docstring")  ParticleComposition::addParticle "void ParticleComposition::addParticle(const IParticle &particle, R3 position)
";

%feature("docstring")  ParticleComposition::addParticles "void ParticleComposition::addParticles(const IParticle &particle, std::vector< R3 > positions)
";

%feature("docstring")  ParticleComposition::nbrParticles "size_t ParticleComposition::nbrParticles() const

Returns number of different particles. 
";

%feature("docstring")  ParticleComposition::getChildren "std::vector< const INode * > ParticleComposition::getChildren() const override
";

%feature("docstring")  ParticleComposition::decompose "SafePointerVector< IParticle > ParticleComposition::decompose() const override

Decompose in constituent  IParticle objects. 
";

%feature("docstring")  ParticleComposition::zSpan "ZLimits ParticleComposition::zSpan() const override

Top and bottom z-coordinate. 
";


// File: classParticleCoreShell.xml
%feature("docstring") ParticleCoreShell "

A particle with a core/shell geometry.

C++ includes: ParticleCoreShell.h
";

%feature("docstring")  ParticleCoreShell::className "std::string ParticleCoreShell::className() const final
";

%feature("docstring")  ParticleCoreShell::ParticleCoreShell "ParticleCoreShell::ParticleCoreShell(const Particle &shell, const Particle &core, R3 relative_core_position=R3(0.0, 0.0, 0.0))
";

%feature("docstring")  ParticleCoreShell::~ParticleCoreShell "ParticleCoreShell::~ParticleCoreShell() override
";

%feature("docstring")  ParticleCoreShell::clone "ParticleCoreShell * ParticleCoreShell::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ParticleCoreShell::accept "void ParticleCoreShell::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  ParticleCoreShell::createSlicedParticle "SlicedParticle ParticleCoreShell::createSlicedParticle(const ZLimits &limits) const override

Creates a sliced form factor for this particle. 
";

%feature("docstring")  ParticleCoreShell::coreParticle "const Particle * ParticleCoreShell::coreParticle() const
";

%feature("docstring")  ParticleCoreShell::shellParticle "const Particle * ParticleCoreShell::shellParticle() const
";

%feature("docstring")  ParticleCoreShell::getChildren "std::vector< const INode * > ParticleCoreShell::getChildren() const override
";


// File: classParticleLayout.xml
%feature("docstring") ParticleLayout "

Decorator class that adds particles to  ISampleNode objects.

C++ includes: ParticleLayout.h
";

%feature("docstring")  ParticleLayout::className "std::string ParticleLayout::className() const final
";

%feature("docstring")  ParticleLayout::ParticleLayout "ParticleLayout::ParticleLayout()
";

%feature("docstring")  ParticleLayout::ParticleLayout "ParticleLayout::ParticleLayout(const IParticle &particle, double abundance=-1.0)
";

%feature("docstring")  ParticleLayout::~ParticleLayout "ParticleLayout::~ParticleLayout() override
";

%feature("docstring")  ParticleLayout::clone "ParticleLayout * ParticleLayout::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ParticleLayout::accept "void ParticleLayout::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  ParticleLayout::addParticle "void ParticleLayout::addParticle(const IParticle &particle, double abundance=-1.0, R3 position={}, const IRotation &rotation=IdentityRotation())

Adds particle to the layout with abundance, position and the rotation defined.

Parameters:
-----------

particle: 
to be added

abundance: 
 Particle abundance

position: 
 Particle position

rotation: 
 Particle rotation 
";

%feature("docstring")  ParticleLayout::particles "SafePointerVector< IParticle > ParticleLayout::particles() const

Returns information on all particles (type and abundance) and generates new particles if an  IParticle denotes a collection 
";

%feature("docstring")  ParticleLayout::interferenceFunction "const IInterference * ParticleLayout::interferenceFunction() const
";

%feature("docstring")  ParticleLayout::getTotalAbundance "double ParticleLayout::getTotalAbundance() const
";

%feature("docstring")  ParticleLayout::setInterference "void ParticleLayout::setInterference(const IInterference &interparticle)

Adds interference functions. 
";

%feature("docstring")  ParticleLayout::totalParticleSurfaceDensity "double ParticleLayout::totalParticleSurfaceDensity() const
";

%feature("docstring")  ParticleLayout::setTotalParticleSurfaceDensity "void ParticleLayout::setTotalParticleSurfaceDensity(double particle_density)

Sets total particle surface density.

Parameters:
-----------

particle_density: 
number of particles per square nanometer 
";

%feature("docstring")  ParticleLayout::getChildren "std::vector< const INode * > ParticleLayout::getChildren() const override
";

%feature("docstring")  ParticleLayout::weight "double ParticleLayout::weight() const

Returns the relative weight of this layout. 
";

%feature("docstring")  ParticleLayout::setWeight "void ParticleLayout::setWeight(double weight)

Sets the relative weight of this layout. 
";

%feature("docstring")  ParticleLayout::weightedParticleSurfaceDensity "double ParticleLayout::weightedParticleSurfaceDensity() const
";


// File: classff_1_1PolygonalTopology.xml
%feature("docstring") ff::PolygonalTopology "

For internal use in  PolyhedralFace.

C++ includes: PolyhedralTopology.h
";


// File: classff_1_1PolyhedralEdge.xml
%feature("docstring") ff::PolyhedralEdge "

One edge of a polygon, for form factor computation.

C++ includes: PolyhedralComponents.h
";

%feature("docstring")  ff::PolyhedralEdge::PolyhedralEdge "ff::PolyhedralEdge::PolyhedralEdge(R3 Vlow, R3 Vhig)
";

%feature("docstring")  ff::PolyhedralEdge::E "R3 ff::PolyhedralEdge::E() const
";

%feature("docstring")  ff::PolyhedralEdge::R "R3 ff::PolyhedralEdge::R() const
";

%feature("docstring")  ff::PolyhedralEdge::qE "complex_t ff::PolyhedralEdge::qE(C3 q) const
";

%feature("docstring")  ff::PolyhedralEdge::qR "complex_t ff::PolyhedralEdge::qR(C3 q) const
";

%feature("docstring")  ff::PolyhedralEdge::contrib "complex_t ff::PolyhedralEdge::contrib(int m, C3 qpa, complex_t qrperp) const

Returns sum_l=0^M/2 u^2l v^(M-2l) / (2l+1)!(M-2l)! - vperp^M/M! 
";


// File: classff_1_1PolyhedralFace.xml
%feature("docstring") ff::PolyhedralFace "

A polygon, for form factor computation.

C++ includes: PolyhedralComponents.h
";

%feature("docstring")  ff::PolyhedralFace::PolyhedralFace "ff::PolyhedralFace::PolyhedralFace(const std::vector< R3 > &_V=std::vector< R3 >(), bool _sym_S2=false)

Sets internal variables for given vertex chain.

Parameters:
-----------

V: 
oriented vertex list

_sym_S2: 
true if face has a perpedicular two-fold symmetry axis 
";

%feature("docstring")  ff::PolyhedralFace::area "double ff::PolyhedralFace::area() const
";

%feature("docstring")  ff::PolyhedralFace::pyramidalVolume "double ff::PolyhedralFace::pyramidalVolume() const
";

%feature("docstring")  ff::PolyhedralFace::radius3d "double ff::PolyhedralFace::radius3d() const
";

%feature("docstring")  ff::PolyhedralFace::normalProjectionConj "complex_t ff::PolyhedralFace::normalProjectionConj(C3 q) const

Returns conj(q)*normal [BasicVector3D::dot is antilinear in 'this' argument]. 
";

%feature("docstring")  ff::PolyhedralFace::ff_n "complex_t ff::PolyhedralFace::ff_n(int n, C3 q) const

Returns contribution qn*f_n [of order q^(n+1)] from this face to the polyhedral form factor. 
";

%feature("docstring")  ff::PolyhedralFace::ff "complex_t ff::PolyhedralFace::ff(C3 q, bool sym_Ci) const

Returns the contribution ff(q) of this face to the polyhedral form factor. 
";

%feature("docstring")  ff::PolyhedralFace::ff_2D "complex_t ff::PolyhedralFace::ff_2D(C3 qpa) const

Returns the two-dimensional form factor of this face, for use in a prism. 
";

%feature("docstring")  ff::PolyhedralFace::ff_2D_direct "complex_t ff::PolyhedralFace::ff_2D_direct(C3 qpa) const

Two-dimensional form factor, for use in prism, from sum over edge form factors. 
";

%feature("docstring")  ff::PolyhedralFace::ff_2D_expanded "complex_t ff::PolyhedralFace::ff_2D_expanded(C3 qpa) const

Two-dimensional form factor, for use in prism, from power series. 
";

%feature("docstring")  ff::PolyhedralFace::assert_Ci "void ff::PolyhedralFace::assert_Ci(const PolyhedralFace &other) const

Throws if deviation from inversion symmetry is detected. Does not check vertices. 
";


// File: classff_1_1PolyhedralTopology.xml
%feature("docstring") ff::PolyhedralTopology "

For internal use in  IFormFactorPolyhedron.

C++ includes: PolyhedralTopology.h
";


// File: classff_1_1Polyhedron.xml
%feature("docstring") ff::Polyhedron "

A polyhedron, implementation class for use in  IFormFactorPolyhedron.

C++ includes: Polyhedron.h
";

%feature("docstring")  ff::Polyhedron::Polyhedron "ff::Polyhedron::Polyhedron(const PolyhedralTopology &topology, double z_bottom, const std::vector< R3 > &vertices)
";

%feature("docstring")  ff::Polyhedron::Polyhedron "ff::Polyhedron::Polyhedron(const Polyhedron &)=delete
";

%feature("docstring")  ff::Polyhedron::assert_platonic "void ff::Polyhedron::assert_platonic() const
";

%feature("docstring")  ff::Polyhedron::volume "double ff::Polyhedron::volume() const
";

%feature("docstring")  ff::Polyhedron::radius "double ff::Polyhedron::radius() const
";

%feature("docstring")  ff::Polyhedron::vertices "const std::vector< R3 > ff::Polyhedron::vertices() const
";

%feature("docstring")  ff::Polyhedron::evaluate_for_q "complex_t ff::Polyhedron::evaluate_for_q(const C3 &q) const

needed for topZ, bottomZ computation

Returns the form factor F(q) of this polyhedron, respecting the offset z_bottom. 
";


// File: classPrism.xml
%feature("docstring") Prism "";

%feature("docstring")  Prism::Prism "Prism::Prism(bool symmetry_Ci, double height, const std::vector< R3 > &vertices)

The mathematics implemented here is described in full detail in a paper by Joachim Wuttke, entitled \"Form factor (Fourier shape transform) of polygon and polyhedron.\" 
";

%feature("docstring")  Prism::Prism "Prism::Prism(const Prism &)=delete
";

%feature("docstring")  Prism::area "double Prism::area() const
";

%feature("docstring")  Prism::vertices "const std::vector< R3 > & Prism::vertices() const
";

%feature("docstring")  Prism::evaluate_for_q "complex_t Prism::evaluate_for_q(const C3 &q) const

needed for topZ, bottomZ computation 
";


// File: structLattice2D_1_1ReciprocalBases.xml
%feature("docstring") Lattice2D::ReciprocalBases "";


// File: classRefractiveMaterialImpl.xml
%feature("docstring") RefractiveMaterialImpl "

Material implementation based on refractive coefficiencts (valid for one wavelength value only)

C++ includes: RefractiveMaterialImpl.h
";

%feature("docstring")  RefractiveMaterialImpl::~RefractiveMaterialImpl "RefractiveMaterialImpl::~RefractiveMaterialImpl() override=default
";

%feature("docstring")  RefractiveMaterialImpl::clone "RefractiveMaterialImpl * RefractiveMaterialImpl::clone() const override

Returns pointer to a copy of material. 
";

%feature("docstring")  RefractiveMaterialImpl::refractiveIndex "complex_t RefractiveMaterialImpl::refractiveIndex(double wavelength) const override

Returns refractive index For this particular implementation returned value does not depend on passed wavelength 
";

%feature("docstring")  RefractiveMaterialImpl::refractiveIndex2 "complex_t RefractiveMaterialImpl::refractiveIndex2(double wavelength) const override

Returns squared refractive index. For this particular implementation returned value does not depend on passed wavelength. 
";

%feature("docstring")  RefractiveMaterialImpl::materialData "complex_t RefractiveMaterialImpl::materialData() const override

Returns underlying material data. 
";

%feature("docstring")  RefractiveMaterialImpl::typeID "MATERIAL_TYPES RefractiveMaterialImpl::typeID() const override

Returns type of material implementation. 
";

%feature("docstring")  RefractiveMaterialImpl::scalarSubtrSLD "complex_t RefractiveMaterialImpl::scalarSubtrSLD(double lambda0) const override

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld (in  $nm^{-2}$) being the scattering length density. If the wavelength associated with passed wavevector is different from the one associated with refractive coefficients used during the object construction, provided result is inconsistent. 
";

%feature("docstring")  RefractiveMaterialImpl::print "void RefractiveMaterialImpl::print(std::ostream &ostr) const override

Prints object data. 
";


// File: classRippleCosine.xml
%feature("docstring") RippleCosine "";

%feature("docstring")  RippleCosine::RippleCosine "RippleCosine::RippleCosine(double length, double width, double height)
";

%feature("docstring")  RippleCosine::~RippleCosine "RippleCosine::~RippleCosine() override
";


// File: classRippleSawtooth.xml
%feature("docstring") RippleSawtooth "";

%feature("docstring")  RippleSawtooth::RippleSawtooth "RippleSawtooth::RippleSawtooth(double length, double width, double height, double asymmetry)
";

%feature("docstring")  RippleSawtooth::~RippleSawtooth "RippleSawtooth::~RippleSawtooth() override
";


// File: classRotationEuler.xml
%feature("docstring") RotationEuler "

A sequence of rotations about the z-x'-z'' axes.

C++ includes: Rotations.h
";

%feature("docstring")  RotationEuler::className "std::string RotationEuler::className() const final
";

%feature("docstring")  RotationEuler::RotationEuler "RotationEuler::RotationEuler(std::vector< double > P)
";

%feature("docstring")  RotationEuler::RotationEuler "RotationEuler::RotationEuler(double alpha, double beta, double gamma)
";

%feature("docstring")  RotationEuler::clone "RotationEuler* RotationEuler::clone() const override
";

%feature("docstring")  RotationEuler::createInverse "IRotation * RotationEuler::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationEuler::accept "void RotationEuler::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  RotationEuler::getAlpha "double RotationEuler::getAlpha() const
";

%feature("docstring")  RotationEuler::getBeta "double RotationEuler::getBeta() const
";

%feature("docstring")  RotationEuler::getGamma "double RotationEuler::getGamma() const
";

%feature("docstring")  RotationEuler::getTransform3D "Transform3D RotationEuler::getTransform3D() const override

Returns transformation. 
";


// File: classRotationX.xml
%feature("docstring") RotationX "

A rotation about the x axis.

C++ includes: Rotations.h
";

%feature("docstring")  RotationX::className "std::string RotationX::className() const final
";

%feature("docstring")  RotationX::RotationX "RotationX::RotationX(std::vector< double > P)

Constructor of rotation around x-axis. 
";

%feature("docstring")  RotationX::RotationX "RotationX::RotationX(double angle)
";

%feature("docstring")  RotationX::clone "RotationX* RotationX::clone() const override
";

%feature("docstring")  RotationX::createInverse "RotationX* RotationX::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationX::accept "void RotationX::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  RotationX::getAngle "double RotationX::getAngle() const
";

%feature("docstring")  RotationX::getTransform3D "Transform3D RotationX::getTransform3D() const override

Returns transformation. 
";


// File: classRotationY.xml
%feature("docstring") RotationY "

A rotation about the y axis.

C++ includes: Rotations.h
";

%feature("docstring")  RotationY::className "std::string RotationY::className() const final
";

%feature("docstring")  RotationY::RotationY "RotationY::RotationY(std::vector< double > P)

Constructor of rotation around y-axis. 
";

%feature("docstring")  RotationY::RotationY "RotationY::RotationY(double angle)
";

%feature("docstring")  RotationY::clone "RotationY* RotationY::clone() const override
";

%feature("docstring")  RotationY::createInverse "RotationY* RotationY::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationY::accept "void RotationY::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  RotationY::getAngle "double RotationY::getAngle() const
";

%feature("docstring")  RotationY::getTransform3D "Transform3D RotationY::getTransform3D() const override

Returns transformation. 
";


// File: classRotationZ.xml
%feature("docstring") RotationZ "

A rotation about the z axis.

C++ includes: Rotations.h
";

%feature("docstring")  RotationZ::className "std::string RotationZ::className() const final
";

%feature("docstring")  RotationZ::RotationZ "RotationZ::RotationZ(std::vector< double > P)

Constructor of rotation around z-axis. 
";

%feature("docstring")  RotationZ::RotationZ "RotationZ::RotationZ(double angle)
";

%feature("docstring")  RotationZ::clone "RotationZ* RotationZ::clone() const override
";

%feature("docstring")  RotationZ::createInverse "RotationZ* RotationZ::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationZ::accept "void RotationZ::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  RotationZ::getAngle "double RotationZ::getAngle() const
";

%feature("docstring")  RotationZ::getTransform3D "Transform3D RotationZ::getTransform3D() const override

Returns transformation. 
";


// File: structRoughnessModelWrap.xml
%feature("docstring") RoughnessModelWrap "";


// File: classSimpleSelectionRule.xml
%feature("docstring") SimpleSelectionRule "

Selection rule (v*q)modulus!=0, defined by vector v(a,b,c) and modulus.

C++ includes: ISelectionRule.h
";

%feature("docstring")  SimpleSelectionRule::SimpleSelectionRule "SimpleSelectionRule::SimpleSelectionRule(int a, int b, int c, int modulus)
";

%feature("docstring")  SimpleSelectionRule::~SimpleSelectionRule "SimpleSelectionRule::~SimpleSelectionRule() override=default
";

%feature("docstring")  SimpleSelectionRule::clone "SimpleSelectionRule * SimpleSelectionRule::clone() const override
";

%feature("docstring")  SimpleSelectionRule::coordinateSelected "bool SimpleSelectionRule::coordinateSelected(const I3 &coordinate) const override
";


// File: structSlicedParticle.xml
%feature("docstring") SlicedParticle "

Struct that contains information on a sliced particle. This information is needed for evaluating the sliced form factor and the average of a material, used in the Fresnel calculations.

C++ includes: SlicedParticle.h
";


// File: structSlicingEffects.xml
%feature("docstring") SlicingEffects "

Nested structure that holds slicing effects on position and removed parts.

C++ includes: IBornFF.h
";


// File: classSquareLattice2D.xml
%feature("docstring") SquareLattice2D "

A two-dimensional Bravais lattice with square unit cell.

C++ includes: Lattice2D.h
";

%feature("docstring")  SquareLattice2D::className "std::string SquareLattice2D::className() const final
";

%feature("docstring")  SquareLattice2D::SquareLattice2D "SquareLattice2D::SquareLattice2D(double length, double xi=0.0)
";

%feature("docstring")  SquareLattice2D::clone "SquareLattice2D * SquareLattice2D::clone() const override
";

%feature("docstring")  SquareLattice2D::accept "void SquareLattice2D::accept(INodeVisitor *visitor) const override
";

%feature("docstring")  SquareLattice2D::length1 "double SquareLattice2D::length1() const override
";

%feature("docstring")  SquareLattice2D::length2 "double SquareLattice2D::length2() const override
";

%feature("docstring")  SquareLattice2D::latticeAngle "double SquareLattice2D::latticeAngle() const override
";

%feature("docstring")  SquareLattice2D::unitCellArea "double SquareLattice2D::unitCellArea() const override
";


// File: classTruncatedEllipsoid.xml
%feature("docstring") TruncatedEllipsoid "";

%feature("docstring")  TruncatedEllipsoid::TruncatedEllipsoid "TruncatedEllipsoid::TruncatedEllipsoid(double r_x, double r_y, double r_z, double height, double dh)
";

%feature("docstring")  TruncatedEllipsoid::~TruncatedEllipsoid "TruncatedEllipsoid::~TruncatedEllipsoid() override
";


// File: classZLimits.xml
%feature("docstring") ZLimits "

An interval. Limits are of type double, and may be infinite. Used for the z-coordinate, especially when slicing form factors.

C++ includes: ZLimits.h
";

%feature("docstring")  ZLimits::ZLimits "ZLimits::ZLimits()
";

%feature("docstring")  ZLimits::ZLimits "ZLimits::ZLimits(double _min, double _max)
";

%feature("docstring")  ZLimits::isFinite "bool ZLimits::isFinite() const
";

%feature("docstring")  ZLimits::zBottom "double ZLimits::zBottom() const
";

%feature("docstring")  ZLimits::zTop "double ZLimits::zTop() const
";

%feature("docstring")  ZLimits::zTopOr0 "double ZLimits::zTopOr0() const
";

%feature("docstring")  ZLimits::thickness "double ZLimits::thickness() const
";

%feature("docstring")  ZLimits::thicknessOr0 "double ZLimits::thicknessOr0() const
";


// File: namespace_0d130.xml


// File: namespace_0d134.xml


// File: namespace_0d138.xml


// File: namespace_0d148.xml


// File: namespace_0d150.xml


// File: namespace_0d16.xml


// File: namespace_0d179.xml


// File: namespace_0d2.xml


// File: namespace_0d207.xml


// File: namespace_0d220.xml


// File: namespace_0d230.xml


// File: namespace_0d252.xml


// File: namespace_0d265.xml


// File: namespace_0d36.xml


// File: namespace_0d4.xml


// File: namespace_0d42.xml


// File: namespace_0d44.xml


// File: namespace_0d46.xml


// File: namespace_0d47.xml


// File: namespace_0d50.xml


// File: namespacebake.xml
%feature("docstring")  bake::CubicLattice "Lattice3D bake::CubicLattice(double a)

Returns a primitive cubic (cP) lattice with edge length a. 
";

%feature("docstring")  bake::FCCLattice "Lattice3D bake::FCCLattice(double a)

Returns a face-centered cubic (cF) lattice with edge length a. 
";

%feature("docstring")  bake::HexagonalLattice "Lattice3D bake::HexagonalLattice(double a, double c)

Returns a primitive hexagonal (hP) lattice with hexagonal edge a and height c. 
";

%feature("docstring")  bake::HCPLattice "Lattice3D bake::HCPLattice(double a, double c)

TODO: Clarify how this is meant: HCP is not a Bravais lattice. 
";

%feature("docstring")  bake::TetragonalLattice "Lattice3D bake::TetragonalLattice(double a, double c)

Returns a primitive tetragonal (tP) lattice with square base edge a and height c. 
";

%feature("docstring")  bake::BCTLattice "Lattice3D bake::BCTLattice(double a, double c)

Returns a body-centered cubic (cI) lattice with edge length a. TODO: Clarify meaning of c 
";


// File: namespaceExemplarySamples.xml
%feature("docstring")  ExemplarySamples::createBoxCompositionRotateX "MultiLayer * ExemplarySamples::createBoxCompositionRotateX()
";

%feature("docstring")  ExemplarySamples::createBoxCompositionRotateY "MultiLayer * ExemplarySamples::createBoxCompositionRotateY()
";

%feature("docstring")  ExemplarySamples::createBoxCompositionRotateZ "MultiLayer * ExemplarySamples::createBoxCompositionRotateZ()
";

%feature("docstring")  ExemplarySamples::createBoxCompositionRotateZandY "MultiLayer * ExemplarySamples::createBoxCompositionRotateZandY()
";

%feature("docstring")  ExemplarySamples::createBoxStackComposition "MultiLayer * ExemplarySamples::createBoxStackComposition()
";

%feature("docstring")  ExemplarySamples::createBoxesSquareLattice2D "MultiLayer * ExemplarySamples::createBoxesSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createCoreShellParticle "MultiLayer * ExemplarySamples::createCoreShellParticle()
";

%feature("docstring")  ExemplarySamples::createCoreShellBoxRotateZandY "MultiLayer * ExemplarySamples::createCoreShellBoxRotateZandY()
";

%feature("docstring")  ExemplarySamples::createCustomMorphology "MultiLayer * ExemplarySamples::createCustomMorphology()
";

%feature("docstring")  ExemplarySamples::createCylindersAndPrisms "MultiLayer * ExemplarySamples::createCylindersAndPrisms()
";

%feature("docstring")  ExemplarySamples::createCylindersInDWBA "MultiLayer * ExemplarySamples::createCylindersInDWBA()
";

%feature("docstring")  ExemplarySamples::createCylindersInBA "MultiLayer * ExemplarySamples::createCylindersInBA(double height=5, double radius=5)
";

%feature("docstring")  ExemplarySamples::createLargeCylindersInDWBA "MultiLayer * ExemplarySamples::createLargeCylindersInDWBA(double height=1000, double radius=500)
";

%feature("docstring")  ExemplarySamples::createRotatedCylinders "MultiLayer * ExemplarySamples::createRotatedCylinders()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayer "MultiLayer * ExemplarySamples::createFeNiBilayer()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerTanh "MultiLayer * ExemplarySamples::createFeNiBilayerTanh()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerNC "MultiLayer * ExemplarySamples::createFeNiBilayerNC()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerSpinFlip "MultiLayer * ExemplarySamples::createFeNiBilayerSpinFlip()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerSpinFlipTanh "MultiLayer * ExemplarySamples::createFeNiBilayerSpinFlipTanh()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerSpinFlipNC "MultiLayer * ExemplarySamples::createFeNiBilayerSpinFlipNC()
";

%feature("docstring")  ExemplarySamples::createHomogeneousMultilayer "MultiLayer * ExemplarySamples::createHomogeneousMultilayer()
";

%feature("docstring")  ExemplarySamples::createLattice1D "MultiLayer * ExemplarySamples::createLattice1D()
";

%feature("docstring")  ExemplarySamples::createLayersWithAbsorptionWithFF "MultiLayer * ExemplarySamples::createLayersWithAbsorptionWithFF(const IFormFactor *)
";

%feature("docstring")  ExemplarySamples::createLayersWithAbsorptionBySLD "MultiLayer * ExemplarySamples::createLayersWithAbsorptionBySLD()
";

%feature("docstring")  ExemplarySamples::createMagneticSubstrateZeroField "MultiLayer * ExemplarySamples::createMagneticSubstrateZeroField()
";

%feature("docstring")  ExemplarySamples::createSimpleMagneticLayer "MultiLayer * ExemplarySamples::createSimpleMagneticLayer()
";

%feature("docstring")  ExemplarySamples::createMagneticLayer "MultiLayer * ExemplarySamples::createMagneticLayer()
";

%feature("docstring")  ExemplarySamples::createSimpleMagneticRotationWithRoughness "MultiLayer * ExemplarySamples::createSimpleMagneticRotationWithRoughness(const std::string &roughnessKey)
";

%feature("docstring")  ExemplarySamples::createMagneticRotation "MultiLayer * ExemplarySamples::createMagneticRotation()
";

%feature("docstring")  ExemplarySamples::createMagneticParticleZeroField "MultiLayer * ExemplarySamples::createMagneticParticleZeroField()
";

%feature("docstring")  ExemplarySamples::createMagneticCylinders "MultiLayer * ExemplarySamples::createMagneticCylinders()
";

%feature("docstring")  ExemplarySamples::createMagneticSpheres "MultiLayer * ExemplarySamples::createMagneticSpheres()
";

%feature("docstring")  ExemplarySamples::createMesoCrystal "MultiLayer * ExemplarySamples::createMesoCrystal()
";

%feature("docstring")  ExemplarySamples::createMultiLayerWithNCRoughness "MultiLayer * ExemplarySamples::createMultiLayerWithNCRoughness()
";

%feature("docstring")  ExemplarySamples::createMultiLayerWithRoughness "MultiLayer * ExemplarySamples::createMultiLayerWithRoughness()
";

%feature("docstring")  ExemplarySamples::createMultipleLayout "MultiLayer * ExemplarySamples::createMultipleLayout()
";

%feature("docstring")  ExemplarySamples::createRadialParaCrystal "MultiLayer * ExemplarySamples::createRadialParaCrystal()
";

%feature("docstring")  ExemplarySamples::createBasic2DParaCrystalWithFTDis "MultiLayer * ExemplarySamples::createBasic2DParaCrystalWithFTDis(const IFTDistribution2D *pdf2)
";

%feature("docstring")  ExemplarySamples::createHexParaCrystal "MultiLayer * ExemplarySamples::createHexParaCrystal()
";

%feature("docstring")  ExemplarySamples::createRectParaCrystal "MultiLayer * ExemplarySamples::createRectParaCrystal()
";

%feature("docstring")  ExemplarySamples::createParticleComposition "MultiLayer * ExemplarySamples::createParticleComposition()
";

%feature("docstring")  ExemplarySamples::createCylindersWithSizeDistribution "MultiLayer * ExemplarySamples::createCylindersWithSizeDistribution()
";

%feature("docstring")  ExemplarySamples::createTwoTypesCylindersDistribution "MultiLayer * ExemplarySamples::createTwoTypesCylindersDistribution()
";

%feature("docstring")  ExemplarySamples::createRotatedPyramidsDistribution "MultiLayer * ExemplarySamples::createRotatedPyramidsDistribution()
";

%feature("docstring")  ExemplarySamples::createSpheresWithLimitsDistribution "MultiLayer * ExemplarySamples::createSpheresWithLimitsDistribution()
";

%feature("docstring")  ExemplarySamples::createConesWithLimitsDistribution "MultiLayer * ExemplarySamples::createConesWithLimitsDistribution()
";

%feature("docstring")  ExemplarySamples::createLinkedBoxDistribution "MultiLayer * ExemplarySamples::createLinkedBoxDistribution()
";

%feature("docstring")  ExemplarySamples::createParticleInVacuumWithFF "MultiLayer * ExemplarySamples::createParticleInVacuumWithFF(const IFormFactor *)
";

%feature("docstring")  ExemplarySamples::createHardDisk "MultiLayer * ExemplarySamples::createHardDisk()
";

%feature("docstring")  ExemplarySamples::createPlainMultiLayerBySLD "MultiLayer * ExemplarySamples::createPlainMultiLayerBySLD(int n_layers=10, double thick_ti=3.0)
";

%feature("docstring")  ExemplarySamples::createResonator "MultiLayer * ExemplarySamples::createResonator(double ti_thickness=13.0)
";

%feature("docstring")  ExemplarySamples::createCosineRipple "MultiLayer * ExemplarySamples::createCosineRipple()
";

%feature("docstring")  ExemplarySamples::createTriangularRipple "MultiLayer * ExemplarySamples::createTriangularRipple(double d=0)
";

%feature("docstring")  ExemplarySamples::createAsymRipple "MultiLayer * ExemplarySamples::createAsymRipple()
";

%feature("docstring")  ExemplarySamples::createRotatedPyramids "MultiLayer * ExemplarySamples::createRotatedPyramids()
";

%feature("docstring")  ExemplarySamples::createSizeDistributionDAModel "MultiLayer * ExemplarySamples::createSizeDistributionDAModel()
";

%feature("docstring")  ExemplarySamples::createSizeDistributionLMAModel "MultiLayer * ExemplarySamples::createSizeDistributionLMAModel()
";

%feature("docstring")  ExemplarySamples::createSizeDistributionSSCAModel "MultiLayer * ExemplarySamples::createSizeDistributionSSCAModel()
";

%feature("docstring")  ExemplarySamples::createCylindersInSSCA "MultiLayer * ExemplarySamples::createCylindersInSSCA()
";

%feature("docstring")  ExemplarySamples::createSlicedComposition "MultiLayer * ExemplarySamples::createSlicedComposition()
";

%feature("docstring")  ExemplarySamples::createSlicedCylinders "MultiLayer * ExemplarySamples::createSlicedCylinders()
";

%feature("docstring")  ExemplarySamples::createSLDSlicedCylinders "MultiLayer * ExemplarySamples::createSLDSlicedCylinders()
";

%feature("docstring")  ExemplarySamples::createAveragedSlicedCylinders "MultiLayer * ExemplarySamples::createAveragedSlicedCylinders()
";

%feature("docstring")  ExemplarySamples::createThickAbsorptiveSample "MultiLayer * ExemplarySamples::createThickAbsorptiveSample()
";

%feature("docstring")  ExemplarySamples::createTransformBox "MultiLayer * ExemplarySamples::createTransformBox()
";

%feature("docstring")  ExemplarySamples::createBasic2DLattice "MultiLayer * ExemplarySamples::createBasic2DLattice()
";

%feature("docstring")  ExemplarySamples::createSquareLattice2D "MultiLayer * ExemplarySamples::createSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createCenteredSquareLattice2D "MultiLayer * ExemplarySamples::createCenteredSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createRotatedSquareLattice2D "MultiLayer * ExemplarySamples::createRotatedSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createFiniteSquareLattice2D "MultiLayer * ExemplarySamples::createFiniteSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createSuperLattice "MultiLayer * ExemplarySamples::createSuperLattice()
";


// File: namespaceff.xml


// File: namespaceff__aux.xml
%feature("docstring")  ff_aux::generateReciprocalFactorialArray "constexpr std::array<double, N> ff_aux::generateReciprocalFactorialArray()

Returns a compile-time generated std::array of reciprocal factorials. 
";


// File: namespaceMaterialUtils.xml
%feature("docstring")  MaterialUtils::ScalarReducedPotential "complex_t MaterialUtils::ScalarReducedPotential(complex_t n, R3 k, double n_ref)

Function for calculating the reduced potential, used for obtaining the Fresnel coefficients (non-polarized material case) 
";

%feature("docstring")  MaterialUtils::PolarizedReducedPotential "Eigen::Matrix2cd MaterialUtils::PolarizedReducedPotential(complex_t n, R3 b_field, R3 k, double n_ref)

Function for calculating the reduced potential, used for obtaining the Fresnel coefficients (polarized material case) 
";

%feature("docstring")  MaterialUtils::MagnetizationCorrection "Eigen::Matrix2cd MaterialUtils::MagnetizationCorrection(complex_t unit_factor, double magnetic_factor, Vec3< T > polarization)
";

%feature("docstring")  MaterialUtils::checkMaterialTypes "MATERIAL_TYPES MaterialUtils::checkMaterialTypes(const std::vector< const Material * > &materials)

Checks if all non-default materials in  materials are of the same type and returns this type. If several types of materials are involved, InvalidMaterialType identifier is returned. 
";


// File: namespacePy.xml


// File: namespacePy_1_1Import.xml
%feature("docstring")  Py::Import::createFromPython "std::unique_ptr< MultiLayer > Py::Import::createFromPython(const std::string &script, const std::string &functionName, const std::string &path=\"\")

Creates a multi layer by running python code in embedded interpreter.

Parameters:
-----------

script: 
Python script

functionName: 
A function name in this script which produces a  MultiLayer

path: 
A path to import BornAgain library. If empty, relies on PYTHONPATH 
";

%feature("docstring")  Py::Import::listOfFunctions "std::vector< std::string > Py::Import::listOfFunctions(const std::string &script, const std::string &path=\"\")

Returns list of functions defined in the script.

Parameters:
-----------

script: 
Python script

path: 
A path to import BornAgain library. If empty, relies on PYTHONPATH 
";


// File: namespacerefMat.xml


// File: namespaceripples.xml
%feature("docstring")  ripples::factor_x_box "complex_t ripples::factor_x_box(complex_t q, double l)
";

%feature("docstring")  ripples::factor_x_Gauss "complex_t ripples::factor_x_Gauss(complex_t q, double l)
";

%feature("docstring")  ripples::factor_x_Lorentz "complex_t ripples::factor_x_Lorentz(complex_t q, double l)
";

%feature("docstring")  ripples::profile_yz_bar "complex_t ripples::profile_yz_bar(complex_t qy, complex_t qz, double width, double height)

Complex form factor of rectangular ripple (bar). 
";

%feature("docstring")  ripples::profile_yz_cosine "complex_t ripples::profile_yz_cosine(complex_t qy, complex_t qz, double width, double height)

Complex form factor of cosine ripple. 
";

%feature("docstring")  ripples::profile_yz_triangular "complex_t ripples::profile_yz_triangular(complex_t qy, complex_t qz, double width, double height, double asymmetry)

Complex form factor of triangular ripple. 
";


// File: namespaceSampleUtils.xml


// File: namespaceSampleUtils_1_1Multilayer.xml
%feature("docstring")  SampleUtils::Multilayer::LayerTopRoughness "const LayerRoughness * SampleUtils::Multilayer::LayerTopRoughness(const MultiLayer &multilayer, size_t i)

Returns top roughness of layer. 
";

%feature("docstring")  SampleUtils::Multilayer::IndexOfLayer "size_t SampleUtils::Multilayer::IndexOfLayer(const MultiLayer &multilayer, const Layer *p_layer)

Returns the index of the given layer. 
";

%feature("docstring")  SampleUtils::Multilayer::ContainsCompatibleMaterials "bool SampleUtils::Multilayer::ContainsCompatibleMaterials(const MultiLayer &multilayer)

Returns true if the multilayer contains non-default materials of one type only. 
";

%feature("docstring")  SampleUtils::Multilayer::hasRoughness "bool SampleUtils::Multilayer::hasRoughness(const MultiLayer &sample)
";


// File: namespaceSampleUtils_1_1someff.xml
%feature("docstring")  SampleUtils::someff::ffSphere "complex_t SampleUtils::someff::ffSphere(C3 q, double R)

Returns the form factor of a sphere of radius R.

Used by the hard sphere and by several soft sphere classes. 
";


// File: namespacestd.xml


// File: IInterference_8cpp.xml


// File: IInterference_8h.xml


// File: Interference1DLattice_8cpp.xml


// File: Interference1DLattice_8h.xml


// File: Interference2DLattice_8cpp.xml


// File: Interference2DLattice_8h.xml


// File: Interference2DParaCrystal_8cpp.xml


// File: Interference2DParaCrystal_8h.xml


// File: Interference2DSuperLattice_8cpp.xml


// File: Interference2DSuperLattice_8h.xml


// File: Interference3DLattice_8cpp.xml


// File: Interference3DLattice_8h.xml


// File: InterferenceFinite2DLattice_8cpp.xml


// File: InterferenceFinite2DLattice_8h.xml


// File: InterferenceFinite3DLattice_8cpp.xml


// File: InterferenceFinite3DLattice_8h.xml


// File: InterferenceHardDisk_8cpp.xml


// File: InterferenceHardDisk_8h.xml


// File: InterferenceNone_8cpp.xml


// File: InterferenceNone_8h.xml


// File: InterferenceRadialParaCrystal_8cpp.xml


// File: InterferenceRadialParaCrystal_8h.xml


// File: Interferences_8h.xml


// File: InterferenceTwin_8cpp.xml


// File: InterferenceTwin_8h.xml


// File: ParticleLayout_8cpp.xml


// File: ParticleLayout_8h.xml


// File: FormFactorComponents_8cpp.xml


// File: FormFactorComponents_8h.xml


// File: FTDistribution2DComponents_8cpp.xml


// File: FTDistribution2DComponents_8h.xml


// File: IRegistry_8h.xml


// File: FTDecay1D_8cpp.xml


// File: FTDecay1D_8h.xml


// File: FTDecay2D_8cpp.xml


// File: FTDecay2D_8h.xml


// File: FTDistributions1D_8cpp.xml


// File: FTDistributions1D_8h.xml


// File: FTDistributions2D_8cpp.xml


// File: FTDistributions2D_8h.xml


// File: IDistribution1DSampler_8cpp.xml


// File: IDistribution1DSampler_8h.xml


// File: IDistribution2DSampler_8cpp.xml


// File: IDistribution2DSampler_8h.xml


// File: IPeakShape_8cpp.xml


// File: IPeakShape_8h.xml


// File: Factorial_8h.xml


// File: PolyhedralComponents_8cpp.xml


// File: PolyhedralComponents_8h.xml


// File: PolyhedralTopology_8h.xml


// File: Polyhedron_8cpp.xml


// File: Polyhedron_8h.xml


// File: FormFactorAnisoPyramid_8cpp.xml


// File: FormFactorAnisoPyramid_8h.xml


// File: FormFactorBar_8cpp.xml


// File: FormFactorBar_8h.xml


// File: FormFactorBox_8cpp.xml


// File: FormFactorBox_8h.xml


// File: FormFactorCantellatedCube_8cpp.xml


// File: FormFactorCantellatedCube_8h.xml


// File: FormFactorCone_8cpp.xml


// File: FormFactorCone_8h.xml


// File: FormFactorCone6_8cpp.xml


// File: FormFactorCone6_8h.xml


// File: FormFactorCosineRipple_8cpp.xml


// File: FormFactorCosineRipple_8h.xml


// File: FormFactorCuboctahedron_8cpp.xml


// File: FormFactorCuboctahedron_8h.xml


// File: FormFactorCylinder_8cpp.xml


// File: FormFactorCylinder_8h.xml


// File: FormFactorDodecahedron_8cpp.xml


// File: FormFactorDodecahedron_8h.xml


// File: FormFactorEllipsoidalCylinder_8cpp.xml


// File: FormFactorEllipsoidalCylinder_8h.xml


// File: FormFactorFullSphere_8cpp.xml


// File: FormFactorFullSphere_8h.xml


// File: FormFactorFullSpheroid_8cpp.xml


// File: FormFactorFullSpheroid_8h.xml


// File: FormFactorHemiEllipsoid_8cpp.xml


// File: FormFactorHemiEllipsoid_8h.xml


// File: FormFactorHollowSphere_8cpp.xml


// File: FormFactorHollowSphere_8h.xml


// File: FormFactorIcosahedron_8cpp.xml


// File: FormFactorIcosahedron_8h.xml


// File: FormFactorLongBoxGauss_8cpp.xml


// File: FormFactorLongBoxGauss_8h.xml


// File: FormFactorLongBoxLorentz_8cpp.xml


// File: FormFactorLongBoxLorentz_8h.xml


// File: FormFactorPrism3_8cpp.xml


// File: FormFactorPrism3_8h.xml


// File: FormFactorPrism6_8cpp.xml


// File: FormFactorPrism6_8h.xml


// File: FormFactorPyramid_8cpp.xml


// File: FormFactorPyramid_8h.xml


// File: FormFactorSawtoothRipple_8cpp.xml


// File: FormFactorSawtoothRipple_8h.xml


// File: FormFactorTetrahedron_8cpp.xml


// File: FormFactorTetrahedron_8h.xml


// File: FormFactorTruncatedCube_8cpp.xml


// File: FormFactorTruncatedCube_8h.xml


// File: FormFactorTruncatedSphere_8cpp.xml


// File: FormFactorTruncatedSphere_8h.xml


// File: FormFactorTruncatedSpheroid_8cpp.xml


// File: FormFactorTruncatedSpheroid_8h.xml


// File: HardParticles_8h.xml


// File: IFormFactorPolyhedron_8cpp.xml


// File: IFormFactorPolyhedron_8h.xml


// File: IFormFactorPrism_8cpp.xml


// File: IFormFactorPrism_8h.xml


// File: IProfileRipple_8cpp.xml


// File: IProfileRipple_8h.xml


// File: Prism_8cpp.xml


// File: Prism_8h.xml


// File: Ripples_8cpp.xml


// File: Ripples_8h.xml


// File: LayerInterface_8cpp.xml


// File: LayerInterface_8h.xml


// File: LayerRoughness_8cpp.xml


// File: LayerRoughness_8h.xml


// File: BakeLattice_8cpp.xml


// File: BakeLattice_8h.xml


// File: ISelectionRule_8h.xml


// File: Lattice2D_8cpp.xml


// File: Lattice2D_8h.xml


// File: Lattice3D_8cpp.xml


// File: Lattice3D_8h.xml


// File: SomeFormFactors_8cpp.xml


// File: SomeFormFactors_8h.xml


// File: Admixtures_8h.xml


// File: BaseMaterialImpl_8h.xml


// File: MagneticMaterialImpl_8cpp.xml


// File: MagneticMaterialImpl_8h.xml


// File: Material_8cpp.xml


// File: Material_8h.xml


// File: MaterialBySLDImpl_8cpp.xml


// File: MaterialBySLDImpl_8h.xml


// File: MaterialFactoryFuncs_8cpp.xml
%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, complex_t refractive_index, R3 magnetization)

Constructs a material with  name,  refractive_index and  magnetization (in A/m). Alternatively,  $\\\\delta$ and  $\\\\beta$ for refractive index  $n = 1 - \\\\delta + i \\\\beta$ can be passed directly. With no parameters given, constructs default (vacuum) material with  $n = 1$ and zero magnetization. 
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, double delta, double beta, R3 magnetization)
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial()
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD()
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD(const std::string &name, double sld_real, double sld_imag, R3 magnetization)

Constructs a wavelength-independent material with a given complex-valued scattering length density (SLD). SLD values for a wide variety of materials can be found on https://sld-calculator.appspot.com/ and https://www.ncnr.nist.gov/resources/activation/ By convention, SLD imaginary part is treated as negative by default, which corresponds to attenuation of the signal. With no parameters given, MaterialBySLD constructs default (vacuum) material with zero sld and zero magnetization.

Parameters:
-----------

name: 
material name

sld_real: 
real part of the scattering length density, inverse square angstroms

sld_imag: 
imaginary part of the scattering length density, inverse square angstroms

magnetization: 
magnetization (in A/m) 
";


// File: MaterialFactoryFuncs_8h.xml
%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial()
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, double delta, double beta, R3 magnetization={})
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, complex_t refractive_index, R3 magnetization={})

Constructs a material with  name,  refractive_index and  magnetization (in A/m). Alternatively,  $\\\\delta$ and  $\\\\beta$ for refractive index  $n = 1 - \\\\delta + i \\\\beta$ can be passed directly. With no parameters given, constructs default (vacuum) material with  $n = 1$ and zero magnetization. 
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD()
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD(const std::string &name, double sld_real, double sld_imag, R3 magnetization={})

Constructs a wavelength-independent material with a given complex-valued scattering length density (SLD). SLD values for a wide variety of materials can be found on https://sld-calculator.appspot.com/ and https://www.ncnr.nist.gov/resources/activation/ By convention, SLD imaginary part is treated as negative by default, which corresponds to attenuation of the signal. With no parameters given, MaterialBySLD constructs default (vacuum) material with zero sld and zero magnetization.

Parameters:
-----------

name: 
material name

sld_real: 
real part of the scattering length density, inverse square angstroms

sld_imag: 
imaginary part of the scattering length density, inverse square angstroms

magnetization: 
magnetization (in A/m) 
";


// File: MaterialUtils_8cpp.xml
%feature("docstring")  Unit_Matrix "const Eigen::Matrix2cd Unit_Matrix(Eigen::Matrix2cd::Identity())
";


// File: MaterialUtils_8h.xml


// File: RefractiveMaterialImpl_8cpp.xml


// File: RefractiveMaterialImpl_8h.xml


// File: Layer_8cpp.xml


// File: Layer_8h.xml


// File: MultiLayer_8cpp.xml


// File: MultiLayer_8h.xml


// File: MultilayerUtils_8cpp.xml


// File: MultilayerUtils_8h.xml


// File: PyImport_8cpp.xml


// File: PyImport_8h.xml


// File: RoughnessModels_8cpp.xml


// File: RoughnessModels_8h.xml


// File: Crystal_8cpp.xml


// File: Crystal_8h.xml


// File: FormFactorCoreShell_8cpp.xml


// File: FormFactorCoreShell_8h.xml


// File: FormFactorCrystal_8cpp.xml


// File: FormFactorCrystal_8h.xml


// File: FormFactorWeighted_8cpp.xml


// File: FormFactorWeighted_8h.xml


// File: IParticle_8cpp.xml


// File: IParticle_8h.xml


// File: MesoCrystal_8cpp.xml


// File: MesoCrystal_8h.xml


// File: Particle_8cpp.xml


// File: Particle_8h.xml


// File: ParticleComposition_8cpp.xml


// File: ParticleComposition_8h.xml


// File: ParticleCoreShell_8cpp.xml


// File: ParticleCoreShell_8h.xml


// File: SlicedParticle_8h.xml


// File: FormFactorDecoratorMaterial_8cpp.xml


// File: FormFactorDecoratorMaterial_8h.xml


// File: FormFactorDecoratorPositionFactor_8cpp.xml


// File: FormFactorDecoratorPositionFactor_8h.xml


// File: FormFactorDecoratorRotation_8cpp.xml


// File: FormFactorDecoratorRotation_8h.xml


// File: IBornFF_8cpp.xml


// File: IBornFF_8h.xml


// File: IFormFactor_8cpp.xml


// File: IFormFactor_8h.xml


// File: IFormFactorDecorator_8h.xml


// File: ISampleNode_8cpp.xml


// File: ISampleNode_8h.xml


// File: Rotations_8cpp.xml
%feature("docstring")  createProduct "IRotation* createProduct(const IRotation &left, const IRotation &right)

Returns concatenated rotation (first right, then left). 
";


// File: Rotations_8h.xml
%feature("docstring")  createProduct "IRotation* createProduct(const IRotation &left, const IRotation &right)

Returns concatenated rotation (first right, then left). 
";


// File: ZLimits_8cpp.xml


// File: ZLimits_8h.xml


// File: Box_8cpp.xml


// File: Box_8h.xml


// File: DoubleEllipse_8cpp.xml


// File: DoubleEllipse_8h.xml


// File: IShape3D_8cpp.xml
%feature("docstring")  RectangleVertices "std::vector<R3> RectangleVertices(double length, double width, double z)

Helper functions to construct lists of vertices

Generate vertices of centered rectangle at height z 
";

%feature("docstring")  EllipseVertices "std::vector<R3> EllipseVertices(double r_x, double r_y, double z)

Generate vertices of centered ellipse with given semi-axes at height z. 
";


// File: IShape3D_8h.xml
%feature("docstring")  RectangleVertices "std::vector<R3> RectangleVertices(double length, double width, double z)

Helper functions to construct lists of vertices

Generate vertices of centered rectangle at height z 
";

%feature("docstring")  EllipseVertices "std::vector<R3> EllipseVertices(double r_x, double r_y, double z)

Generate vertices of centered ellipse with given semi-axes at height z. 
";


// File: RippleCosine_8cpp.xml


// File: RippleCosine_8h.xml


// File: RippleSawtooth_8cpp.xml


// File: RippleSawtooth_8h.xml


// File: TruncatedEllipsoid_8cpp.xml


// File: TruncatedEllipsoid_8h.xml


// File: FormFactorGauss_8cpp.xml


// File: FormFactorGauss_8h.xml


// File: FormFactorSphereGaussianRadius_8cpp.xml


// File: FormFactorSphereGaussianRadius_8h.xml


// File: FormFactorSphereLogNormalRadius_8cpp.xml


// File: FormFactorSphereLogNormalRadius_8h.xml


// File: SoftParticles_8h.xml


// File: BoxCompositionBuilder_8cpp.xml


// File: BoxCompositionBuilder_8h.xml


// File: BoxesSquareLatticeBuilder_8cpp.xml


// File: BoxesSquareLatticeBuilder_8h.xml


// File: CoreShellParticleBuilder_8cpp.xml


// File: CoreShellParticleBuilder_8h.xml


// File: CustomMorphologyBuilder_8cpp.xml


// File: CustomMorphologyBuilder_8h.xml


// File: CylindersAndPrismsBuilder_8cpp.xml


// File: CylindersAndPrismsBuilder_8h.xml


// File: CylindersBuilder_8cpp.xml


// File: CylindersBuilder_8h.xml


// File: ExemplarySamples_8h.xml


// File: FeNiBilayerBuilder_8cpp.xml


// File: FeNiBilayerBuilder_8h.xml


// File: HomogeneousMultilayerBuilder_8cpp.xml


// File: HomogeneousMultilayerBuilder_8h.xml


// File: LatticeBuilder_8cpp.xml


// File: LatticeBuilder_8h.xml


// File: LayersWithAbsorptionBuilder_8cpp.xml


// File: LayersWithAbsorptionBuilder_8h.xml


// File: LayersWithAbsorptionBySLDBuilder_8cpp.xml
%feature("docstring")  middle_layer_thickness "const double middle_layer_thickness(60.0)
";


// File: LayersWithAbsorptionBySLDBuilder_8h.xml


// File: MagneticLayersBuilder_8cpp.xml


// File: MagneticLayersBuilder_8h.xml


// File: MagneticParticlesBuilder_8cpp.xml


// File: MagneticParticlesBuilder_8h.xml


// File: MesoCrystalBuilder_8cpp.xml


// File: MesoCrystalBuilder_8h.xml


// File: MultiLayerWithNCRoughnessBuilder_8cpp.xml


// File: MultiLayerWithNCRoughnessBuilder_8h.xml


// File: MultiLayerWithRoughnessBuilder_8cpp.xml


// File: MultiLayerWithRoughnessBuilder_8h.xml


// File: MultipleLayoutBuilder_8cpp.xml


// File: MultipleLayoutBuilder_8h.xml


// File: ParaCrystalBuilder_8cpp.xml


// File: ParaCrystalBuilder_8h.xml


// File: ParticleCompositionBuilder_8cpp.xml


// File: ParticleCompositionBuilder_8h.xml


// File: ParticleDistributionsBuilder_8cpp.xml


// File: ParticleDistributionsBuilder_8h.xml


// File: ParticleInVacuumBuilder_8cpp.xml


// File: ParticleInVacuumBuilder_8h.xml


// File: PercusYevickBuilder_8cpp.xml


// File: PercusYevickBuilder_8h.xml


// File: PlainMultiLayerBySLDBuilder_8cpp.xml


// File: PlainMultiLayerBySLDBuilder_8h.xml


// File: ReferenceMaterials_8h.xml


// File: ResonatorBuilder_8cpp.xml


// File: ResonatorBuilder_8h.xml


// File: RipplesBuilder_8cpp.xml


// File: RipplesBuilder_8h.xml


// File: RotatedPyramidsBuilder_8cpp.xml


// File: RotatedPyramidsBuilder_8h.xml


// File: SizeDistributionModelsBuilder_8cpp.xml


// File: SizeDistributionModelsBuilder_8h.xml


// File: SlicedCompositionBuilder_8cpp.xml


// File: SlicedCompositionBuilder_8h.xml


// File: SlicedCylindersBuilder_8cpp.xml


// File: SlicedCylindersBuilder_8h.xml


// File: ThickAbsorptiveSampleBuilder_8cpp.xml


// File: ThickAbsorptiveSampleBuilder_8h.xml


// File: TransformationsBuilder_8cpp.xml


// File: TransformationsBuilder_8h.xml


// File: TwoDimLatticeBuilder_8cpp.xml


// File: TwoDimLatticeBuilder_8h.xml


// File: dir_220e7f16e10b4e45e27e10ed0346ff0c.xml


// File: dir_53ad17160220d2858133377088cf64b3.xml


// File: dir_7b210e8d28f50f0c519681ee1b473363.xml


// File: dir_8dce49f7ddb29807dd12921987aafe35.xml


// File: dir_844f24c588eea1b259def164cc466f1a.xml


// File: dir_ff19b2623e8f6ab46659baac68a70953.xml


// File: dir_da063889c15f3636a66540651967c41d.xml


// File: dir_ed097210e0926370940660d36aeab42a.xml


// File: dir_fba8602a8c23825d875c7205aab8e979.xml


// File: dir_9b633c8be420b8d6b83f5ed5376ef19b.xml


// File: dir_61bfb933e72dfe3586b97d80db501038.xml


// File: dir_8f7f72226bf217e57890a767dfa82dfa.xml


// File: dir_c4bcd3a441ff6332187b5528d22c5933.xml


// File: dir_7002b98d93049c66d9f454102abc535d.xml


// File: dir_ccd033f493018670b3204f8d6a838d21.xml


// File: dir_d9d42b37b662547974602e66402128ce.xml

